@@ -10,7 +10,7 @@
 ;;  See the GNU General Public License for more details.
 ;;
 ;;  Copyright (c) 1999-2001 Philippe Troin
-;;  Copyright (c) 2002-2011 Amaury Darsch
+;;  Copyright (c) 2002-2013 Amaury Darsch
 
 (eval-when-compile 
   (require 'font-lock))
@@ -72,7 +72,7 @@
       (concat 
        "\\b\\("
        (mapconcat (lambda (x) x) 
-		  '("assert"  "block"   "class"   "const"   "daemon"  "delay"
+		  '("assert"  "block"   "class"   "const"   "delay"
 		    "do"      "else"    "enum"    "errorln" "eval"    "for"
                     "force"   "gamma"   "if"      "lambda"  "launch"  "loop"
                     "nameset" "println" "protect" "return"  "sync"    "switch"
