@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_BUILTIN_HPP
@@ -70,6 +70,8 @@ namespace afnix {
   Object* builtin_nilp    (Runnable* robj, Nameset* nset, Cons* args);
   Object* builtin_objp    (Runnable* robj, Nameset* nset, Cons* args);
   Object* builtin_evlp    (Runnable* robj, Nameset* nset, Cons* args);
+  Object* builtin_nblp    (Runnable* robj, Nameset* nset, Cons* args);
+  Object* builtin_cblp    (Runnable* robj, Nameset* nset, Cons* args);
   Object* builtin_lexp    (Runnable* robj, Nameset* nset, Cons* args);
   Object* builtin_symp    (Runnable* robj, Nameset* nset, Cons* args);
   Object* builtin_setp    (Runnable* robj, Nameset* nset, Cons* args);
