@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Set.hpp"
@@ -175,6 +175,7 @@ namespace afnix {
     interp->mkrsv ("nameset-p",      new Function (builtin_nstp));
     interp->mkrsv ("counter-p",      new Function (builtin_cntrp));
     interp->mkrsv ("message-p",      new Function (builtin_mesgp));
+    interp->mkrsv ("nameable-p",     new Function (builtin_nblp));
     interp->mkrsv ("instance-p",     new Function (builtin_instp));
     interp->mkrsv ("resolver-p",     new Function (builtin_rslvp));
     interp->mkrsv ("property-p",     new Function (builtin_propp));
@@ -182,6 +183,7 @@ namespace afnix {
     interp->mkrsv ("character-p",    new Function (builtin_charp));
     interp->mkrsv ("qualified-p",    new Function (builtin_qualp));
     interp->mkrsv ("librarian-p",    new Function (builtin_lbrnp));
+    interp->mkrsv ("collectable-p",  new Function (builtin_cblp));
     interp->mkrsv ("alias-table-p",  new Function (builtin_atblp));
     interp->mkrsv ("print-table-p",  new Function (builtin_ptblp));
     interp->mkrsv ("block-buffer-p", new Function (builtin_bbufp));
