@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Set.hpp"
@@ -103,7 +103,25 @@ namespace afnix {
       return new Boolean (false);
     }
   }
+  
+  // cblp: collectable predicate
 
+  Object* builtin_cblp (Runnable* robj, Nameset* nset, Cons* args) {
+    Object* obj = get_obj (robj, nset, args, "collectable-p");
+    bool result = (dynamic_cast <Collectable*> (obj) == nilp) ? false : true;
+    Object::cref (obj);
+    return new Boolean (result);
+  }
+  
+  // nblp: nameable predicate
+
+  Object* builtin_nblp (Runnable* robj, Nameset* nset, Cons* args) {
+    Object* obj = get_obj (robj, nset, args, "nameable-p");
+    bool result = (dynamic_cast <Nameable*> (obj) == nilp) ? false : true;
+    Object::cref (obj);
+    return new Boolean (result);
+  }
+  
   // symp: symbol predicate
 
   Object* builtin_symp (Runnable* robj, Nameset* nset, Cons* args) {
