@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Vector.hpp"
@@ -138,6 +138,46 @@ namespace afnix {
     return nilp;
   }
 
+  // -------------------------------------------------------------------------
+  // - public section                                                        -
+  // -------------------------------------------------------------------------
+
+  // get a stream by name locally or from the resolver
+  
+  InputStream* Resolver::tois (const String& name, Resolver* rslv) {
+    try {
+      // check locally
+      if (System::isfile (name) == true) return new InputFile(name);
+      // check with a resolver
+      return (rslv != nilp) ? rslv->get (name) : nilp;
+    } catch (...) {
+      return nilp;
+    }
+  }
+
+  // get a buffer by name locally or from the resolver
+
+  Buffer Resolver::tobuffer (const String& name, Resolver* rslv) {
+    InputStream* is = nilp;
+    try {
+      // get the stream by name
+      is = Resolver::tois (name, rslv);
+      if (is == nilp) return Buffer();
+      // consume the stream
+      long slen = (is == nilp) ? 0 : is->consume ();
+      // map to a buffer for compare
+      Buffer result = is->toibuf ();
+      if (result.length () != slen) {
+	throw Exception ("resolver-error", "inconsistent stream buffer size");
+      }
+      Object::dref (is);
+      return result;
+    } catch (...) {
+      Object::dref (is);
+      throw;
+    }
+  }
+  
   // -------------------------------------------------------------------------
   // - class section                                                         -
   // -------------------------------------------------------------------------
