@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_RESOLVER_HPP
@@ -34,6 +34,13 @@ namespace afnix {
   /// @author amaury darsch
 
   class Resolver : public Object {
+  public:
+    /// get an input stream locally or by the resolver
+    static InputStream* tois (const String& name, Resolver* rslv);
+
+    /// get a buffer locally or by the resolver
+    static Buffer tobuffer (const String& name, Resolver* rslv);
+    
   private:
     /// the list of path
     struct s_rpath* p_rpath;
