@@ -54,6 +54,7 @@
 #define AFNIX_PROCTYPE_MIPS64    14
 #define AFNIX_PROCTYPE_MIPS64EL  15
 #define AFNIX_PROCTYPE_PPC64EL   16
+#define AFNIX_PROCTYPE_AARCH64   17
 
 // recognized processor name
 #define AFNIX_PROCNAME_UNKNOWN   "unknown"
@@ -73,6 +74,7 @@
 #define AFNIX_PROCNAME_SH        "sh"
 #define AFNIX_PROCNAME_MIPS64    "mips64"
 #define AFNIX_PROCNAME_MIPS64EL  "mips64el"
+#define AFNIX_PROCNAME_AARCH64   "aarch64"
 
 // force size type with S390/clang
 #if defined(__s390__) || defined(__clang__)
@@ -128,6 +130,9 @@ static int get_procid (const char* proc) {
   // arm
   if (strcmp (proc, AFNIX_PROCNAME_ARM) == 0) 
     return AFNIX_PROCTYPE_ARM;
+  // aarch64
+  if (strcmp (proc, AFNIX_PROCNAME_AARCH64) == 0)
+    return AFNIX_PROCTYPE_AARCH64;
   // ppc
   if (strcmp (proc, AFNIX_PROCNAME_PPC) == 0) 
     return AFNIX_PROCTYPE_PPC;
@@ -183,6 +188,7 @@ static const char* get_procnm (const int id) {
   if (id ==  AFNIX_PROCTYPE_SPARC)    return AFNIX_PROCNAME_SPARC;
   if (id ==  AFNIX_PROCTYPE_ALPHA)    return AFNIX_PROCNAME_ALPHA;
   if (id ==  AFNIX_PROCTYPE_ARM)      return AFNIX_PROCNAME_ARM;
+  if (id ==  AFNIX_PROCTYPE_AARCH64)  return AFNIX_PROCNAME_AARCH64;
   if (id ==  AFNIX_PROCTYPE_PPC)      return AFNIX_PROCNAME_PPC;
   if (id ==  AFNIX_PROCTYPE_PPC64EL)  return AFNIX_PROCNAME_PPC64EL;
   if (id ==  AFNIX_PROCTYPE_M68K)     return AFNIX_PROCNAME_M68K;
@@ -331,6 +337,8 @@ int main (int, char**) {
 	   AFNIX_PROCTYPE_ALPHA);
   fprintf (stdout, "#define  AFNIX_PROCTYPE_ARM       %d\n",
 	   AFNIX_PROCTYPE_ARM);
+  fprintf (stdout, "#define  AFNIX_PROCTYPE_AARCH64   %d\n",
+           AFNIX_PROCTYPE_AARCH64);
   fprintf (stdout, "#define  AFNIX_PROCTYPE_PPC       %d\n",
 	   AFNIX_PROCTYPE_PPC);
   fprintf (stdout, "#define  AFNIX_PROCTYPE_PPC64EL   %d\n",
@@ -369,6 +377,8 @@ int main (int, char**) {
 	   AFNIX_PROCNAME_ALPHA);
   fprintf (stdout, "#define  AFNIX_PROCNAME_ARM       \"%s\"\n",
 	   AFNIX_PROCNAME_ARM);
+  fprintf (stdout, "#define  AFNIX_PROCNAME_AARCH64   \"%s\"\n",
+           AFNIX_PROCNAME_AARCH64);
   fprintf (stdout, "#define  AFNIX_PROCNAME_PPC       \"%s\"\n",
 	   AFNIX_PROCNAME_PPC);
   fprintf (stdout, "#define  AFNIX_PROCNAME_PPC64EL   \"%s\"\n",
