@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "cstr.hpp"
@@ -464,8 +464,18 @@ namespace afnix {
     // check for nil first
     if ((ptr == nilp) || (size <= 0)) return;
     // map the pointer and loop
-    t_byte* bptr = (t_byte*) ptr;
-    for (long k = 0; k < size; k++) bptr[k] = bval;
+    t_byte* pdst = (t_byte*) ptr;
+    for (long k = 0; k < size; k++) pdst[k] = bval;
+  }
+
+  // copy a memory block with a byte block
+
+  void c_memcpy (void* ptr, const long size, const t_byte* psrc) {
+    // check for nil first
+    if ((ptr == nilp) || (size <= 0) || (psrc == nilp)) return;
+    // map the pointer and loop
+    t_byte* pdst = (t_byte*) ptr;
+    for (long k = 0; k < size; k++) pdst[k] = psrc[k];
   }
 
   // map some memory with a file descriptor
