@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "cnet.hpp"
@@ -32,20 +32,33 @@ namespace afnix {
 
 #ifdef AFNIX_HAVE_CHAROPT
 namespace afnix {
+  // set a socket option
   static bool c_setsockopt (const int sid, const int level, const int optname,
 			    const void* optval, unsigned int optlen) {
     int result = setsockopt (sid, level, optname, (char*) optval, optlen);
     return (result == -1) ? false : true;
   }
+  // get a socket option
+  static bool c_getsockopt (const int sid, const int level, const int optname,
+			    void* optval, unsigned int& optlen) {
+    int result = getsockopt (sid, level, optname, (char*) optval, &optlen);
+    return (result == -1) ? false : true;
+  }
 }
 #else
 namespace afnix {
-  // set a simple socket option
+  // set a  socket option
   static bool c_setsockopt (const int sid, const int level, const int optname,
 			    const void* optval, unsigned int optlen) {
     int result = setsockopt (sid, level, optname, optval, optlen);
     return (result == -1) ? false : true;
   }
+  // get a  socket option
+  static bool c_getsockopt (const int sid, const int level, const int optname,
+			    void* optval, unsigned int& optlen) {
+    int result = getsockopt (sid, level, optname, optval, &optlen);
+    return (result == -1) ? false : true;
+  }
 }
 #endif
 
@@ -55,6 +68,7 @@ namespace afnix {
   static inline socklen_t get_addr_len (const int sid) {
     return c_isipv6 (sid) ? IP_ADDRLEN_6 : IP_ADDRLEN_4;
   }
+  
   // initialize an ip address with a port and type
   static void init_addr (t_sockaddr& addr, t_word port, bool flag) {
     if (flag == true) {
@@ -68,6 +82,7 @@ namespace afnix {
       addr.addr4.sin_addr.s_addr = 0;
     }     
   }
+  
   // fill an ip address from bytes
   static void byte_to_addr (t_sockaddr& addr, t_word port, const t_byte* src) {
     // check for ipv6
@@ -90,6 +105,7 @@ namespace afnix {
       addr.addr4.sin_addr.s_addr = value.d_qval;
     }    
   }
+  
   // map an ip address to bytes
   static t_byte* addr_to_byte (t_sockaddr& addr) {
     t_byte* result = nilp;
@@ -114,6 +130,7 @@ namespace afnix {
     }
     return result;
   }
+  
   // get an address port
   static t_word get_addr_port (t_sockaddr& addr) {
     t_word result = 0;
@@ -127,6 +144,7 @@ namespace afnix {
     }
     return result;
   }
+  
   // check for an ipv6 socket
   bool c_isipv6 (const int sid) {
     struct sockaddr address;
@@ -140,40 +158,34 @@ namespace afnix {
     if (address.sa_family == AF_INET6) return true;
     return false;
   }
+  
   // set socket option
-  bool c_ipsetopt (const int sid, t_sockopt opt, bool flag, long val) {
+  bool c_ipsetopt (const int sid, const t_sopt opt, const bool val) {
     // check for a valid socket
     if (sid == -1) return false;
     struct linger  lval;
-    int bval      = flag ? 1 : 0;
-    int ival      = val;
+    int bval      = val ? 1 : 0;
     lval.l_onoff  = bval;
-    lval.l_linger = ival;
+    lval.l_linger = 0;
     // dispatch ip independant options
     switch (opt) {
-    case SOCKET_REUSEADDR:
-      return c_setsockopt (sid, SOL_SOCKET, SO_REUSEADDR,&bval,sizeof (bval));
+    case SOPT_RADR:
+      return c_setsockopt (sid, SOL_SOCKET, SO_REUSEADDR, &bval, sizeof (bval));
       break;
-    case SOCKET_DONTROUTE:
-      return c_setsockopt (sid, SOL_SOCKET, SO_DONTROUTE,&bval,sizeof (bval));
+    case SOPT_RPRT:
+      return c_setsockopt (sid, SOL_SOCKET, SO_REUSEPORT, &bval, sizeof (bval));
       break;
-    case SOCKET_KEEPALIVE:
-      return c_setsockopt (sid, SOL_SOCKET, SO_KEEPALIVE,&bval,sizeof (bval));
+    case SOPT_DNTR:
+      return c_setsockopt (sid, SOL_SOCKET, SO_DONTROUTE, &bval, sizeof (bval));
       break;
-    case SOCKET_LINGER:
-      return c_setsockopt (sid, SOL_SOCKET, SO_LINGER,   &lval,sizeof (lval));
+    case SOPT_KLIV:
+      return c_setsockopt (sid, SOL_SOCKET, SO_KEEPALIVE, &bval, sizeof (bval));
       break;
-    case SOCKET_RCVSIZE:
-      return c_setsockopt (sid, SOL_SOCKET, SO_RCVBUF,   &ival,sizeof (ival));
+    case SOPT_LIGT:
+      return c_setsockopt (sid, SOL_SOCKET, SO_LINGER,    &lval, sizeof (lval));
       break;
-    case SOCKET_SNDSIZE:
-      return c_setsockopt (sid, SOL_SOCKET, SO_SNDBUF,   &ival,sizeof (ival));
-      break;
-    case  SOCKET_MAXSEG:
-      return c_setsockopt (sid, SOL_TCP,    TCP_MAXSEG,  &ival,sizeof (ival));
-      break;
-    case SOCKET_NODELAY:
-      return c_setsockopt (sid, SOL_TCP,    TCP_NODELAY, &bval,sizeof (bval));
+    case SOPT_NDLY:
+      return c_setsockopt (sid, SOL_TCP,    TCP_NODELAY,  &bval, sizeof (bval));
       break;
     default:
       break;
@@ -181,15 +193,131 @@ namespace afnix {
     // dispatch between ipv6 and ipv4
     if (c_isipv6 (sid) == true) {
       switch (opt) {
-      case SOCKET_HOPLIMIT:
-	return c_setsockopt (sid, SOL_IPV6, IPV6_UNICAST_HOPS, &ival, 
-			     sizeof (ival));
-	break;
-      case SOCKET_MCASTLOOP:
+      case SOPT_MLBK:
 	return c_setsockopt (sid, SOL_IPV6, IPV6_MULTICAST_LOOP, &bval, 
 			     sizeof (bval));
 	break;
-      case SOCKET_MCASTHOP:
+      default:
+	break;
+      }
+    } else {
+      switch (opt) {
+      case SOPT_BCST:
+	return c_setsockopt (sid, SOL_SOCKET, SO_BROADCAST,&bval,
+			     sizeof (bval));
+	break;
+      case SOPT_MLBK:
+	return c_setsockopt (sid, SOL_IP, IP_MULTICAST_LOOP, &bval, 
+			     sizeof (bval));
+	break;
+      default:
+	break;
+      }
+    }
+    return false;
+  }
+
+  // get socket option
+  bool c_ipgetopt (const int sid, const t_sopt opt, bool& val) {
+    // check for a valid socket
+    if (sid == -1) return false;
+    int bval = 0;
+    unsigned int blen = sizeof (bval);
+    struct linger lval;
+    lval.l_onoff  = 0;
+    lval.l_linger = 0;
+    // dispatch ip independant options
+    bool result = false;
+    switch (opt) {
+    case SOPT_RADR:
+      result =  c_getsockopt (sid, SOL_SOCKET, SO_REUSEADDR, &bval, blen);
+      if (blen == 0) bval = 0;
+      break;
+    case SOPT_RPRT:
+      result =  c_getsockopt (sid, SOL_SOCKET, SO_REUSEPORT, &bval, blen);
+      if (blen == 0) bval = 0;
+      break;
+    case SOPT_DNTR:
+      result = c_getsockopt (sid, SOL_SOCKET, SO_DONTROUTE, &bval, blen);
+      if (blen == 0) bval = 0;
+      break;
+    case SOPT_KLIV:
+      result = c_getsockopt (sid, SOL_SOCKET, SO_KEEPALIVE, &bval, blen);
+      if (blen == 0) bval = 0;
+      break;
+    case SOPT_LIGT:
+      blen = sizeof (lval);
+      result = c_getsockopt (sid, SOL_SOCKET, SO_LINGER, &lval, blen);
+      bval = (blen == 0) ? 0 : lval.l_onoff;
+      break;
+    case SOPT_NDLY:
+      result = c_getsockopt (sid, SOL_TCP, TCP_NODELAY, &bval, blen);
+      if (blen == 0) bval = 0;
+      break;
+    default:
+      break;
+    }
+    // dispatch between ipv6 and ipv4
+    if (c_isipv6 (sid) == true) {
+      switch (opt) {
+      case SOPT_MLBK:
+	result = c_getsockopt (sid, SOL_IPV6, IPV6_MULTICAST_LOOP,&bval,blen); 
+	if (blen == 0) bval = 0;
+	break;
+      default:
+	break;
+      }
+    } else {
+      switch (opt) {
+      case SOPT_BCST:
+	result = c_getsockopt (sid, SOL_SOCKET, SO_BROADCAST, &bval, blen);
+	if (blen == 0) bval = 0;
+	break;
+      case SOPT_MLBK:
+	result = c_getsockopt (sid, SOL_IP, IP_MULTICAST_LOOP, &bval, blen);
+	if (blen == 0) bval = 0;
+	break;
+      default:
+	break;
+      }
+    }
+    val = (bval == 0) ? false : true;
+    return result;
+  }
+  
+  // set socket option
+  bool c_ipsetopt (const int sid, const t_sopt opt, const long val) {
+    // check for a valid socket
+    if (sid == -1) return false;
+    struct linger  lval;
+    int ival      = val;
+    lval.l_onoff  = 1;
+    lval.l_linger = ival;
+    // dispatch ip independant options
+    switch (opt) {
+    case SOPT_LIGT:
+      return c_setsockopt (sid, SOL_SOCKET, SO_LINGER,   &lval, sizeof (lval));
+      break;
+    case SOPT_RSIZ:
+      return c_setsockopt (sid, SOL_SOCKET, SO_RCVBUF,   &ival, sizeof (ival));
+      break;
+    case SOPT_SSIZ:
+      return c_setsockopt (sid, SOL_SOCKET, SO_SNDBUF,   &ival, sizeof (ival));
+      break;
+    case SOPT_MSIZ:
+      return c_setsockopt (sid, SOL_TCP,    TCP_MAXSEG,  &ival, sizeof (ival));
+      break;
+    default:
+      break;
+    }
+    // dispatch between ipv6 and ipv4
+    if (c_isipv6 (sid) == true) {
+      switch (opt) {
+      case SOPT_SHOP:
+	return c_setsockopt (sid, SOL_IPV6, IPV6_UNICAST_HOPS, &ival, 
+			     sizeof (ival));
+	break;
+      case SOPT_MHOP:
 	return c_setsockopt (sid, SOL_IPV6, IPV6_MULTICAST_HOPS, &ival, 
 			     sizeof (ival));
 	break;
@@ -198,18 +326,10 @@ namespace afnix {
       }
     } else {
       switch (opt) {
-      case SOCKET_BROADCAST:
-	return c_setsockopt (sid, SOL_SOCKET, SO_BROADCAST,&bval,
-			     sizeof (bval));
-	break;
-      case SOCKET_HOPLIMIT:
+      case SOPT_SHOP:
 	return c_setsockopt (sid, SOL_IP, IP_TTL, &ival, sizeof (ival));
 	break;
-      case SOCKET_MCASTLOOP:
-	return c_setsockopt (sid, SOL_IP, IP_MULTICAST_LOOP, &bval, 
-			     sizeof (bval));
-	break;
-      case SOCKET_MCASTHOP:
+      case SOPT_MHOP:
 	return c_setsockopt (sid, SOL_IP, IP_MULTICAST_TTL, &ival, 
 			     sizeof (ival));
 	break;
@@ -219,6 +339,70 @@ namespace afnix {
     }
     return false;
   }
+
+  // get socket option
+  bool c_ipgetopt (const int sid, const t_sopt opt, long& val) {
+    // check for a valid socket
+    if (sid == -1) return false;
+    int ival = 0;
+    unsigned int ilen = sizeof (ival);
+    struct linger lval;
+    lval.l_onoff  = 0;
+    lval.l_linger = 0;
+    // dispatch ip independant options
+    bool result = false;
+    switch (opt) {
+    case SOPT_LIGT:
+      ilen = sizeof (lval);
+      result = c_getsockopt (sid, SOL_SOCKET, SO_LINGER, &lval, ilen);
+      ival = (ilen == 0) ? 0 : lval.l_linger;
+      break;
+    case SOPT_RSIZ:
+      result = c_getsockopt (sid, SOL_SOCKET, SO_RCVBUF, &ival, ilen);
+      if (ilen == 0) ival = 0;
+      break;
+    case SOPT_SSIZ:
+      result = c_getsockopt (sid, SOL_SOCKET, SO_SNDBUF, &ival, ilen);
+      if (ilen == 0) ival = 0;
+      break;
+    case SOPT_MSIZ:
+      result = c_getsockopt (sid, SOL_TCP, TCP_MAXSEG,   &ival, ilen);
+      if (ilen == 0) ival = 0;
+      break;
+    default:
+      break;
+    }
+    // dispatch between ipv6 and ipv4
+    if (c_isipv6 (sid) == true) {
+      switch (opt) {
+      case SOPT_SHOP:
+	result = c_getsockopt (sid, SOL_IPV6, IPV6_UNICAST_HOPS, &ival, ilen);
+	if (ilen == 0) ival = 0;
+	break;
+      case SOPT_MHOP:
+	result = c_getsockopt (sid, SOL_IPV6, IPV6_MULTICAST_HOPS,&ival,ilen); 
+	if (ilen == 0) ival = 0;
+	break;
+      default:
+	break;
+      }
+    } else {
+      switch (opt) {
+      case SOPT_SHOP:
+	result = c_getsockopt (sid, SOL_IP, IP_TTL, &ival, ilen);
+	if (ilen == 0) ival = 0;
+	break;
+      case SOPT_MHOP:
+	return c_getsockopt (sid, SOL_IP, IP_MULTICAST_TTL, &ival, ilen);
+	if (ilen == 0) ival = 0;
+	break;
+      default:
+	break;
+      }
+    }
+    val = ival;
+    return result;
+  }
 }
 #else
 namespace afnix {
@@ -272,64 +456,180 @@ namespace afnix {
     }
     return result;
   }
+
   // check for an ipv6 socket - always return false here
   bool c_isipv6 (const int) {
     return false;
   }
+  
   // set socket option
-  bool c_ipsetopt (const int sid, t_sockopt opt, bool flag, long val) {
+  bool c_ipsetopt (const int sid, const t_sopt opt, const bool val) {
     // check for a valid socket
     if (sid == -1) return false;
     struct linger  lval;
-    int bval      = flag ? 1 : 0;
-    int ival      = val;
+    int bval      = val ? 1 : 0;
     lval.l_onoff  = bval;
-    lval.l_linger = ival;
+    lval.l_linger = 0;
     // dispatch ip independant options
     switch (opt) {
-    case SOCKET_REUSEADDR:
-      return c_setsockopt (sid, SOL_SOCKET, SO_REUSEADDR,&bval,sizeof (bval));
+    case SOPT_RADR:
+      return c_setsockopt (sid, SOL_SOCKET, SO_REUSEADDR, &bval, sizeof (bval));
       break;
-    case SOCKET_BROADCAST:
-      return c_setsockopt (sid, SOL_SOCKET, SO_BROADCAST,&bval,sizeof (bval));
+    case SOPT_RPRT:
+      return c_setsockopt (sid, SOL_SOCKET, SO_REUSEPORT, &bval, sizeof (bval));
       break;
-    case SOCKET_DONTROUTE:
-      return c_setsockopt (sid, SOL_SOCKET, SO_DONTROUTE,&bval,sizeof (bval));
+    case SOPT_BCST:
+      return c_setsockopt (sid, SOL_SOCKET, SO_BROADCAST, &bval, sizeof (bval));
       break;
-    case SOCKET_KEEPALIVE:
-      return c_setsockopt (sid, SOL_SOCKET, SO_KEEPALIVE,&bval,sizeof (bval));
+    case SOPT_DNTR:
+      return c_setsockopt (sid, SOL_SOCKET, SO_DONTROUTE, &bval, sizeof (bval));
       break;
-    case SOCKET_LINGER:
-      return c_setsockopt (sid, SOL_SOCKET, SO_LINGER,   &lval,sizeof (lval));
+    case SOPT_KLIV:
+      return c_setsockopt (sid, SOL_SOCKET, SO_KEEPALIVE, &bval, sizeof (bval));
       break;
-    case SOCKET_RCVSIZE:
-      return c_setsockopt (sid, SOL_SOCKET, SO_RCVBUF,   &ival,sizeof (ival));
+    case SOPT_LIGT:
+      return c_setsockopt (sid, SOL_SOCKET, SO_LINGER,    &lval, sizeof (lval));
       break;
-    case SOCKET_SNDSIZE:
-      return c_setsockopt (sid, SOL_SOCKET, SO_SNDBUF,   &ival,sizeof (ival));
+    case SOPT_NDLY:
+      return c_setsockopt (sid, SOL_TCP,    TCP_NODELAY,  &bval, sizeof (bval));
       break;
-    case  SOCKET_MAXSEG:
-      return c_setsockopt (sid, SOL_TCP,    TCP_MAXSEG,  &ival,sizeof (ival));
-      break;
-    case SOCKET_NODELAY:
-      return c_setsockopt (sid, SOL_TCP,    TCP_NODELAY, &bval,sizeof (bval));
-      break;
-    case SOCKET_HOPLIMIT:
-      return c_setsockopt (sid, SOL_IP,     IP_TTL,      &ival,sizeof (ival));
-      break;
-    case SOCKET_MCASTLOOP:
-      return c_setsockopt (sid, SOL_IP,     IP_MULTICAST_LOOP, &bval, 
-			   sizeof (bval));
-      break;
-    case SOCKET_MCASTHOP:
-      return c_setsockopt (sid, SOL_IP,     IP_MULTICAST_TTL,  &ival, 
-			   sizeof (ival));
+    case SOPT_MLBK:
+      return c_setsockopt (sid, SOL_IP, IP_MULTICAST_LOOP,&bval, sizeof (bval));
       break;
     default:
       break;
     }
     return false;
   }
+
+  // get socket option
+  bool c_ipgetopt (const int sid, const t_sopt opt, bool& val) {
+    // check for a valid socket
+    if (sid == -1) return false;
+    int bval = 0;
+    unsigned int blen = sizeof (bval);
+    struct linger lval;
+    lval.l_onoff  = 0;
+    lval.l_linger = 0;
+    // dispatch ip independant options
+    bool result = false;
+    switch (opt) {
+    case SOPT_RADR:
+      result =  c_getsockopt (sid, SOL_SOCKET, SO_REUSEADDR, &bval, blen);
+      if (blen == 0) bval = 0;
+      break;
+    case SOPT_RPRT:
+      result =  c_getsockopt (sid, SOL_SOCKET, SO_REUSEPORT, &bval, blen);
+      if (blen == 0) bval = 0;
+      break;
+    case SOPT_BCST:
+      result = c_getsockopt (sid, SOL_SOCKET, SO_BROADCAST, &bval, blen);
+      if (blen == 0) bval = 0;
+      break;
+    case SOPT_DNTR:
+      result = c_getsockopt (sid, SOL_SOCKET, SO_DONTROUTE, &bval, blen);
+      if (blen == 0) bval = 0;
+      break;
+    case SOPT_KLIV:
+      result = c_getsockopt (sid, SOL_SOCKET, SO_KEEPALIVE, &bval, blen);
+      if (blen == 0) bval = 0;
+      break;
+    case SOPT_LIGT:
+      blen = sizeof (lval);
+      result = c_getsockopt (sid, SOL_SOCKET, SO_LINGER, &lval, blen);
+      bval = (blen == 0) ? 0 : lval.l_onoff;
+      break;
+    case SOPT_NDLY:
+      result = c_getsockopt (sid, SOL_TCP, TCP_NODELAY, &bval, blen);
+      if (blen == 0) bval = 0;
+      break;
+    case SOPT_MLBK:
+      result = c_getsockopt (sid, SOL_IP, IP_MULTICAST_LOOP, &bval, blen);
+      if (blen == 0) bval = 0;
+    default:
+      break;
+    }
+    val = (bval == 0) ? false : true;
+    return result;
+  }
+  
+  // set socket option
+  bool c_ipsetopt (const int sid, const t_sopt opt, const long val) {
+    // check for a valid socket
+    if (sid == -1) return false;
+    struct linger  lval;
+    int ival      = val;
+    lval.l_onoff  = 1;
+    lval.l_linger = ival;
+    // dispatch ip independant options
+    switch (opt) {
+    case SOPT_LIGT:
+      return c_setsockopt (sid, SOL_SOCKET, SO_LINGER,   &lval, sizeof (lval));
+      break;
+    case SOPT_RSIZ:
+      return c_setsockopt (sid, SOL_SOCKET, SO_RCVBUF,   &ival, sizeof (ival));
+      break;
+    case SOPT_SSIZ:
+      return c_setsockopt (sid, SOL_SOCKET, SO_SNDBUF,   &ival, sizeof (ival));
+      break;
+    case SOPT_MSIZ:
+      return c_setsockopt (sid, SOL_TCP,    TCP_MAXSEG,  &ival, sizeof (ival));
+      break;
+    case SOPT_SHOP:
+      return c_setsockopt (sid, SOL_IP,     IP_TTL,      &ival, sizeof (ival));
+      break;
+    case SOPT_MHOP:
+      return c_setsockopt (sid, SOL_IP, IP_MULTICAST_TTL,&ival, sizeof (ival));
+      break;
+    default:
+      break;
+    }
+    return false;
+  }
+  
+  // get socket option
+  bool c_ipgetopt (const int sid, const t_sopt opt, long& val) {
+    // check for a valid socket
+    if (sid == -1) return false;
+    int ival = 0;
+    unsigned int ilen = sizeof (ival);
+    struct linger lval;
+    lval.l_onoff  = 0;
+    lval.l_linger = 0;
+    // dispatch ip independant options
+    bool result = false;
+    switch (opt) {
+    case SOPT_LIGT:
+      ilen = sizeof (lval);
+      result = c_getsockopt (sid, SOL_SOCKET, SO_LINGER, &lval, ilen);
+      ival = (ilen == 0) ? 0 : lval.l_linger;
+      break;
+    case SOPT_RSIZ:
+      result = c_getsockopt (sid, SOL_SOCKET, SO_RCVBUF, &ival, ilen);
+      if (ilen == 0) ival = 0;
+      break;
+    case SOPT_SSIZ:
+      result = c_getsockopt (sid, SOL_SOCKET, SO_SNDBUF, &ival, ilen);
+      if (ilen == 0) ival = 0;
+      break;
+    case SOPT_MSIZ:
+      result = c_getsockopt (sid, SOL_TCP, TCP_MAXSEG,   &ival, ilen);
+      if (ilen == 0) ival = 0;
+      break;
+    case SOPT_SHOP:
+      result = c_getsockopt (sid, SOL_IP, IP_TTL, &ival, ilen);
+      if (ilen == 0) ival = 0;
+      break;
+    case SOPT_MHOP:
+      return c_getsockopt (sid, SOL_IP, IP_MULTICAST_TTL, &ival, ilen);
+      if (ilen == 0) ival = 0;
+      break;
+    default:
+      break;
+    }
+    val = ival;
+    return result;
+  }
 }
 #endif
 
@@ -848,17 +1148,17 @@ namespace afnix {
 
   // shutdown a socket
 
-  bool c_ipshut (const int sid, t_shut how) {
+  bool c_ipshut (const int sid, const t_shut how) {
     bool status = false;
     if (sid == -1) return false;
     switch (sid) {
-    case SOCKET_SHUT_BOTH:
+    case SHUT_BOTH:
       status = (shutdown (sid, 2) == 0) ? true : false;
       break;
-    case SOCKET_SHUT_RECV:
+    case SHUT_RECV:
       status = (shutdown (sid, 0) == 0) ? true : false;
       break;
-    case SOCKET_SHUT_SEND:
+    case SHUT_SEND:
       status = (shutdown (sid, 1) == 0) ? true : false;
       break;
     }
