@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_CNET_HPP
@@ -30,25 +30,26 @@ namespace afnix {
 
   /// the shutdown mode
   enum t_shut {
-    SOCKET_SHUT_BOTH, //shutdown both directions
-    SOCKET_SHUT_RECV, // shutdown reception
-    SOCKET_SHUT_SEND  // shutdown emission
+    SHUT_BOTH, //shutdown both directions
+    SHUT_RECV, // shutdown reception
+    SHUT_SEND  // shutdown emission
   };
 
   /// the supported socket options
-  enum t_sockopt {
-    SOCKET_REUSEADDR, // reuse address
-    SOCKET_BROADCAST, // enable packet broadcast
-    SOCKET_DONTROUTE, // bypass routing table
-    SOCKET_KEEPALIVE, // set connection test
-    SOCKET_LINGER,    // set linger time
-    SOCKET_RCVSIZE,   // receive buffer size
-    SOCKET_SNDSIZE,   // send buffer size
-    SOCKET_HOPLIMIT,  // set hop limit
-    SOCKET_MCASTLOOP, // multicast use lopback
-    SOCKET_MCASTHOP,  // multicast hop limit
-    SOCKET_MAXSEG,    // tcp maximum segment size
-    SOCKET_NODELAY    // disable naggle algorithm
+  enum t_sopt {
+    SOPT_RADR, // reuse address
+    SOPT_RPRT, // reuse address
+    SOPT_BCST, // enable packet broadcast
+    SOPT_DNTR, // bypass routing table
+    SOPT_KLIV, // set connection test
+    SOPT_LIGT, // set linger time
+    SOPT_RSIZ, // receive buffer size
+    SOPT_SSIZ, // send buffer size
+    SOPT_SHOP, // socket hop limit
+    SOPT_MLBK, // multicast use loopback
+    SOPT_MHOP, // multicast hop limit
+    SOPT_MSIZ, // tcp maximum segment size
+    SOPT_NDLY  // disable naggle algorithm
   };
 
   /// the ip address structure
@@ -77,16 +78,33 @@ namespace afnix {
   };
 
   /// set a socket option
-  /// @param int  sid the socket id
-  /// @param opt  the option to set
-  /// @param flag the option flag
-  /// @param val  the option value
-  bool c_ipsetopt (const int sid, t_sockopt opt, bool flag, long val);
+  /// @param sid the socket id
+  /// @param opt the option to set
+  /// @param val the option flag
+  bool c_ipsetopt (const int sid, const t_sopt sopt, const bool val);
+
+  /// get a socket option
+  /// @param sid the socket id
+  /// @param opt the option to set
+  /// @param val the option flag
+  bool c_ipgetopt (const int sid, const t_sopt sopt, bool& val);
+
+  /// set a socket option by value
+  /// @param int sid the socket id
+  /// @param opt the option to set
+  /// @param val the option value
+  bool c_ipsetopt (const int sid, const t_sopt opt, const long val);
+
+  /// get a socket option by value
+  /// @param int sid the socket id
+  /// @param opt the option to set
+  /// @param val the option value
+  bool c_ipgetopt (const int sid, const t_sopt opt, long& val);
 
   /// shutdown a socket connection
   /// @param sid the socket id
   /// @param how the shutdown mode
-  bool c_ipshut (const int sid, t_shut how);
+  bool c_ipshut (const int sid, const t_shut how);
 
   /// @return the loopback name
   const char* c_loopname (void);
