@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_CSHL_HPP
@@ -31,15 +31,17 @@ namespace afnix {
   /// @return the main program as a dynamic library
   void* c_dlmain (void);
 
-  /// @param  the library name.
-  /// @return a library descriptor suitable for query.
-  void* c_dlopen (const char* name);
- 
   /// open a dynamic library by name.
-  /// @param  the library name.
+  /// @param name the library name.
   /// @return a library descriptor suitable for query.
   void* c_dlopen (const char* name);
   
+  /// open a dynamic library by prefix and name.
+  /// @param pfix the library prefix.
+  /// @param name the library name.
+  /// @return a library descriptor suitable for query.
+  void* c_dlopen (const char* pfix, const char* name);
+  
   /// query a symbol by name, using a library descriptor.
   /// @param name the symbol name
   /// @param lptr the library descriptor
