@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "cstr.hpp"
@@ -245,6 +245,13 @@ namespace afnix {
     return (result == -1) ? c_errmap (errno) : result;
   }
 
+  // duplicate a stream id.
+
+  int c_dup (const int sid) {
+    if (sid < 0) return -1;
+    return dup (sid);
+  }
+
   // close this stream.
 
   bool c_close (const int sid) {
