@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_CSIO_HPP
@@ -101,6 +101,10 @@ namespace afnix {
   /// @return the number of character writen or an error code
   t_long c_write (const int sid, const char* buffer, const t_long count);
 
+  /// duplicate a stream id
+  /// @param sid the stream id
+  int c_dup (const int sid);
+  
   /// close this stream. 
   /// @param sid the stream id
   bool c_close (const int sid);
