@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "cstr.hpp"
@@ -157,6 +157,19 @@ namespace afnix {
     return result;
   }
 
+  // find a string niside a string
+
+  const char* c_strstr (const char* src, const char* str) {
+    // check for nil
+    if ((str == nilp) || (*str == nilc)) return src;
+    if ((src == nilp) || (*src == nilc)) return nilp;
+    // compare at position
+    if ((*src == *str) && (c_strstr (src+1,str+1) == src+1)) {
+      return src;
+    }
+    return c_strstr (src+1, str);
+  }
+  
   // remove the leading blank from a string and return a new string
 
   char* c_rmlead (const char* s) {
