@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_CSTR_HPP
@@ -86,6 +86,11 @@ namespace afnix {
   /// @param src the source string
   /// @param max the maximum length
   char* c_strtrc (const char* src, const long max);
+
+  /// find a string inside a string
+  /// @param src the source haystack
+  /// @param str the needle string
+  const char* c_strstr (const char* src, const char* str);
   
   /// remove the leading blank and tab and return a new string
   /// @param the original string
