@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_CUCD_HPP
@@ -34,8 +34,8 @@ namespace afnix {
   // -------------------------------------------------------------------------
 
   /// the ucd version
-  const t_byte UCD_MAJOR   = 6;
-  const t_byte UCD_MINOR   = 3;
+  const t_byte UCD_MAJOR   = 9;
+  const t_byte UCD_MINOR   = 0;
   const t_byte UCD_PATCH   = 0;
 
   /// general category value
@@ -130,7 +130,7 @@ namespace afnix {
   const long UCD_TCM_MAX = 3;
 
   /// the ucd structure 
-  struct ucd_s {
+  struct s_cucd {
     t_quad      d_code; // code point value           
     const char* p_name; // code point name            
     t_byte      d_pgcv; // general category value     
@@ -152,10 +152,10 @@ namespace afnix {
   const long c_ucdpsize (const long index);
 
   /// @return a plane array by plane index
-  const ucd_s* c_ucdplane (const long index);
+  const s_cucd* c_ucdplane (const long index);
 
   /// @return a ucd structure by code point
-  const ucd_s* c_getucd (const t_quad code);
+  const s_cucd* c_getcucd (const t_quad code);
 
   /// perform a normal form decomposition (canonical)
   /// @param dst  the destination buffer
