@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "cstr.hpp"
@@ -56,6 +56,14 @@ int main (int, char**) {
   if (c_strcmp (hello,data) == false) return 1;
   delete [] data;
 
+  const char* src = "hello world";
+  const char* hs = c_strstr (src, "hello");
+  if (hs != src) return 1;
+  const char* ws = c_strstr (src, "world");
+  if (ws != &src[6]) return 1;
+  const char* gs = c_strstr (src, "afnix");
+  if (gs != nilp) return 1;
+  
   // here we are saved - what an accomplishment !!!
   return 0;
 }
