@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "cucd.hpp"
@@ -27,7 +27,7 @@ namespace afnix {
   static bool ucd_check_plane (const long index) {
     // get the plane size and data
     const long   psize = c_ucdpsize (index);
-    const ucd_s* plane = c_ucdplane (index);
+    const s_cucd* plane = c_ucdplane (index);
     // compute start and end
     t_quad psi = (((t_quad) index) << 16) & 0xFFFF0000;
     t_quad pei = psi + 0x0000FFFF;
@@ -49,7 +49,7 @@ namespace afnix {
   static bool ucd_check_point (const long index) {
     for (long i = 0; i < 65536; i++) {
       t_quad code = (t_quad) ((index << 16) + i);
-      const ucd_s* ucd = c_getucd (code);
+      const s_cucd* ucd = c_getcucd (code);
       if (ucd == nilp) continue;
       if (ucd->d_code != code) return false;
     }
