@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Byte.hpp"
@@ -71,6 +71,7 @@ namespace afnix {
     p_data = new char [d_size];
     d_blen = 0;
     d_rflg = true;
+    d_pflg = false;
     d_emod = Encoding::BYTE;
   }
 
@@ -81,6 +82,7 @@ namespace afnix {
     p_data = new char[d_size];
     d_blen = 0;
     d_rflg = true;
+    d_pflg = false;
     d_emod = Encoding::BYTE;
   }
 
@@ -91,6 +93,7 @@ namespace afnix {
     p_data = new char[d_size];
     d_blen = 0;
     d_rflg = true;
+    d_pflg = false;
     d_emod = emod;
   }
 
@@ -101,6 +104,7 @@ namespace afnix {
     p_data = new char[d_size];
     d_blen = 0;
     d_rflg = true;
+    d_pflg = false;
     d_emod = emod;
   }
 
@@ -111,6 +115,7 @@ namespace afnix {
     p_data = new char[d_size];
     d_blen = 0;
     d_rflg = true;
+    d_pflg = false;
     d_emod = Encoding::UTF8;
     add (value, Ascii::strlen (value));
   }
@@ -122,6 +127,7 @@ namespace afnix {
     p_data = new char[d_size];
     d_blen = 0;
     d_rflg = true;
+    d_pflg = false;
     d_emod = Encoding::UTF8;
     add (value);
   }
@@ -133,6 +139,7 @@ namespace afnix {
     d_blen = blen;
     p_data = data;
     d_rflg = false;
+    d_pflg = true;
     d_emod = Encoding::BYTE;
   }
 
@@ -144,6 +151,7 @@ namespace afnix {
       d_size = that.d_size;
       d_blen = 0;
       d_rflg = that.d_rflg;
+      d_pflg = false;
       d_emod = that.d_emod;
       p_data = new char[d_size];
       add (that.p_data, that.d_blen);
@@ -157,7 +165,7 @@ namespace afnix {
   // destroy this buffer
   
   Buffer::~Buffer (void) {
-    delete [] p_data;
+    if (d_pflg == false) delete [] p_data;
   }
 
   // assign a buffer to this one
@@ -174,6 +182,7 @@ namespace afnix {
       // add the new data
       d_size = that.d_size;
       d_rflg = that.d_rflg;
+      d_pflg = false;
       d_emod = that.d_emod;
       p_data = new char[d_size];
       add (that.p_data, that.d_blen);
@@ -1135,6 +1144,23 @@ namespace afnix {
     }
   }
 
+  // add a word in host format to this buffer
+
+  void Buffer::addhw (const t_word wval) {
+    wrlock ();
+    try {
+      // convert the word in network format
+      t_byte buf[2];
+      c_whton (wval, buf);
+      // add the byte array to the buffer
+      add ((const char*) &buf[0], 2);
+      unlock ();
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // get a word in host format from this buffer
 
   t_word Buffer::gethw (void) {
@@ -1157,6 +1183,23 @@ namespace afnix {
     }
   }
 
+  // add a quad in host format to this buffer
+
+  void Buffer::addhq (const t_quad qval) {
+    wrlock ();
+    try {
+      // convert the quad in network format
+      t_byte buf[4];
+      c_qhton (qval, buf);
+      // add the byte array to the buffer
+      add ((const char*) &buf[0], 4);
+      unlock ();
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // get a quad in host format from this buffer
 
   t_quad Buffer::gethq (void) {
@@ -1179,6 +1222,23 @@ namespace afnix {
     }
   }
 
+  // add an octa in host format to this buffer
+
+  void Buffer::addho (const t_octa oval) {
+    wrlock ();
+    try {
+      // convert the octa in network format
+      t_byte buf[8];
+      c_ohton (oval, buf);
+      // add the byte array to the buffer
+      add ((const char*) &buf[0], 8);
+      unlock ();
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // get an octa in host format from this buffer
 
   t_octa Buffer::getho (void) {
