@@ -11,10 +11,11 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Vector.hpp"
+#include "Central.hpp"
 #include "QuarkZone.hpp"
 #include "Collectable.hpp"
 
@@ -27,12 +28,13 @@ namespace afnix {
   // create a collectable object
 
   Collectable::Collectable (void) {
-    p_cptr = nilp;
+    p_cptr = Central::confine (this);
   }
 
   // destroy this object
 
   Collectable::~Collectable (void) {
+    Central::untangle (this, p_cptr);
   }
 
   // -------------------------------------------------------------------------
