@@ -11,13 +11,12 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Cons.hpp"
 #include "Stdsid.hxx"
 #include "Vector.hpp"
-#include "Central.hpp"
 #include "Boolean.hpp"
 #include "Integer.hpp"
 #include "Runnable.hpp"
@@ -44,7 +43,6 @@ namespace afnix {
   // create a new cons cell initialized to nil
 
   Cons::Cons (void) {
-    p_cptr = Central::confine (this);
     d_type = Cons::NORMAL;
     p_car  = nilp;
     p_cdr  = nilp;
@@ -55,7 +53,6 @@ namespace afnix {
   // create a new cons cell with a type
 
   Cons::Cons (t_type type) {
-    p_cptr = Central::confine (this);
     d_type = type;
     p_car  = nilp;
     p_cdr  = nilp;
@@ -66,7 +63,6 @@ namespace afnix {
   // create a new cons cell with a car
 
   Cons::Cons (Object* car) {
-    p_cptr = Central::confine (this);
     d_type = Cons::NORMAL;
     p_car  = Object::iref (car);
     p_cdr  = nilp;
@@ -77,7 +73,6 @@ namespace afnix {
   // create a new cons cell with a type and a car
 
   Cons::Cons (t_type type, Object* car) {
-    p_cptr = Central::confine (this);
     d_type = type;
     p_car  = Object::iref (car);
     p_cdr  = nilp;
@@ -90,7 +85,6 @@ namespace afnix {
   Cons::Cons (const Cons& that) {
     that.rdlock ();
     try {
-      p_cptr = Central::confine (this);
       d_type = that.d_type;
       Object::iref (p_car = that.p_car);
       Object::iref (p_cdr = that.p_cdr);
@@ -109,7 +103,6 @@ namespace afnix {
     delete p_mon;
     Object::dref (p_car);
     Object::dref (p_cdr);
-    Central::untangle (this, p_cptr);
   }
 
   // return the class name
