@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Vector.hpp"
@@ -572,6 +572,21 @@ namespace afnix {
       throw;
     }
   }
+
+  // get a copy of the input buffer
+
+  Buffer InputBound::toibuf (void) const {
+    rdlock ();
+    try {
+      Buffer result;
+      if (p_is != nilp) result = p_is->toibuf ();
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
   
   // return a string representation of the input buffer
 
