@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Ascii.hpp"
@@ -168,7 +168,21 @@ namespace afnix {
       throw;
     }
   }
+  
+  // get a copy of the input buffer
 
+  Buffer InputBuffer::toibuf (void) const {
+    rdlock ();
+    try {
+      Buffer result = d_sbuf;
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // return a string representation of the stream buffer
 
   String InputBuffer::tostring (void) const {
