@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_INPUTBUFFER_HPP
@@ -73,6 +73,9 @@ namespace afnix {
     /// @return the size of the input buffer
     long buflen (void) const;
 
+    /// @return a copy if the input buffer
+    Buffer toibuf (void) const;
+    
     /// @return a string representation of the input buffer
     String tostring (void) const;
   };
