@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_INPUTSTREAM_HPP
@@ -84,6 +84,9 @@ namespace afnix {
     /// @return the size of the input buffer
     virtual long buflen (void) const =0;
 
+    /// @return a copy if the input buffer
+    virtual Buffer toibuf (void) const =0;
+    
     /// @return a string representation of the input buffer
     virtual String tostring (void) const =0;
 
