@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Cons.hpp"
@@ -150,7 +150,7 @@ namespace afnix {
   bool Object::uref (Object* object) {
     // check for nil first
     s_oacs* axs = (object == nilp) ? nilp : object->p_oacs;
-    if (axs == nilp) return false;
+    if (axs == nilp) return true;
     // lock and reference
     axs->d_rmon.enter ();
     bool result = (axs->d_rcnt <= 1);
