@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Ascii.hpp"
@@ -183,13 +183,6 @@ namespace afnix {
   // - object section                                                        -
   // -------------------------------------------------------------------------
 
-  // the quark zone
-  static const long QUARK_ZONE_LENGTH = 1;
-  static QuarkZone  zone (QUARK_ZONE_LENGTH);
-
-  // the object supported quarks
-  static const long QUARK_CLOSE   = zone.intern ("close");
-
   // create a new object in a generic way
 
   Object* OutputFile::mknew (Vector* argv) {
@@ -220,32 +213,25 @@ namespace afnix {
 
   bool OutputFile::isquark (const long quark, const bool hflg) const {
     rdlock ();
-    if (zone.exists (quark) == true) {
+    try {
+      // check the nameable class
+      bool result = hflg ? Nameable::isquark (quark, hflg) : false;
+      // check the output class
+      if (result == false) {
+	result = hflg ? OutputStream::isquark (quark, hflg) : false;
+      }
       unlock ();
-      return true;
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
     }
-    // check the nameable class
-    bool result = hflg ? Nameable::isquark (quark, hflg) : false;
-    // check the output class
-    if (result == false) {
-      result = hflg ? OutputStream::isquark (quark, hflg) : false;
-    }
-    unlock ();
-    return result;
   }
 
   // apply this object with a set of arguments and a quark
   
   Object* OutputFile::apply (Runnable* robj, Nameset* nset, const long quark,
 			     Vector* argv) {
-    // get the number of arguments
-    long argc = (argv == nilp) ? 0 : argv->length ();
-
-    // dispatch 0 argument
-    if (argc == 0) {
-      if (quark == QUARK_CLOSE) return new Boolean (close ());
-    }
-
     // check the nameable class
     if (Nameable::isquark (quark, true) == true) {
       return Nameable::apply (robj, nset, quark, argv);
