@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Real.hpp"
@@ -318,7 +318,30 @@ namespace afnix {
       throw;
     }
   }
+  
+  // locate a property index by name
 
+  long Plist::locate (const String& name) const {
+    rdlock ();
+    try {
+      long llen = d_list.length ();
+      long result = -1L;
+      for (long k = 0L; k < llen; k++) {
+	Property* prop = dynamic_cast <Property*> (d_list.get (k));
+	if (prop == nilp) continue;
+	if (prop->getname () == name) {
+	  result = k;
+	  break;
+	}
+      }
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // get a property by name
 
   Property* Plist::find (const String& name) const {
@@ -529,6 +552,23 @@ namespace afnix {
     }
   }
 
+  // get a property literal by name
+
+  Literal* Plist::toliteral (const String& name) const {
+    rdlock ();
+    try {
+      // get the property
+      Property* prop = lookup (name);
+      // the property literal
+      Literal* result = (prop == nilp) ? nilp : prop->toliteral();
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // get a property value by name
 
   String Plist::getpval (const String& name) const {
@@ -804,7 +844,7 @@ namespace afnix {
   // -------------------------------------------------------------------------
 
   // the quark zone
-  static const long QUARK_ZONE_LENGTH = 17;
+  static const long QUARK_ZONE_LENGTH = 18;
   static QuarkZone  zone (QUARK_ZONE_LENGTH);
 
   // the object supported quarks
@@ -817,6 +857,7 @@ namespace afnix {
   static const long QUARK_LOOKUP  = zone.intern ("lookup");
   static const long QUARK_EMPTYP  = zone.intern ("empty-p");
   static const long QUARK_EXISTP  = zone.intern ("exists-p");
+  static const long QUARK_TOPLIT  = zone.intern ("to-literal");
   static const long QUARK_TOBOOL  = zone.intern ("to-boolean");
   static const long QUARK_TOLONG  = zone.intern ("to-integer");
   static const long QUARK_TOREAL  = zone.intern ("to-real");
@@ -940,6 +981,10 @@ namespace afnix {
 	String name = argv->getstring (0);
 	return new Boolean (exists (name));
       }
+      if (quark == QUARK_TOPLIT) {
+	String name = argv->getstring (0);
+	return toliteral (name);
+      }
       if (quark == QUARK_TOBOOL) {
 	String name = argv->getstring (0);
 	return new Boolean (tobool (name));
