@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_PLIST_HPP
@@ -135,6 +135,9 @@ namespace afnix {
     /// @return a property by index
     virtual Property* get (const long index) const;
 
+    /// @return a property index by name
+    virtual long locate (const String& name) const;
+    
     /// @return a property by name
     virtual Property* find (const String& name) const;
 
@@ -199,6 +202,9 @@ namespace afnix {
     /// @return a property by name or throw an exception
     virtual Property* lookup (const String& name) const;
 
+    /// @return a property literal by name
+    virtual Literal* toliteral (const String& name) const;
+    
     /// @return a property value by name
     virtual String getpval (const String& name) const;
 
