@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Stdsid.hxx"
@@ -929,12 +929,36 @@ namespace afnix {
 
   void PrintTable::merge (const PrintTable& ptbl) {
     wrlock ();
+    try {
+      merge (ptbl, false, false);
+      unlock ();
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
+  // merge a print table into this one
+
+  void PrintTable::merge (const PrintTable& ptbl,
+			  const bool hflg, const bool fflg) {
+    wrlock ();
     try {
       // make sure e have enough columns
       long cols = ptbl.getcols ();
       if (d_cols < cols) {
 	throw Exception ("merge-error", "print table is too large");
       }
+      // merge the header
+      if ((hflg == true) && (ishead () ==  true)) {
+	long idx = add ();
+	for (long col = 0; col < cols; col++) {
+	  // get the table value
+	  String value = ptbl.gethead (col);
+	  // merge it locally
+	  set (idx, col, value);
+	}
+      }
       // get the number of rows and iterate
       long rows = ptbl.getrows ();
       for (long row = 0; row < rows; row++) {
@@ -953,6 +977,16 @@ namespace afnix {
 	  }
 	}
       }
+      // merge the footer
+      if ((fflg == true) && (isfoot () ==  true)) {
+	long idx = add ();
+	for (long col = 0; col < cols; col++) {
+	  // get the table value
+	  String value = ptbl.getfoot (col);
+	  // merge it locally
+	  set (idx, col, value);
+	}
+      }
       // done
       unlock ();
     } catch (...) {
@@ -1276,6 +1310,18 @@ namespace afnix {
 	settag (row, col, val);
 	return nilp;
       }
+      if (quark == QUARK_MERGE) {
+	Object* obj = argv->get (0);
+	PrintTable* pobj = dynamic_cast <PrintTable*> (obj);
+	if (pobj == nilp) {
+	  throw Exception ("type-error", "invalid object with merge",
+			   Object::repr (obj));
+	}
+	bool hflg = argv->getbool (1);
+	bool fflg = argv->getbool (2);
+	merge (*pobj, hflg, fflg);
+	return nilp;
+      }
     }
     // call the serial method
     return Serial::apply (robj, nset, quark, argv);
