@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Set.hpp"
@@ -49,12 +49,98 @@ namespace afnix {
     add (obj);
   }
 
+  // copy constructor for this set
+
+  Set::Set (const Set& that) {
+    that.rdlock ();
+    try {
+      d_size = that.d_size;
+      d_slen = that.d_slen;
+      p_vset = new Object*[d_size];
+      for (long k = 0; k < d_slen; k++) {
+	p_vset[k] = Object::iref (that.p_vset[k]);
+      }
+      that.unlock ();
+    } catch (...) {
+      that.unlock ();
+      throw;
+    }
+  }
+
+  // copy move this set
+
+  Set::Set (Set&& that) {
+    that.wrlock ();
+    try {
+      d_size = that.d_size; that.d_size = 0L;
+      d_slen = that.d_slen; that.d_slen = 0L;
+      p_vset = that.p_vset; that.p_vset = nilp;
+      that.unlock ();
+    } catch (...) {
+      that.unlock ();
+      throw;
+    }
+  }
+  
   // destroy this set
 
   Set::~Set (void) {
     reset ();
   }
 
+  // assignment a set to this one
+
+  Set& Set::operator = (const Set& that) {
+    // protect against this = that
+    if (this == &that) return *this;
+    // lock everybody
+    wrlock ();
+    that.rdlock ();
+    try {
+      // clean vector first
+      if (d_slen != 0) {
+	for (long k = 0L; k < d_slen; k++) Object::dref (p_vset[k]);
+	delete [] p_vset;
+      }
+      // copy old to new
+      d_size = that.d_size;
+      d_slen = that.d_slen;
+      p_vset = new Object*[d_size];
+      for (long k = 0L; k < d_slen; k++) {
+	p_vset[k] = Object::iref (that.p_vset[k]);
+      }
+      that.unlock ();
+      unlock ();
+      return *this;
+    } catch (...) {
+      that.unlock ();
+      unlock ();
+      throw;
+    }
+  }
+
+  // move a vector into this one
+
+  Set& Set::operator = (Set&& that) {
+    // check for self assignation
+    if (this == &that) return *this;
+    // lock and assign
+    wrlock ();
+    that.wrlock ();
+    try {
+      d_size = that.d_size; that.d_size = 0L;
+      d_slen = that.d_slen; that.d_slen = 0L;
+      p_vset = that.p_vset; that.p_vset = nilp;
+      unlock ();
+      that.unlock ();
+      return *this;
+    } catch (...) {
+      unlock ();
+      that.unlock ();
+      throw;
+    }
+  }
+  
   // return the class name
   String Set::repr (void) const {
     return "Set";
