@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_SET_HPP
@@ -47,13 +47,29 @@ namespace afnix {
     /// create an empty set
     Set (void);
 
-    /// create a set woth an object
+    /// create a set with an object
     /// @param obj the object to add in the set
     Set (Object* obj);
 
+    /// copy construct this set
+    /// @param that the set to copy 
+    Set (const Set& that);
+
+    /// copy move this set
+    /// @param that the set to move 
+    Set (Set&& that);
+    
     /// destroy this set
     ~Set (void);
 
+    /// assign a set to this one
+    /// @param that the vector to assign
+    Set& operator = (const Set& that);
+
+    /// move a set to this one
+    /// @param that the vector to move
+    Set& operator = (Set&& that);
+
     /// @return the class name
     String repr (void) const;
 
@@ -112,10 +128,6 @@ namespace afnix {
     Iterator* makeit (void);
 
   private:
-    // make the copy constructor private
-    Set (const Set&);
-    // make the assignment operator private
-    Set& operator = (const Set&);
     // make the set iterator a friend
     friend class Setit;
 
