@@ -11,12 +11,13 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Item.hpp"
 #include "Stream.hpp"
 #include "Vector.hpp"
+#include "Boolean.hpp"
 #include "QuarkZone.hpp"
 #include "Exception.hpp"
 
@@ -38,6 +39,20 @@ namespace afnix {
     d_emod = emod;
   }
 
+  // close this stream
+
+  bool Stream::close (void) {
+    wrlock ();
+    try {
+      bool result = false;
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+	
   // return the stream descriptor
 
   int Stream::getsid (void) const {
@@ -110,10 +125,11 @@ namespace afnix {
   static const long QUARK_STREAM  = String::intern ("Stream");
 
   // the quark zone
-  static const long QUARK_ZONE_LENGTH = 2;
+  static const long QUARK_ZONE_LENGTH = 3;
   static QuarkZone  zone (QUARK_ZONE_LENGTH);
 
   // the object supported quarks
+  static const long QUARK_CLOSE   = zone.intern ("close");
   static const long QUARK_GETEMOD = zone.intern ("get-encoding-mode");
   static const long QUARK_SETEMOD = zone.intern ("set-encoding-mode");
 
@@ -151,13 +167,18 @@ namespace afnix {
 
   bool Stream::isquark (const long quark, const bool hflg) const {
     rdlock ();
-    if (zone.exists (quark) == true) {
+    try {
+      if (zone.exists (quark) == true) {
+	unlock ();
+	return true;
+      }
+      bool result = hflg ? Transcoder::isquark (quark, hflg) : false;
       unlock ();
-      return true;
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
     }
-    bool result = hflg ? Transcoder::isquark (quark, hflg) : false;
-    unlock ();
-    return result;
   }
 
   // apply this object with a set of arguments and a quark
@@ -169,6 +190,7 @@ namespace afnix {
     
     // dispatch 0 argument
     if (argc == 0) {
+      if (quark == QUARK_CLOSE) return new Boolean (close ());
       if (quark == QUARK_GETEMOD) return emod_to_item (getemod ());
     }
 
