@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Ascii.hpp"
@@ -1199,7 +1199,7 @@ namespace afnix {
 
   bool Unicode::islower (const t_quad code) {
     // get the ucd record and do nothing if it does not exist
-    const ucd_s* ucd = c_getucd (code);
+    const s_cucd* ucd = c_getcucd (code);
     if (ucd == nilp) return false;
     // check for lower case code
     return (ucd->d_pgcv == UCD_GCV_LL);
@@ -1209,7 +1209,7 @@ namespace afnix {
 
   bool Unicode::isupper (const t_quad code) {
     // get the ucd record and do nothing if it does not exist
-    const ucd_s* ucd = c_getucd (code);
+    const s_cucd* ucd = c_getcucd (code);
     if (ucd == nilp) return false;
     // check for lower case code
     return (ucd->d_pgcv == UCD_GCV_LU);
@@ -1219,7 +1219,7 @@ namespace afnix {
 
   bool Unicode::isletter (const t_quad code) {
     // get the ucd record and do nothing if it does not exist
-    const ucd_s* ucd = c_getucd (code);
+    const s_cucd* ucd = c_getcucd (code);
     if (ucd == nilp) return false;
     // get the gcv byte and check
     t_byte gcv = ucd->d_pgcv;
@@ -1235,7 +1235,7 @@ namespace afnix {
 
   bool Unicode::isdigit (const t_quad code) {
     // get the ucd record and do nothing if it does not exist
-    const ucd_s* ucd = c_getucd (code);
+    const s_cucd* ucd = c_getcucd (code);
     if (ucd == nilp) return false;
     // get the gcv byte and check
     t_byte gcv = ucd->d_pgcv;
@@ -1247,7 +1247,7 @@ namespace afnix {
 
   bool Unicode::iscan (const t_quad code) {
     // get the ucd record and do nothing if it does not exist
-    const ucd_s* ucd = c_getucd (code);
+    const s_cucd* ucd = c_getcucd (code);
     if (ucd == nilp) return false;
     // get the gcv byte
     t_byte gcv = ucd->d_pgcv;
@@ -1345,7 +1345,7 @@ namespace afnix {
 
   bool Unicode::isterm (const t_quad code) {
     // get the ucd record and do nothing if it does not exist
-    const ucd_s* ucd = c_getucd (code);
+    const s_cucd* ucd = c_getcucd (code);
     if (ucd == nilp) return false;
     // get the gcv byte
     t_byte gcv = ucd->d_pgcv;
@@ -1387,7 +1387,7 @@ namespace afnix {
 
   bool Unicode::iswcc (const t_quad code) {
     // get the ucd record and do nothing if it does not exist
-    const ucd_s* ucd = c_getucd (code);
+    const s_cucd* ucd = c_getcucd (code);
     if (ucd == nilp) return false;
     // get the gcv byte
     t_byte gcv = ucd->d_pgcv;
