@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Byte.hpp"
@@ -37,19 +37,21 @@ namespace afnix {
   // create an empty vector
 
   Vector::Vector (void) {
-    d_size   = 0;
-    d_length = 0;
-    p_vector = nilp;
+    d_size = 0L;
+    d_vlen = 0L;
+    p_vobj = nilp;
   }
 
   // create a vector with an original size
   
   Vector::Vector (const long size) {
-    if (size < 0) throw Exception ("size-error","negative vector size");
-    d_size   = size;
-    d_length = 0;
-    p_vector = new Object*[d_size];
-    for (long i = 0; i < d_size; i++) p_vector[i] = nilp;
+    if (size < 0L) {
+      throw Exception ("size-error","negative vector size");
+    }
+    d_size = size;
+    d_vlen = 0L;
+    p_vobj = new Object*[d_size];
+    for (long k = 0L; k < d_size; k++) p_vobj[k] = nilp;
   }
   
   // copy constructor for this vector
@@ -57,11 +59,12 @@ namespace afnix {
   Vector::Vector (const Vector& that) {
     that.rdlock ();
     try {
-      d_size   = that.d_size;
-      d_length = that.d_length;
-      p_vector = new Object*[d_size];
-      for (long i = 0; i < d_length; i++)
-	p_vector[i] = Object::iref (that.p_vector[i]);
+      d_size = that.d_size;
+      d_vlen = that.d_vlen;
+      p_vobj = new Object*[d_size];
+      for (long k = 0L; k < d_vlen; k++) {
+	p_vobj[k] = Object::iref (that.p_vobj[k]);
+      }
       that.unlock ();
     } catch (...) {
       that.unlock ();
@@ -69,13 +72,81 @@ namespace afnix {
     }
   }
 
+  // copy move this vector
+
+  Vector::Vector (Vector&& that) {
+    that.wrlock ();
+    try {
+      d_size = that.d_size; that.d_size = 0L;
+      d_vlen = that.d_vlen; that.d_vlen = 0L;
+      p_vobj = that.p_vobj; that.p_vobj = nilp;
+      that.unlock ();
+    } catch (...) {
+      that.unlock ();
+      throw;
+    }
+  }
+  
   // destroy this vector
 
   Vector::~Vector (void) {
-    for (long i = 0; i < d_length; i++) Object::dref (p_vector[i]);
-    delete [] p_vector;
+    for (long k = 0L; k < d_vlen; k++) Object::dref (p_vobj[k]);
+    delete [] p_vobj;
   }
 
+  // assignment a vector to this one
+
+  Vector& Vector::operator = (const Vector& that) {
+    // protect against this = that
+    if (this == &that) return *this;
+    // lock everybody
+    wrlock ();
+    that.rdlock ();
+    try {
+      // clean vector first
+      if (d_vlen != 0) {
+	for (long i = 0; i < d_vlen; i++) Object::dref (p_vobj[i]);
+	delete [] p_vobj;
+      }
+      // copy old to new
+      d_size = that.d_size;
+      d_vlen = that.d_vlen;
+      p_vobj = new Object*[d_size];
+      for (long i = 0; i < d_vlen; i++) {
+	p_vobj[i] = Object::iref (that.p_vobj[i]);
+      }
+      that.unlock ();
+      unlock ();
+      return *this;
+    } catch (...) {
+      that.unlock ();
+      unlock ();
+      throw;
+    }
+  }
+
+  // move a vector into this one
+
+  Vector& Vector::operator = (Vector&& that) {
+    // check for self assignation
+    if (this == &that) return *this;
+    // lock and assign
+    wrlock ();
+    that.wrlock ();
+    try {
+      d_size = that.d_size; that.d_size = 0L;
+      d_vlen = that.d_vlen; that.d_vlen = 0L;
+      p_vobj = that.p_vobj; that.p_vobj = nilp;
+      unlock ();
+      that.unlock ();
+      return *this;
+    } catch (...) {
+      unlock ();
+      that.unlock ();
+      throw;
+    }
+  }
+  
   // return the class name
 
   String Vector::repr (void) const {
@@ -94,9 +165,9 @@ namespace afnix {
     rdlock ();
     try {
       // write the vector length
-      Serial::wrlong (d_length, os);
+      Serial::wrlong (d_vlen, os);
       // write the objects
-      for (long i = 0; i < d_length; i++) {
+      for (long i = 0; i < d_vlen; i++) {
 	Object* obj = get (i);
 	if (obj == nilp) {
 	  Serial::wrnilid (os);
@@ -139,46 +210,30 @@ namespace afnix {
     return new Vector (*this);
   }
 
-  // assignment operator for this class
+  // release this object links
 
-  Vector& Vector::operator = (const Vector& that) {
-    // protect against this = that
-    if (this == &that) return *this;
-    // lock everybody
+  void Vector::release (void) {
     wrlock ();
-    that.rdlock ();
     try {
-      // clean vector first
-      if (d_length != 0) {
-	for (long i = 0; i < d_length; i++)
-	  Object::dref (p_vector[i]);
-	delete [] p_vector;
+      for (long k = 0L; k < d_vlen; k++) {
+	auto co = dynamic_cast <Collectable*> (p_vobj[k]);
+	if (co != nilp) co->release ();
       }
-      // copy old to new
-      d_size   = that.d_size;
-      d_length = that.d_length;
-      p_vector = new Object*[d_size];
-      for (long i = 0; i < d_length; i++)
-	p_vector[i] = Object::iref (that.p_vector[i]);
-      that.unlock ();
-      unlock ();
-      return *this;
     } catch (...) {
-      that.unlock ();
       unlock ();
       throw;
     }
   }
-
+  
   // reset this vector
 
   void Vector::reset (void) {
     wrlock ();
     try {
-      if (p_vector != nilp) {
-	for (long i = 0; i < d_length; i++) Object::dref (p_vector[i]);
-      }
-      d_length = 0;
+      for (long k = 0L; k < d_vlen; k++) Object::dref (p_vobj[k]);
+      d_size = 0L;
+      d_vlen = 0;
+      delete [] p_vobj; p_vobj = nilp;
       unlock ();
     } catch (...) {
       unlock ();
@@ -191,7 +246,7 @@ namespace afnix {
   bool Vector::empty (void) const {
     rdlock ();
     try {
-      bool result = (d_length == 0);
+      bool result = (d_vlen == 0);
       unlock ();
       return result;
     } catch (...) {
@@ -205,8 +260,8 @@ namespace afnix {
   bool Vector::exists (Object* object) const {
     rdlock ();
     try {
-      for (long i = 0; i < d_length; i++) {
-	if (p_vector[i] == object) {
+      for (long i = 0; i < d_vlen; i++) {
+	if (p_vobj[i] == object) {
 	  unlock ();
 	  return true;
 	}
@@ -224,7 +279,7 @@ namespace afnix {
   long Vector::length (void) const {
     rdlock ();
     try {
-      long result = d_length;
+      long result = d_vlen;
       unlock ();
       return result;
     } catch (...) {
@@ -239,17 +294,17 @@ namespace afnix {
     wrlock ();
     try {
       // check if we have to resize the vector
-      if (d_length >= d_size) {
+      if (d_vlen >= d_size) {
 	long size = (d_size <= 0) ? 1 : d_size * 2;
 	Object** vector = new Object*[size];
-	for (long i = 0; i < d_length; i++)
-	  vector[i] = p_vector[i];
-	delete [] p_vector;
-	d_size   = size;
-	p_vector = vector;
+	for (long i = 0; i < d_vlen; i++)
+	  vector[i] = p_vobj[i];
+	delete [] p_vobj;
+	d_size = size;
+	p_vobj = vector;
       }
       // set the object in this vector
-      p_vector[d_length++] = Object::iref (object);
+      p_vobj[d_vlen++] = Object::iref (object);
       // unlock the vector
       unlock ();
     } catch (...) {
@@ -268,31 +323,31 @@ namespace afnix {
 	throw Exception ("index-error", "out-of-bound index in add");
       }
       // check for large index
-      if (index >= d_length) {
+      if (index >= d_vlen) {
 	// resize upto the index
-	for (long k = d_length; k < index; k++) add (nilp);
+	for (long k = d_vlen; k < index; k++) add (nilp);
 	add (object);
 	unlock ();
 	return;
       }
       // check if we have to resize the vector
-      if (d_length >= d_size) {
+      if (d_vlen >= d_size) {
 	long size = (d_size <= 0) ? 1 : d_size * 2;
 	Object** vector = new Object*[size];
-	for (long i = 0; i < d_length; i++)
-	  vector[i] = p_vector[i];
-	delete [] p_vector;
-	d_size   = size;
-	p_vector = vector;
+	for (long i = 0; i < d_vlen; i++)
+	  vector[i] = p_vobj[i];
+	delete [] p_vobj;
+	d_size = size;
+	p_vobj = vector;
       }
       // move the objects
-      for (long i = d_length; i > index; i--) {
-	p_vector[i] = p_vector[i-1];
+      for (long i = d_vlen; i > index; i--) {
+	p_vobj[i] = p_vobj[i-1];
       }
       // set the object in this vector
-      p_vector[index] = Object::iref (object);
+      p_vobj[index] = Object::iref (object);
       // adjust the length
-      d_length++;
+      d_vlen++;
       // unlock the vector
       unlock ();
     } catch (...) {
@@ -308,14 +363,14 @@ namespace afnix {
     wrlock ();
     try {
       // check that we are bounded
-      if (index >= d_length) {
+      if (index >= d_vlen) {
 	throw Exception ("index-error","index is out of range");
       }
       // protect the object first
       Object::iref (object);
       // set the object
-      Object::dref (p_vector[index]);
-      p_vector[index] = object;
+      Object::dref (p_vobj[index]);
+      p_vobj[index] = object;
       // unlock the vector
       unlock ();
     } catch (...) {
@@ -330,11 +385,11 @@ namespace afnix {
     rdlock ();
     try {
       // check that we are bounded
-      if ((index < 0) || (index >= d_length)) {
+      if ((index < 0) || (index >= d_vlen)) {
 	throw Exception ("index-error","index is out of range");
       }
       // get the object and unlock
-      Object* result = p_vector[index];
+      Object* result = p_vobj[index];
       unlock ();
       return result;
     } catch (...) {
@@ -362,7 +417,7 @@ namespace afnix {
   Object* Vector::last (void) const {
     rdlock ();
     try {
-      Object* result = get (d_length-1);
+      Object* result = get (d_vlen-1);
       unlock ();
       return result;
     } catch (...) {
@@ -379,12 +434,12 @@ namespace afnix {
       // get the first object
       Object* result = get (0);
       // shift the remaining arguments
-      for (long i = 1; i < d_length; i++) {
-	p_vector[i-1] = p_vector[i];
-	p_vector[i]   = nilp;
+      for (long i = 1; i < d_vlen; i++) {
+	p_vobj[i-1] = p_vobj[i];
+	p_vobj[i]   = nilp;
       }
       // fix length and result object
-      d_length--;
+      d_vlen--;
       Object::tref (result);
       unlock ();
       return result;
@@ -402,7 +457,7 @@ namespace afnix {
       // get the last object
       Object* result = last ();
       // fix length and result object
-      d_length--;
+      d_vlen--;
       Object::tref (result);
       unlock ();
       return result;
@@ -418,8 +473,8 @@ namespace afnix {
     if (object == nilp) return -1;
     rdlock ();
     try {
-      for (long i = 0; i < d_length; i++) {
-	if (p_vector[i] == object) {
+      for (long i = 0; i < d_vlen; i++) {
+	if (p_vobj[i] == object) {
 	  unlock ();
 	  return i;
 	}
@@ -437,17 +492,17 @@ namespace afnix {
   void Vector::remove (const long index) {
     wrlock ();
     try {
-      if ((index < 0) || (index >= d_length)) {
+      if ((index < 0) || (index >= d_vlen)) {
 	throw Exception ("index-error","index is out of range");
       }
       // remove the object
-      Object::dref (p_vector[index]);
+      Object::dref (p_vobj[index]);
       // repack the vector
-      long mark = d_length - 1;
+      long mark = d_vlen - 1;
       for (long i = index; i < mark; i++) {
-	p_vector[i] = p_vector[i+1];
+	p_vobj[i] = p_vobj[i+1];
       }
-      d_length = mark;
+      d_vlen = mark;
       unlock ();
     } catch (...) {
       unlock ();
@@ -481,8 +536,8 @@ namespace afnix {
     Vector* result = nilp;
     try {
       result = new Vector;
-      for (long i = 1; i < d_length; i++) {
-	result->add (p_vector[i]);
+      for (long i = 1; i < d_vlen; i++) {
+	result->add (p_vobj[i]);
       }
       unlock ();
       return result;
@@ -1126,7 +1181,7 @@ namespace afnix {
     if (p_vobj != nilp) p_vobj->rdlock ();
     try {
       if (p_vobj != nilp) {
-	d_vidx = (p_vobj->d_length == 0) ? 0 : p_vobj->d_length - 1;
+	d_vidx = (p_vobj->d_vlen == 0) ? 0 : p_vobj->d_vlen - 1;
       } else {
 	d_vidx = 0;
       }
@@ -1146,7 +1201,7 @@ namespace afnix {
     if (p_vobj != nilp) p_vobj->rdlock ();
     try {
       if (p_vobj != nilp) {
-	if (++d_vidx >= p_vobj->d_length) d_vidx = p_vobj->d_length;
+	if (++d_vidx >= p_vobj->d_vlen) d_vidx = p_vobj->d_vlen;
       } else {
 	d_vidx = 0;
       }
@@ -1179,7 +1234,7 @@ namespace afnix {
     if (p_vobj != nilp) p_vobj->rdlock ();
     try {
       Object* result = nilp;
-      if ((p_vobj != nilp) && (d_vidx < p_vobj->d_length)) {
+      if ((p_vobj != nilp) && (d_vidx < p_vobj->d_vlen)) {
 	result = p_vobj->get (d_vidx);
       }
       if (p_vobj != nilp) p_vobj->unlock ();
@@ -1200,7 +1255,7 @@ namespace afnix {
     try {
       bool result = false;
       if (p_vobj != nilp) {
-	result = (d_vidx >= p_vobj->d_length);
+	result = (d_vidx >= p_vobj->d_vlen);
       }
       if (p_vobj != nilp) p_vobj->unlock ();
       unlock ();
