@@ -11,18 +11,22 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_VECTOR_HPP
 #define  AFNIX_VECTOR_HPP
 
+#ifndef  AFNIX_SERIAL_HPP
+#include "Serial.hpp"
+#endif
+
 #ifndef  AFNIX_ITERABLE_HPP
 #include "Iterable.hpp"
 #endif
 
-#ifndef  AFNIX_SERIAL_HPP
-#include "Serial.hpp"
+#ifndef  AFNIX_COLLECTABLE_HPP
+#include "Collectable.hpp"
 #endif
 
 namespace afnix {
@@ -32,14 +36,14 @@ namespace afnix {
   /// class should be used when an indexed container is required.
   /// @author amaury darsch
 
-  class Vector : public Iterable, public Serial {
+  class Vector : public Iterable, public Serial, public Collectable {
   private:
-    /// the current size of this vector
-    long d_length;
-    /// the size of the allocated vector
+    /// the vector size
     long d_size;
+    /// the vector length
+    long d_vlen;
     /// the allocated vector
-    Object** p_vector;
+    Object** p_vobj;
 
   public:
     /// create an empty vector.
@@ -49,13 +53,25 @@ namespace afnix {
     /// @param size the requested size
     Vector (const long size);
 
-    /// copy constructor for this vector
+    /// copy construct this vector
     /// @param that the vector to copy 
     Vector (const Vector& that);
 
+    /// copy move this vector
+    /// @param that the vector to move 
+    Vector (Vector&& that);
+
     /// destroy this vector
     ~Vector (void);
 
+    /// assign a vector to this one
+    /// @param that the vector to assign
+    Vector& operator = (const Vector& that);
+
+    /// move a vector to this one
+    /// @param that the vector to move
+    Vector& operator = (Vector&& that);
+
     /// @return the class name
     String repr (void) const;
 
@@ -73,10 +89,9 @@ namespace afnix {
     /// @return a clone of this object
     Object* clone (void) const;
 
-    /// assign a vector to this one
-    /// @param that the vector to assign
-    Vector& operator = (const Vector& that);
-
+    /// release this object links
+    void release (void);
+    
     /// reset this vector
     void reset (void);
 
