@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Real.hpp"
@@ -49,9 +49,31 @@ namespace afnix {
     #endif
     for (t_long i = 0; i < size; i++) r.nlset (i, x.nlget (i));
   }
-
+  
   // compare two vectors
 
+  bool Algebra::eql (const Rvi& x, const Rvi& y) {
+    // check size compatibility
+    t_long size = x.getsize ();
+    if (y.getsize () != size) {
+      throw Exception ("vector-error",
+		       "incompatible vector size with compare");
+    }
+    bool result = true;
+    // loop in locked mode
+    #ifdef _OPENMP
+    #pragma omp parallel for private(result)
+    #endif
+    for (t_long i = 0; i < size; i++) {
+      t_real xi = x.nlget (i);
+      t_real yi = y.nlget (i);
+      if (xi != yi) result &= false;
+    }
+    return result;
+  }
+  
+  // compare two vectors by precision
+
   bool Algebra::cmp (const Rvi& x, const Rvi& y) {
     // check size compatibility
     t_long size = x.getsize ();
@@ -461,6 +483,33 @@ namespace afnix {
 
   // compare two matrices
 
+  bool Algebra::eql (const Rmi& mx, const Rmi& my) {
+    // extract operating size
+    t_long rsiz = mx.getrsiz ();
+    t_long csiz = mx.getcsiz ();
+    // check target size
+    if ((my.getrsiz () != rsiz) || (my.getcsiz () != csiz)) {
+      throw Exception ("algebra-error", "incompatible size in matrix compare");
+    }
+    // check for null
+    if ((rsiz == 0) || (csiz == 0)) return true;
+    bool result = true;
+    // loop in locked mode
+    #ifdef _OPENMP
+    #pragma omp parallel for private(result)
+    #endif
+    for (t_long i = 0; i < rsiz; i++) {
+      for (t_long j = 0; j < csiz; j++) {
+	t_real xij = mx.nlget (i, j);
+	t_real yij = my.nlget (i, j);
+	if (xij!= yij) result &= false;
+      }
+    }
+    return result;
+  }
+  
+  // compare two matrices by precision
+
   bool Algebra::cmp (const Rmi& mx, const Rmi& my) {
     // extract operating size
     t_long rsiz = mx.getrsiz ();
