@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_ALGEBRA_HPP
@@ -43,7 +43,12 @@ namespace afnix {
     /// @param x the vector argument
     static void cpy (Rvi& r, const Rvi& x);
 
-    /// compare two vectors
+    /// compare two vectors precision
+    /// @param x the vector argument
+    /// @param y the vector argument
+    static bool eql (const Rvi& x, const Rvi& y);
+    
+    /// compare two vectors by precision
     /// @param x the vector argument
     /// @param y the vector argument
     static bool cmp (const Rvi& x, const Rvi& y);
@@ -168,6 +173,11 @@ namespace afnix {
     /// compare two matrices
     /// @param mx the matrix argument
     /// @param my the matrix argument
+    static bool eql (const Rmi& mx, const Rmi& my);
+
+    /// compare two matrices by precision
+    /// @param mx the matrix argument
+    /// @param my the matrix argument
     static bool cmp (const Rmi& mx, const Rmi& my);
 
     /// check if a matrix row is null
