@@ -11,17 +11,20 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Qr.hpp"
 #include "Mgs.hpp"
 #include "Cgs.hpp"
 #include "Bcs.hpp"
+#include "Cov.hpp"
+#include "Mean.hpp"
 #include "Tqmr.hpp"
 #include "Meta.hpp"
 #include "Mpia.hpp"
 #include "Ippd.hpp"
+#include "Lufit.hpp"
 #include "Random.hpp"
 #include "Linear.hpp"
 #include "Newton.hpp"
@@ -33,6 +36,7 @@
 #include "Rvector.hpp"
 #include "Rgivens.hpp"
 #include "Rmatrix.hpp"
+#include "MthCalls.hpp"
 #include "Function.hpp"
 #include "Analytic.hpp"
 #include "Rsamples.hpp"
@@ -59,9 +63,12 @@ namespace afnix {
     mset->symcst ("Rmd",                 new Meta (Rmd::mknew));
     mset->symcst ("Cgs",                 new Meta (Cgs::mknew));
     mset->symcst ("Bcs",                 new Meta (Bcs::mknew));
+    mset->symcst ("Cov",                 new Meta (Cov::mknew));
+    mset->symcst ("Mean",                new Meta (Mean::mknew));
     mset->symcst ("Tqmr",                new Meta (Tqmr::mknew));
     mset->symcst ("Rmit",                new Meta (Rmit::meval));
     mset->symcst ("Ippd",                new Meta (Ippd::mknew));
+    mset->symcst ("Lufit",               new Meta (Lufit::mknew));
     mset->symcst ("Linear",              new Meta (Linear::mknew));
     mset->symcst ("Newton",              new Meta (Newton::mknew));
     mset->symcst ("Rblock",              new Meta (Rblock::mknew));
@@ -87,8 +94,12 @@ namespace afnix {
     mset->symcst ("rpi-p",               new Function (mth_rpip));
     mset->symcst ("cgs-p",               new Function (mth_cgsp));
     mset->symcst ("bcs-p",               new Function (mth_bcsp));
+    mset->symcst ("cov-p",               new Function (mth_covp));
+    mset->symcst ("fit-p",               new Function (mth_fitp));
+    mset->symcst ("mean-p",              new Function (mth_meanp));
     mset->symcst ("tqmr-p",              new Function (mth_tqmrp));
     mset->symcst ("ippd-p",              new Function (mth_ippdp));
+    mset->symcst ("lufit-p",             new Function (mth_lufp));
     mset->symcst ("solver-p",            new Function (mth_slvp));
     mset->symcst ("direct-p",            new Function (mth_dlsp));
     mset->symcst ("linear-p",            new Function (mth_lnrp));
@@ -113,6 +124,9 @@ namespace afnix {
     mset->symcst ("gcd",                 new Function (mth_gcd));
     mset->symcst ("lcm",                 new Function (mth_lcm));
     mset->symcst ("mmi",                 new Function (mth_mmi));
+
+    mset->symcst ("to-rvi",              new Function (mth_torvi));
+    mset->symcst ("to-infix",            new Function (mth_toinfix));
     
     mset->symcst ("get-random-byte",     new Function (mth_byternd));
     mset->symcst ("get-random-integer",  new Function (mth_longrnd));
