@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2011 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_MTHCALLS_HPP
@@ -23,33 +23,22 @@
  
 namespace afnix {
 
-  /// this file contains specific mathematical procedures that require only
-  /// arguments and that are not bounded to a class.
+  /// this file contains specific system procedures that require only
+  /// arguments and that are not bounded to a class
   /// @author amaury darsch
 
-  /// compute the determinant of a matrix by direction
+  /// convert a string to a real vector
   /// @param robj the current runnable
   /// @param nset the current nameset
   /// @param args the argument list
-  Object* mth_det (Runnable* robj, Nameset* nset, Cons* args);
+  Object* mth_torvi (Runnable* robj, Nameset* nset, Cons* args);
 
-  /// solve a linear system with the cramer method
+  /// convert an object to an infix string
   /// @param robj the current runnable
   /// @param nset the current nameset
   /// @param args the argument list
-  Object* mth_crm (Runnable* robj, Nameset* nset, Cons* args);
-
-  /// solve a linear system with the conjugate gradient squared algorithm
-  /// @param robj the current runnable
-  /// @param nset the current nameset
-  /// @param args the argument list
-  Object* mth_cgs (Runnable* robj, Nameset* nset, Cons* args);
-
-  /// solve a linear system with the biconjugate stabilized algorithm
-  /// @param robj the current runnable
-  /// @param nset the current nameset
-  /// @param args the argument list
-  Object* mth_bcs (Runnable* robj, Nameset* nset, Cons* args);
+  Object* mth_toinfix (Runnable* robj, Nameset* nset, Cons* args);
 }
 
+
 #endif
