@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Rmi.hpp"
@@ -140,6 +140,29 @@ namespace afnix {
     }
   }
 
+  // compare two matrices
+
+  bool Rmi::operator == (const Rmi& x) const {
+    rdlock ();
+    x.rdlock ();
+    try {
+      bool result = Algebra::eql (*this, x);
+      unlock ();
+      x.unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      x.unlock ();
+      throw;
+    }
+  }
+
+  // compare two matrices
+
+  bool Rmi::operator != (const Rmi& x) const {
+    return !(*this == x);
+  }
+  
   // get the matrix row size
 
   t_long Rmi::getrsiz (void) const {
@@ -639,10 +662,12 @@ namespace afnix {
   // -------------------------------------------------------------------------
 
   // the quark zone
-  static const long QUARK_ZONE_LENGTH = 24;
+  static const long QUARK_ZONE_LENGTH = 26;
   static QuarkZone  zone (QUARK_ZONE_LENGTH);
 
   // the object supported quarks
+  static const long QUARK_EQL       = zone.intern ("==");
+  static const long QUARK_NEQ       = zone.intern ("!=");
   static const long QUARK_QEQ       = zone.intern ("?=");
   static const long QUARK_SET       = zone.intern ("set");
   static const long QUARK_GET       = zone.intern ("get");
@@ -689,6 +714,24 @@ namespace afnix {
     }
   }
 
+  // operate this object with another object
+
+  Object* Rmi::oper (t_oper type, Object* object) {
+    Rmi* mobj = dynamic_cast <Rmi*> (object);
+    switch (type) {
+    case Object::EQL:
+      if (mobj != nilp) return new Boolean (*this == *mobj);
+      break;
+    case Object::NEQ:
+      if (mobj != nilp) return new Boolean (*this != *mobj);
+      break;
+    default:
+      break;
+    }
+    throw Exception ("type-error", "invalid operand with real matrix",
+		     Object::repr (object));
+  }
+  
   // apply this object with a set of arguments and a quark
   
   Object* Rmi::apply (Runnable* robj, Nameset* nset, const long quark,
@@ -723,6 +766,8 @@ namespace afnix {
     }
     // dispatch 1 argument
     if (argc == 1) {
+      if (quark == QUARK_EQL) return oper (Object::EQL, argv->get (0));
+      if (quark == QUARK_NEQ) return oper (Object::NEQ, argv->get (0));
       if (quark == QUARK_CPR) {
 	t_long row = argv->getlong (0);
 	return cpr (row);
