@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_RMI_HPP
@@ -63,6 +63,16 @@ namespace afnix {
     /// @param is the input stream
     void rdstream (InputStream& os);
 
+    /// compare two matrices
+    /// @param  x the vector argument
+    /// @return true if they are equals
+    virtual bool operator == (const Rmi& x) const;
+
+    /// compare two matrices
+    /// @param  x the vector argument
+    /// @return true if they are not equals
+    virtual bool operator != (const Rmi& x) const;
+    
     /// @return the matrix row size
     virtual t_long getrsiz (void) const;
 
@@ -264,6 +274,11 @@ namespace afnix {
   public:
     /// @return true if the given quark is defined
     bool isquark (const long quark, const bool hflg) const;
+
+    /// operate this object with another object
+    /// @param type   the operator type
+    /// @param object the operand object
+    Object* oper (t_oper type, Object* object);
     
     /// apply this object with a set of arguments and a quark
     /// @param robj  the current runnable
