@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Real.hpp"
@@ -808,12 +808,10 @@ namespace afnix {
       if (dobj != nilp) return new Rvector (*this / dobj->toreal ());
       break;
     default:
-      throw Exception ("vector-error", "invalid operator with r-vector",
-		       Object::repr (object));
       break;
     }
-    throw Exception ("type-error", "invalid operand with r-vector",
-		     Object::repr (object));
+    // call the rvi operator
+    return Rvi::oper (type, object);
   }
 }
 
