@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Rvi.hpp"
@@ -118,21 +118,7 @@ namespace afnix {
     rdlock ();
     x.rdlock ();
     try {
-      // check size first
-      if (d_size != x.d_size) {
-	throw Exception ("vector-error",
-			 "incompatible vector size with compare");
-      }
-      // initialize result
-      bool result = true;
-      // loop in vector
-      for (t_long i = 0; i < d_size; i++) {
-	if (nlget (i) != x.nlget (i)) {
-	  result = false;
-	  break;
-	}
-      }
-      // unlock and return
+      bool result = Algebra::eql (*this, x);
       unlock ();
       x.unlock ();
       return result;
@@ -537,11 +523,12 @@ namespace afnix {
   // -------------------------------------------------------------------------
 
   // the quark zone
-  static const long QUARK_ZONE_LENGTH = 14;
+  static const long QUARK_ZONE_LENGTH = 16;
   static QuarkZone  zone (QUARK_ZONE_LENGTH);
 
   // the object supported quarks
-  static const long QUARK_DOT       = zone.intern ("dot");
+  static const long QUARK_EQL       = zone.intern ("==");
+  static const long QUARK_NEQ       = zone.intern ("!=");
   static const long QUARK_QEQ       = zone.intern ("?=");
   static const long QUARK_AEQ       = zone.intern ("+=");
   static const long QUARK_SEQ       = zone.intern ("-=");
@@ -549,6 +536,7 @@ namespace afnix {
   static const long QUARK_DEQ       = zone.intern ("/=");
   static const long QUARK_SET       = zone.intern ("set");
   static const long QUARK_GET       = zone.intern ("get");
+  static const long QUARK_DOT       = zone.intern ("dot");
   static const long QUARK_NORM      = zone.intern ("norm");
   static const long QUARK_CLEAR     = zone.intern ("clear");
   static const long QUARK_RESET     = zone.intern ("reset");
@@ -573,6 +561,24 @@ namespace afnix {
       throw;
     }
   }
+
+  // operate this object with another object
+
+  Object* Rvi::oper (t_oper type, Object* object) {
+    Rvi* vobj = dynamic_cast <Rvi*> (object);
+    switch (type) {
+    case Object::EQL:
+      if (vobj != nilp) return new Boolean (*this == *vobj);
+      break;
+    case Object::NEQ:
+      if (vobj != nilp) return new Boolean (*this != *vobj);
+      break;
+    default:
+      break;
+    }
+    throw Exception ("type-error", "invalid operand with real vector",
+		     Object::repr (object));
+  }
   
   // apply this object with a set of arguments and a quark
   
@@ -596,6 +602,8 @@ namespace afnix {
     }
     // dispatch 1 argument
     if (argc == 1) {
+      if (quark == QUARK_EQL) return oper (Object::EQL, argv->get (0));
+      if (quark == QUARK_NEQ) return oper (Object::NEQ, argv->get (0));
       if (quark == QUARK_GET) {
         t_long pos = argv->getlong (0);
         return new Real (get (pos));
