@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_RVI_HPP
@@ -213,8 +213,14 @@ namespace afnix {
 
   public:
     /// @return true if the given quark is defined
+
     bool isquark (const long quark, const bool hflg) const;
 
+    /// operate this object with another object
+    /// @param type   the operator type
+    /// @param object the operand object
+    Object* oper (t_oper type, Object* object);
+
     /// apply this object with a set of arguments and a quark
     /// @param robj  the current runnable
     /// @param nset  the current nameset    
