@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Meta.hpp"
@@ -39,7 +39,7 @@ namespace afnix {
     
     // bind all classes in the afnix:net nameset
     nset->symcst ("Address",         new Meta (Address::mknew));
-    nset->symcst ("Socket",          new Meta (Socket::meval));
+    nset->symcst ("Sockopt",         new Meta (Sockopt::meval));
     nset->symcst ("TcpSocket",       new Meta (TcpSocket::mknew));
     nset->symcst ("TcpServer",       new Meta (TcpServer::mknew));
     nset->symcst ("TcpClient",       new Meta (TcpClient::mknew));
@@ -47,9 +47,11 @@ namespace afnix {
     nset->symcst ("UdpServer",       new Meta (UdpServer::mknew));
     nset->symcst ("UdpClient",       new Meta (UdpClient::mknew));
     nset->symcst ("Multicast",       new Meta (Multicast::mknew));
+    nset->symcst ("SockParams",      new Meta (SockParams::mknew));
     
     // bind all predicates in the afnix:net nameset
     nset->symcst ("socket-p",        new Function (net_socketp));
+    nset->symcst ("sockopt-p",       new Function (net_sockoptp));
     nset->symcst ("address-p",       new Function (net_addressp));
     nset->symcst ("datagram-p",      new Function (net_datagramp));
     nset->symcst ("tcp-socket-p",    new Function (net_tcpsocketp));
@@ -59,6 +61,7 @@ namespace afnix {
     nset->symcst ("tcp-server-p",    new Function (net_tcpserverp));
     nset->symcst ("udp-server-p",    new Function (net_udpserverp));
     nset->symcst ("multicast-p",     new Function (net_multicastp));
+    nset->symcst ("sock-params-p",   new Function (net_sockprmsp));
     
     // bind the network system calls
     nset->symcst ("get-loopback",    new Function (net_getloopback));
