@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Cons.hpp"
@@ -47,6 +47,24 @@ namespace afnix {
     Object::cref (obj);
     return new Boolean (result);
   }
+  
+  // sockoptp: socket option object predicate
+
+  Object* net_sockoptp  (Runnable* robj, Nameset* nset, Cons* args) {
+    Object* obj = get_obj (robj, nset, args, "sockopt-p");
+    bool result =  (dynamic_cast <Sockopt*> (obj) == nilp) ? false : true;
+    Object::cref (obj);
+    return new Boolean (result);
+  }
+
+  // sockprmsp: socket parameters object predicate
+
+  Object* net_sockprmsp  (Runnable* robj, Nameset* nset, Cons* args) {
+    Object* obj = get_obj (robj, nset, args, "sock-params-p");
+    bool result =  (dynamic_cast <SockParams*> (obj) == nilp) ? false : true;
+    Object::cref (obj);
+    return new Boolean (result);
+  }
 
   // socketp: socket object predicate
 
