@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_PREDNET_HPP
@@ -33,6 +33,18 @@ namespace afnix {
   /// @param args the arguments list
   Object* net_addressp   (Runnable* robj, Nameset* nset, Cons* args);
 
+  /// the socket option object predicate
+  /// @param robj the current runnable
+  /// @param nset the current nameset
+  /// @param args the arguments list
+  Object* net_sockoptp   (Runnable* robj, Nameset* nset, Cons* args);
+
+  /// the socket parameters predicate
+  /// @param robj the current runnable
+  /// @param nset the current nameset
+  /// @param args the arguments list
+  Object* net_sockprmsp  (Runnable* robj, Nameset* nset, Cons* args);
+
   /// the socket object predicate
   /// @param robj the current runnable
   /// @param nset the current nameset
