@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Item.hpp"
@@ -33,43 +33,6 @@ namespace afnix {
   // - private section                                                       -
   // -------------------------------------------------------------------------
 
-  // the socket eval quarks
-  static const long QUARK_REUSEADDR = String::intern ("REUSE-ADDRESS");
-  static const long QUARK_BROADCAST = String::intern ("BROADCAST");
-  static const long QUARK_DONTROUTE = String::intern ("DONT-ROUTE");
-  static const long QUARK_KEEPALIVE = String::intern ("KEEP-ALIVE");
-  static const long QUARK_LINGER    = String::intern ("LINGER");
-  static const long QUARK_RCVSIZE   = String::intern ("RCV-SIZE");
-  static const long QUARK_SNDSIZE   = String::intern ("SND-SIZE");
-  static const long QUARK_HOPLIMIT  = String::intern ("HOP-LIMIT");
-  static const long QUARK_MCASTLOOP = String::intern ("MULTICAST-LOOPBACK");
-  static const long QUARK_MCASTHOP  = String::intern ("MULTICAST-HOP-LIMIT");
-  static const long QUARK_MAXSEG    = String::intern ("MAX-SEGMENT-SIZE");
-  static const long QUARK_NODELAY   = String::intern ("NO-DELAY");
-  static const long QUARK_SOCKET    = String::intern ("Socket");
-
-  // map an enumeration item to a socket option
-  static inline Socket::t_option item_to_option (const Item& item) {
-    // check for a socket item
-    if (item.gettid () != QUARK_SOCKET)
-      throw Exception ("item-error", "item is not an socket item");
-    // map the item to the enumeration
-    long quark = item.getquark ();
-    if (quark == QUARK_REUSEADDR) return Socket::SOCK_REUSEADDR;
-    if (quark == QUARK_BROADCAST) return Socket::SOCK_BROADCAST;
-    if (quark == QUARK_DONTROUTE) return Socket::SOCK_DONTROUTE;
-    if (quark == QUARK_KEEPALIVE) return Socket::SOCK_KEEPALIVE;
-    if (quark == QUARK_LINGER)    return Socket::SOCK_LINGER;
-    if (quark == QUARK_RCVSIZE)   return Socket::SOCK_RCVSIZE;
-    if (quark == QUARK_SNDSIZE)   return Socket::SOCK_SNDSIZE;
-    if (quark == QUARK_HOPLIMIT)  return Socket::SOCK_HOPLIMIT;
-    if (quark == QUARK_MCASTLOOP) return Socket::SOCK_MCASTLOOP;
-    if (quark == QUARK_MCASTHOP)  return Socket::SOCK_MCASTHOP;
-    if (quark == QUARK_MAXSEG)    return Socket::SOCK_MAXSEG;
-    if (quark == QUARK_NODELAY)   return Socket::SOCK_NODELAY;
-    throw Exception ("item-error", "cannot map item to socket option");
-  }
-
   // generate an authority by address and port
   static String to_authority (const Address* addr, const long port) {
     // initialize result
@@ -96,7 +59,7 @@ namespace afnix {
     // here it is
     return result;
   }
-
+  
   // -------------------------------------------------------------------------
   // - class section                                                         -
   // -------------------------------------------------------------------------
@@ -125,6 +88,25 @@ namespace afnix {
     return "Socket";
   }
 
+  // close this socket 
+  
+  bool Socket::close (void) {
+    wrlock ();
+    try {
+      if ((d_sid == -1) || (Object::uref (this) == false)) {
+	unlock ();
+	return true;
+      }
+      bool status = c_close (d_sid);
+      d_sid = -1;
+      unlock ();
+      return status;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
   // return the stream descriptor
 
   int Socket::getsid (void) const {
@@ -196,25 +178,6 @@ namespace afnix {
     }
   }
 
-  // close this socket 
-  
-  bool Socket::close (void) {
-    wrlock ();
-    try {
-      if ((d_sid == -1) || (Object::uref (this) == false)) {
-	unlock ();
-	return true;
-      }
-      bool status = c_close (d_sid);
-      d_sid = -1;
-      unlock ();
-      return status;
-    } catch (...) {
-      unlock ();
-      throw;
-    }
-  }
-
   // force a socket shutdown
   
   bool Socket::shutdown (void) {
@@ -240,8 +203,8 @@ namespace afnix {
     wrlock ();
     try {
       bool result = false;
-      if (mode == false) result = c_ipshut (d_sid, SOCKET_SHUT_RECV);
-      if (mode == true)  result = c_ipshut (d_sid, SOCKET_SHUT_SEND);
+      if (mode == false) result = c_ipshut (d_sid, SHUT_RECV);
+      if (mode == true)  result = c_ipshut (d_sid, SHUT_SEND);
       unlock ();
       return result;
     } catch (...) {
@@ -250,30 +213,91 @@ namespace afnix {
     }
   }
 
+  // set a socket by parameters
+
+  bool Socket::setopt (const SockParams& prms) {
+    wrlock ();
+    try {
+      // preset result
+      bool result = true;
+      // check for reuse address
+      bool radr = prms.getbopt (SO_RADR);
+      if (radr == true) result = result && setopt (SO_RADR, radr);
+      // check for reuse port
+      bool rprt = prms.getbopt (SO_RPRT);
+      if (rprt == true) result = result && setopt (SO_RPRT, rprt);
+      // check for broadcast
+      bool bcst = prms.getbopt (SO_BCST);
+      if (bcst == true) result = result && setopt (SO_BCST, bcst);
+      // check for bypass routing table
+      bool dntr = prms.getbopt (SO_DNTR);
+      if (dntr == true) result = result && setopt (SO_DNTR, dntr);
+      // check for keepalve
+      bool kliv = prms.getbopt (SO_KLIV);
+      if (kliv == true) result = result && setopt (SO_KLIV, kliv);
+      // check for linger time
+      long ligt = prms.getlopt (SO_LIGT);
+      if (ligt != 0) result = result && setopt (SO_LIGT, ligt);
+      // check for receive buffer size
+      long rsiz = prms.getlopt (SO_RSIZ);
+      if (rsiz != 0) result = result && setopt (SO_RSIZ, rsiz);
+      // check for send size
+      long ssiz = prms.getlopt (SO_SSIZ);
+      if (ssiz != 0) result = result && setopt (SO_SSIZ, ssiz);
+      // check for sockethop limit
+      long shop = prms.getlopt (SO_SHOP);
+      if (shop != 0) result = result && setopt (SO_SHOP, shop);
+      // check for multicast lookpback
+      bool mlbk = prms.getbopt (SO_MLBK);
+      if (mlbk == true) result = result && setopt (SO_MLBK, mlbk);
+      // check for multicast hop limit
+      long mhop = prms.getlopt (SO_MHOP);
+      if (mhop != 0) result = result && setopt (SO_MHOP, mhop);
+      // check for segment size
+      long msiz = prms.getlopt (SO_MSIZ);
+      if (msiz != 0) result = result && setopt (SO_MSIZ, msiz);
+      // check for disable naggle algorithm
+      long ndly = prms.getbopt (SO_NDLY);
+      if (ndly == true) result = result && setopt (SO_NDLY, ndly);
+      // here it is
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // set a socket option
 
-  bool Socket::setopt (t_option opt, bool flag) {
+  bool Socket::setopt (const t_so opt, const bool val) {
     wrlock ();
     try {
       bool result = false;
       switch (opt) {
-      case SOCK_REUSEADDR:
-	result = c_ipsetopt (d_sid, SOCKET_REUSEADDR, flag, 0);
-	break;    
-      case SOCK_BROADCAST:
-	result = c_ipsetopt (d_sid, SOCKET_BROADCAST, flag, 0);
+      case SO_RADR:
+	result = c_ipsetopt (d_sid, SOPT_RADR, val);
 	break;
-      case SOCK_DONTROUTE:
-	result = c_ipsetopt (d_sid, SOCKET_DONTROUTE, flag, 0);
+      case SO_RPRT:
+	result = c_ipsetopt (d_sid, SOPT_RPRT, val);
 	break;
-      case SOCK_KEEPALIVE:
-	result = c_ipsetopt (d_sid, SOCKET_KEEPALIVE, flag, 0);
+      case SO_BCST:
+	result = c_ipsetopt (d_sid, SOPT_BCST, val);
 	break;
-      case SOCK_MCASTLOOP:
-	result = c_ipsetopt (d_sid, SOCKET_MCASTLOOP, flag, 0);
+      case SO_DNTR:
+	result = c_ipsetopt (d_sid, SOPT_DNTR, val);
 	break;
-      case SOCK_NODELAY:
-	result = c_ipsetopt (d_sid, SOCKET_NODELAY,   flag, 0);
+      case SO_KLIV:
+	result = c_ipsetopt (d_sid, SOPT_KLIV, val);
+	break;
+      case SO_LIGT:
+	result = c_ipsetopt (d_sid, SOPT_LIGT, val);
+	break;
+      case SO_MLBK:
+	result = c_ipsetopt (d_sid, SOPT_MLBK, val);
+	break;
+      case SO_NDLY:
+	result = c_ipsetopt (d_sid, SOPT_NDLY, val);
 	break;
       default:
 	break;
@@ -288,28 +312,28 @@ namespace afnix {
 
   // set a socket option with a value
 
-  bool Socket::setopt (t_option opt, bool flag, long val) {
+  bool Socket::setopt (const t_so opt, const long val) {
     wrlock ();
     try {
       bool result = false;
       switch (opt) {
-      case SOCK_LINGER:
-	result = c_ipsetopt (d_sid, SOCKET_LINGER,   flag, val);
+      case SO_LIGT:
+	result = c_ipsetopt (d_sid, SOPT_LIGT, val);
 	break;
-      case SOCK_RCVSIZE:
-	result = c_ipsetopt (d_sid, SOCKET_RCVSIZE,  flag, val);
+      case SO_RSIZ:
+	result = c_ipsetopt (d_sid, SOPT_RSIZ, val);
 	break;
-      case SOCK_SNDSIZE:
-	result = c_ipsetopt (d_sid, SOCKET_SNDSIZE,  flag, val);
+      case SO_SSIZ:
+	result = c_ipsetopt (d_sid, SOPT_SSIZ, val);
 	break;
-      case SOCK_HOPLIMIT:
-	result = c_ipsetopt (d_sid, SOCKET_HOPLIMIT, flag, val);
+      case SO_SHOP:
+	result = c_ipsetopt (d_sid, SOPT_SHOP, val);
 	break;
-      case SOCK_MCASTHOP:
-	result = c_ipsetopt (d_sid, SOCKET_MCASTHOP, flag, val);
+      case SO_MHOP:
+	result = c_ipsetopt (d_sid, SOPT_MHOP, val);
 	break;
-      case SOCK_MAXSEG:
-	result = c_ipsetopt (d_sid, SOCKET_MAXSEG,   flag, val);
+      case SO_MSIZ:
+	result = c_ipsetopt (d_sid, SOPT_MSIZ, val);
 	break;
       default:
 	break;
@@ -322,6 +346,94 @@ namespace afnix {
     }
   }
 
+  // get a boolean socket option
+
+  bool Socket::getbopt (const t_so opt) const {
+    rdlock ();
+    try {
+      bool result = false;
+      bool status = false;
+      switch (opt) {
+      case SO_RADR:
+	status = c_ipgetopt (d_sid, SOPT_RADR, result);
+	break;
+      case SO_RPRT:
+	status = c_ipgetopt (d_sid, SOPT_RPRT, result);
+	break;
+      case SO_BCST:
+	status = c_ipgetopt (d_sid, SOPT_BCST, result);
+	break;
+      case SO_DNTR:
+	status = c_ipgetopt (d_sid, SOPT_DNTR, result);
+	break;
+      case SO_KLIV:
+	result = c_ipgetopt (d_sid, SOPT_KLIV, result);
+	break;
+      case SO_LIGT:
+	status = c_ipgetopt (d_sid, SOPT_LIGT, result);
+	break;
+      case SO_MLBK:
+	status = c_ipgetopt (d_sid, SOPT_MLBK, result);
+	break;
+      case SO_NDLY:
+	status = c_ipgetopt (d_sid, SOPT_NDLY, result);
+	break;
+      default:
+	status = false;
+	break;
+      }
+      if (status == false) {
+	throw Exception ("socket-error", "cannot get boolean option");
+      }
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // get a socket option  value
+
+  long Socket::getlopt (const t_so opt) const {
+    wrlock ();
+    try {
+      long result = 0L;
+      bool status = false;
+      switch (opt) {
+      case SO_LIGT:
+	status = c_ipgetopt (d_sid, SOPT_LIGT, result);
+	break;
+      case SO_RSIZ:
+	status = c_ipgetopt (d_sid, SOPT_RSIZ, result);
+	break;
+      case SO_SSIZ:
+	status = c_ipgetopt (d_sid, SOPT_SSIZ, result);
+	break;
+      case SO_SHOP:
+	status = c_ipgetopt (d_sid, SOPT_SHOP, result);
+	break;
+      case SO_MHOP:
+	status = c_ipgetopt (d_sid, SOPT_MHOP, result);
+	break;
+      case SO_MSIZ:
+	status = c_ipgetopt (d_sid, SOPT_MSIZ, result);
+	break;
+      default:
+	status = false;
+	break;
+      }
+      if (status == false) {
+	throw Exception ("socket-error", "cannot get option value");
+      }
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // connect this socket by port and address
 
   bool Socket::connect (t_word port, const Address& addr) {
@@ -519,17 +631,15 @@ namespace afnix {
   // -------------------------------------------------------------------------
 
   // the quark zone
-  static const long QUARK_ZONE_LENGTH = 20;
+  static const long QUARK_ZONE_LENGTH = 13;
   static QuarkZone  zone (QUARK_ZONE_LENGTH);
   
   // the object supported quarks
   static const long QUARK_BIND      = zone.intern ("bind");
-  static const long QUARK_CLOSE     = zone.intern ("close");
   static const long QUARK_OPENP     = zone.intern ("open-p");
   static const long QUARK_IPV6P     = zone.intern ("ipv6-p");
   static const long QUARK_BCASTP    = zone.intern ("broadcast-p");
   static const long QUARK_CONNECT   = zone.intern ("connect");
-  static const long QUARK_SETEMOD   = zone.intern ("set-encoding-mode");
   static const long QUARK_GETPRTO   = zone.intern ("get-protocol");
   static const long QUARK_SHUTDOWN  = zone.intern ("shutdown");
   static const long QUARK_SOCKADDR  = zone.intern ("get-socket-address");
@@ -538,85 +648,32 @@ namespace afnix {
   static const long QUARK_PEERADDR  = zone.intern ("get-peer-address");
   static const long QUARK_PEERPORT  = zone.intern ("get-peer-port");
   static const long QUARK_PEERAUTH  = zone.intern ("get-peer-authority");
-  static const long QUARK_SETOPTION = zone.intern ("set-option");
-  static const long QUARK_SETIEMOD  = zone.intern ("set-input-encoding-mode");
-  static const long QUARK_GETIEMOD  = zone.intern ("get-input-encoding-mode");
-  static const long QUARK_SETOEMOD  = zone.intern ("set-output-encoding-mode");
-  static const long QUARK_GETOEMOD  = zone.intern ("get-output-encoding-mode");
-
-  // local quarks
-  static const long QUARK_GETEMOD   = String::intern ("get-encoding-mode");
 
   // return true if the given quark is defined
 
   bool Socket::isquark (const long quark, const bool hflg) const {
     rdlock ();
-    if (zone.exists (quark) == true) {
+    try {
+      if (zone.exists (quark) == true) {
+	unlock ();
+	return true;
+      }
+      bool result = hflg ? DupleixStream::isquark (quark, hflg) : false;
+      if (result == false) {
+	result = hflg ? Sockopt::isquark (quark, hflg) : false;
+      }
       unlock ();
-      return true;
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
     }
-    bool result = hflg ? InputStream::isquark (quark, hflg) : false;
-    if (result == false) {
-      result = hflg ? OutputStream::isquark (quark, hflg) : false;
-    }
-    unlock ();
-    return result;
-  }
-
-  // evaluate a quark statically
-
-  Object* Socket::meval (Runnable* robj, Nameset* nset, const long quark) {
-    if (quark == QUARK_REUSEADDR) 
-      return new Item (QUARK_SOCKET, QUARK_REUSEADDR);
-    if (quark == QUARK_BROADCAST) 
-      return new Item (QUARK_SOCKET, QUARK_BROADCAST);
-    if (quark == QUARK_DONTROUTE) 
-      return new Item (QUARK_SOCKET, QUARK_DONTROUTE);
-    if (quark == QUARK_MCASTLOOP) 
-      return new Item (QUARK_SOCKET, QUARK_MCASTLOOP);
-    if (quark == QUARK_KEEPALIVE) 
-      return new Item (QUARK_SOCKET, QUARK_KEEPALIVE);
-    if (quark == QUARK_LINGER)    
-      return new Item (QUARK_SOCKET, QUARK_LINGER);
-    if (quark == QUARK_RCVSIZE)   
-      return new Item (QUARK_SOCKET, QUARK_RCVSIZE);
-    if (quark == QUARK_SNDSIZE)   
-      return new Item (QUARK_SOCKET, QUARK_SNDSIZE);
-    if (quark == QUARK_HOPLIMIT)  
-      return new Item (QUARK_SOCKET, QUARK_HOPLIMIT);
-    if (quark == QUARK_MCASTHOP)  
-      return new Item (QUARK_SOCKET, QUARK_MCASTHOP);
-    if (quark == QUARK_MAXSEG) 
-      return new Item (QUARK_SOCKET, QUARK_MAXSEG);
-    if (quark == QUARK_NODELAY) 
-      return new Item (QUARK_SOCKET, QUARK_NODELAY);
-    throw Exception ("eval-error", "cannot evaluate member",
-		     String::qmap (quark));
   }
 
   // apply this object with a set of arguments and a quark
 
   Object* Socket::apply (Runnable* robj, Nameset* nset, const long quark,
 			 Vector* argv) {
-
-    // check the special quark first
-    if (quark == QUARK_SETIEMOD) {
-      return InputStream::apply (robj, nset, QUARK_SETEMOD, argv);
-    }
-    if (quark == QUARK_GETIEMOD) {
-      return InputStream::apply (robj, nset, QUARK_GETEMOD, argv);
-    }
-    if (quark == QUARK_SETOEMOD) {
-      return OutputStream::apply (robj, nset, QUARK_SETEMOD, argv);
-    }    
-    if (quark == QUARK_GETOEMOD) {
-      return OutputStream::apply (robj, nset, QUARK_GETEMOD, argv);
-    }
-    if (quark == QUARK_SETEMOD) {
-      Object::cref (InputStream::apply  (robj, nset, quark, argv));
-      Object::cref (OutputStream::apply (robj, nset, quark, argv));
-      return nilp;
-    }
     // get the number of arguments
     long argc = (argv == nilp) ? 0 : argv->length ();
 
@@ -630,7 +687,6 @@ namespace afnix {
       if (quark == QUARK_PEERPORT) return new Integer (getpeerport ());
       if (quark == QUARK_SOCKAUTH) return new String  (getsockauth ());
       if (quark == QUARK_PEERAUTH) return new String  (getpeerauth ());
-      if (quark == QUARK_CLOSE)    return new Boolean (close       ());
       if (quark == QUARK_SHUTDOWN) return new Boolean (shutdown    ());
       if (quark == QUARK_SOCKADDR) {
 	rdlock ();
@@ -688,36 +744,9 @@ namespace afnix {
 	connect (port, *addr);
 	return nilp;
       }
-      if (quark == QUARK_SETOPTION) {
-	Item* item = dynamic_cast <Item*> (argv->get (0));
-	if (item == nilp) throw Exception ("argument-error",
-					   "invalid object as socket option");
-	t_option opt = item_to_option (*item);
-	Object* obj = argv->get (1);
-	Boolean* bobj = dynamic_cast <Boolean*> (obj);
-	if (bobj != nilp) {
-	  bool flg = bobj->tobool ();
-	  return new Boolean (setopt (opt, flg));
-	}
-	Integer* iobj = dynamic_cast <Integer*> (obj);
-	if (iobj != nilp) {
-	  long val = iobj->tolong (); 
-	  return new Boolean (setopt (opt, true, val));
-	}
-	throw Exception ("argument-error", "invalid argument with set-option");
-      }
     }
     // dispatch 3 arguments
     if (argc == 3) {
-      if (quark == QUARK_SETOPTION) {
-	Item* item = dynamic_cast <Item*> (argv->get (0));
-	if (item == nilp) throw Exception ("argument-error",
-					   "invalid object as socket option");
-	t_option opt = item_to_option (*item);
-	bool flg = argv->getbool (1);
-	long val = argv->getlong (2);
-	return new Boolean (setopt (opt, flg, val));
-      }
       if (quark == QUARK_CONNECT) {
 	long port = argv->getlong (0);
 	Address* addr = dynamic_cast <Address*> (argv->get (1));
@@ -728,12 +757,12 @@ namespace afnix {
 	return nilp;
       }
     }
-    // check for input stream quark
-    if (InputStream::isquark (quark, true) == true)
-      return InputStream::apply (robj, nset, quark, argv);
-    // check for output stream quark
-    if (OutputStream::isquark (quark, true) == true)
-      return OutputStream::apply (robj, nset, quark, argv);
+    // check for dupleix stream quark
+    if (DupleixStream::isquark (quark, true) == true)
+      return DupleixStream::apply (robj, nset, quark, argv);
+    // check for a socket option
+    if (Sockopt::isquark (quark, true) == true)
+      return Sockopt::apply (robj, nset, quark, argv);
     // call the object method
     return Object::apply (robj, nset, quark, argv);
   }
