@@ -11,27 +11,20 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_SOCKET_HPP
 #define  AFNIX_SOCKET_HPP
 
-#ifndef  AFNIX_ADDRESS_HPP
-#include "Address.hpp"
+#ifndef  AFNIX_SOCKPARAMS_HPP
+#include "SockParams.hpp"
 #endif
 
-#ifndef  AFNIX_INPUTBUFFER_HPP
-#include "InputBuffer.hpp"
+#ifndef  AFNIX_DUPLEIXSTREAM_HPP
+#include "DupleixStream.hpp"
 #endif
 
-#ifndef  AFNIX_INPUTTIMEOPUT_HPP
-#include "InputTimeout.hpp"
-#endif
-
-#ifndef  AFNIX_OUTPUTSTREAM_HPP
-#include "OutputStream.hpp"
-#endif
 
 namespace afnix {
 
@@ -40,24 +33,7 @@ namespace afnix {
   /// and a stream descriptor. 
   /// @author amaury darsch
 
-  class Socket : public InputBuffer, public InputTimeout, public OutputStream {
-  public:
-    /// the socket options
-    enum t_option {
-      SOCK_REUSEADDR = 0,  // enable address reuse
-      SOCK_BROADCAST = 1,  // enable packet broadcast
-      SOCK_DONTROUTE = 2,  // bypass routing table
-      SOCK_KEEPALIVE = 3,  // set connection test
-      SOCK_LINGER    = 4,  // set linger time
-      SOCK_RCVSIZE   = 5,  // receive buffer size
-      SOCK_SNDSIZE   = 6,  // send buffer size
-      SOCK_HOPLIMIT  = 7,  // set hop limit
-      SOCK_MCASTLOOP = 8,  // multicast use lopback
-      SOCK_MCASTHOP  = 9, // multicast hop limit
-      SOCK_MAXSEG    = 10, // tcp maximum segment size
-      SOCK_NODELAY   = 11  // disable naggle algorithm
-    };
-
+  class Socket : public DupleixStream, public Sockopt {    
   protected:
     /// the socket descriptor
     int d_sid;
@@ -76,9 +52,36 @@ namespace afnix {
     /// @return the class name
     String repr (void) const;
 
+    /// close this socket
+    bool close (void);
+
     /// @return the stream descriptor
     int getsid (void) const;
 
+    /// set a socket option by parameter
+    /// @param prms the socket parameter
+    bool setopt (const SockParams& prms);
+
+    /// set a socket option
+    /// @param opt the socket option
+    /// @param val the option value
+    bool setopt (const t_so opt, const bool val);
+
+    /// set a socket option with a value
+    /// @param opt the socket option
+    /// @param val the value to set
+    bool setopt (const t_so opt, const long val);
+
+    /// get a socket option
+    /// @param opt the socket option
+    /// @param val the option value
+    bool getbopt (const t_so opt) const;
+
+    /// get a socket option with a value
+    /// @param opt the socket option
+    /// @param val the value to set
+    long getlopt (const t_so opt) const;
+    
     /// detach the stream descriptor
     virtual int detach (void);
 
@@ -91,9 +94,6 @@ namespace afnix {
     /// @return true if the socket is open
     virtual bool isopen (void) const;
 
-    /// close this socket
-    virtual bool close (void);
-
     /// force the socket to close
     virtual bool shutdown (void);
 
@@ -102,17 +102,6 @@ namespace afnix {
     /// @param mode the shutdown mode
     virtual bool shutdown (const bool mode);
 
-    /// set a socket option
-    /// @param opt  the socket option
-    /// @param flag the flag to set
-    virtual bool setopt (t_option opt, bool flag);
-
-    /// set a socket option with a value
-    /// @param opt  the socket option
-    /// @param flag the flag to set
-    /// @param val  the value to set
-    virtual bool setopt (t_option opt, bool val, long val1);
-
     /// connect this socket by port and address
     /// @param port the port use
     /// @apram addr the address to use
@@ -164,12 +153,6 @@ namespace afnix {
     /// @return true if the given quark is defined
     bool isquark (const long quark, const bool hflg) const;
 
-    /// evaluate an object data member
-    /// @param robj  robj the current runnable
-    /// @param nset  the current nameset    
-    /// @param quark the quark to evaluate
-    static Object* meval (Runnable* robj, Nameset* nset, const long quark);
-
     /// apply this object with a set of arguments and a quark
     /// @param robj  the current runnable
     /// @param nset  the current nameset    
