@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_TCPSERVER_HPP
@@ -32,44 +32,31 @@ namespace afnix {
   /// @author amaury darsch
 
   class TcpServer : public TcpSocket {
-  private:
-    /// the tcp backlog
-    long d_blog;
-
   public:
     /// create a default tcp server on a ephemeral port
     TcpServer (void);
 
+    /// create a tcp server by init flag
+    /// @param cflg the create flag
+    TcpServer (const bool cflg);
+    
     /// create a tcp server at specified port
     /// @param port the port to listen
-    TcpServer (t_word port);
-
-    /// create a tcp server with a certain backlog
-    /// @param port the port to listen
-    /// @param backlog the server backlog
-    TcpServer (t_word port, const long backlog);
+    TcpServer (const t_word port);
 
+    /// create a tcp server by parameters
+    /// @param prms the socket parameters
+    TcpServer (const SockParams& prms);
+    
     /// create a tcp server with a host and port
     /// @param host the host to bind the server
     /// @param port the port to listen
-    TcpServer (const String& host, t_word port);
+    TcpServer (const String& host, const t_word port);
 
     /// create a tcp server with an address and port
     /// @param addr the address to bind the server
     /// @param port the port to listen
-    TcpServer (const Address& addr, t_word port);
-
-    /// create a tcp server with a host, port and backlog
-    /// @param host the host to bind the server
-    /// @param port the port to listen
-    /// @param backlog the server backlog
-    TcpServer (const String& host, t_word port, const long backlog);
-
-    /// create a tcp server with an address, port and backlog
-    /// @param addr the address to bind the server
-    /// @param port the port to listen
-    /// @param backlog the server backlog
-    TcpServer (const Address& addr, t_word port, const long backlog);
+    TcpServer (const Address& addr, const t_word port);
 
     /// @return the class name
     String repr (void) const;
