@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Ascii.hpp"
@@ -34,8 +34,7 @@ namespace afnix {
   // create a default tcp socket
 
   TcpSocket::TcpSocket (void) {
-    d_sid = c_ipsocktcp ();
-    if (d_sid < 0) throw Exception ("tcp-error", c_errmsg (d_sid));
+    create ();
   }
 
   // create a socket by id 
@@ -48,10 +47,7 @@ namespace afnix {
   // create a tcp socket by flag
 
   TcpSocket::TcpSocket (const bool cflg) {
-    if (cflg == true) {
-      d_sid = c_ipsocktcp ();
-      if (d_sid < 0) throw Exception ("tcp-error", c_errmsg (d_sid));
-    }
+    if (cflg == true) create ();
   }
 
   // return the class name
@@ -247,12 +243,57 @@ namespace afnix {
     }
   }
 
+  // get the input stream channel
+  
+  InputStream* TcpSocket::getis (void) {
+    wrlock ();
+    try {
+      InputStream* result = new TcpSocket (c_dup (d_sid));
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // get the output stream channel
+  
+  OutputStream* TcpSocket::getos (void) {
+    wrlock ();
+    try {
+      OutputStream* result = new TcpSocket (c_dup (d_sid));
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // get the socket protocol
 
   String TcpSocket::getprotocol (void) const {
     return "tcp";
   }
 
+  // create a default socket
+
+  void TcpSocket::create (void) {
+    wrlock();
+    try {
+      if (d_sid != -1) {
+	throw Exception ("tcp-error", "existing socket with create");
+      }
+      d_sid = c_ipsocktcp ();
+      if (d_sid < 0) throw Exception ("tcp-error", c_errmsg (d_sid));
+      unlock ();
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // create a tcp socket by address family
 
   void TcpSocket::create (const Address& addr) {
