@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_TCPSOCKET_HPP
@@ -45,7 +45,7 @@ namespace afnix {
 
     /// @return the class name
     String repr (void) const;
-
+    
     /// @return true if we are at the eos
     bool iseos (void) const;
     
@@ -73,9 +73,18 @@ namespace afnix {
     /// @param size the number of character to write
     long write (const char* rbuf, const long size);
 
+    /// @return the input stream channel
+    InputStream* getis (void);
+
+    /// @return the output stream channel
+    OutputStream* getos (void);
+
     /// @retutn the socket protocol
     String getprotocol (void) const;
 
+    /// create a new default socket 
+    virtual void create (void);
+
     /// create a new socket by address familly
     /// @param addr the reference address
     virtual void create (const Address& addr);
