@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Ascii.hpp"
@@ -304,6 +304,34 @@ namespace afnix {
     }
   }
 
+  // get the input stream channel
+  
+  InputStream* UdpSocket::getis (void) {
+    wrlock ();
+    try {
+      InputStream* result = new UdpSocket (c_dup (d_sid));
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // get the output stream channel
+  
+  OutputStream* UdpSocket::getos (void) {
+    wrlock ();
+    try {
+      OutputStream* result = new UdpSocket (c_dup (d_sid));
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // get the socket protocol
 
   String UdpSocket::getprotocol (void) const {
