@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Aes.hpp"
@@ -544,7 +544,7 @@ namespace afnix {
 
   Aes::Aes (const Key& key) : BlockCipher (AES_ALGO_NAME, AES_BLOK_SIZE) {
     // initialize the cipher
-    d_rnum = aes_key_round (d_ckey);
+    d_rnum = aes_key_round (key);
     d_rksz = AES_STATE_LEN * (d_rnum + 1);
     p_rkey = new t_byte[d_rksz];
     // set the key
@@ -556,7 +556,7 @@ namespace afnix {
   Aes::Aes (const Key& key, 
 	    const bool rflg) : BlockCipher (AES_ALGO_NAME, AES_BLOK_SIZE) {
     // initialize the cipher
-    d_rnum = aes_key_round (d_ckey);
+    d_rnum = aes_key_round (key);
     d_rksz = AES_STATE_LEN * (d_rnum + 1);
     p_rkey = new t_byte[d_rksz];
     // set the key
