@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Item.hpp"
@@ -130,7 +130,7 @@ namespace afnix {
     }
     if (pcnt > 0) {
       // pad with the pad size
-      for (long i = size; i < bisz; i++) bi[i] = (t_byte) pcnt;
+      for (long i = size; i <= bisz; i++) bi[i] = (t_byte) pcnt;
       // mark as padded
       return true;
     }
@@ -558,6 +558,7 @@ namespace afnix {
       for (long i = cc; i < d_cbsz; i++) bi[i] = nilc;
       // check for padding
       bool padf = (cc < d_cbsz) ? bc_pad (d_pmod, bi, d_cbsz, cc) : false;
+      if (padf == true) cc = d_cbsz;
       // preprocess the block mode
       bc_pbi (d_cmod, true, bt, bi, p_bl, d_cbsz);
       // encode the block
