@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Cipher.hpp"
@@ -137,7 +137,10 @@ namespace afnix {
   long Cipher::stream (Buffer& ob, Buffer& ib) {
     wrlock ();
     try {
-      long result = d_rflg ? decode (ob, ib) : encode (ob, ib);
+      long result = 0L;
+      while (ib.empty() == false) {
+	result += d_rflg ? decode (ob, ib) : encode (ob, ib);
+      }
       unlock ();
       return result;
     } catch (...) {
