@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Real.hpp"
@@ -97,7 +97,9 @@ namespace afnix {
   // create a literal bundle by size
 
   Bundle::Bundle (const long size) {
-    if (size < 0L) throw Exception ("size-error","negative literal bundle size");
+    if (size < 0L) {
+      throw Exception ("size-error","negative literal bundle size");
+    }
     d_size = size;
     d_slen = 0;
     d_lidx = -1L;
@@ -205,7 +207,7 @@ namespace afnix {
       }
       d_size = 0L;
       d_slen = 0L;
-      d_lidx = 1L;
+      d_lidx = -1L;
       d_type = LSTK_OTHR;
       unlock ();
     } catch (...) {
@@ -220,24 +222,25 @@ namespace afnix {
     rdlock ();
     try {
       String result =  "";
-      if ((d_slen == 0) || (d_lidx == -1L)) {
+      if (d_slen == 0) {
 	unlock ();
 	return result;
       }
+      long lidx = (d_lidx == -1L) ? d_slen - 1L : d_lidx;
       if (d_type == LSTK_BOOL) {
-	Boolean bval = p_bstk[d_lidx];
+	Boolean bval = p_bstk[lidx];
 	result = bval.toliteral ();
       }
       if (d_type == LSTK_INTG) {
-	Integer ival = p_istk[d_lidx];
+	Integer ival = p_istk[lidx];
 	result = ival.toliteral ();
       }
       if (d_type == LSTK_REAL) {
-	Real rval = p_rstk[d_lidx];
+	Real rval = p_rstk[lidx];
 	result = rval.toliteral ();
       }
       if (d_type == LSTK_OTHR) {
-	Literal* lobj = p_lstk[d_lidx];
+	Literal* lobj = p_lstk[lidx];
 	if (lobj != nilp) result = lobj->toliteral ();
       }	  
       unlock ();
@@ -254,24 +257,25 @@ namespace afnix {
     rdlock ();
     try {
       String result =  "";
-      if ((d_slen == 0) || (d_lidx == -1L)) {
+      if (d_slen == 0) {
 	unlock ();
 	return result;
       }
+      long lidx = (d_lidx == -1L) ? d_slen - 1L : d_lidx;
       if (d_type == LSTK_BOOL) {
-	Boolean bval = p_bstk[d_lidx];
+	Boolean bval = p_bstk[lidx];
 	result = bval.tostring ();
       }
       if (d_type == LSTK_INTG) {
-	Integer ival = p_istk[d_lidx];
+	Integer ival = p_istk[lidx];
 	result = ival.tostring ();
       }
       if (d_type == LSTK_REAL) {
-	Real rval = p_rstk[d_lidx];
+	Real rval = p_rstk[lidx];
 	result = rval.tostring ();
       }
       if (d_type == LSTK_OTHR) {
-	Literal* lobj = p_lstk[d_lidx];
+	Literal* lobj = p_lstk[lidx];
 	if (lobj != nilp) result = lobj->tostring ();
       }	  
       unlock ();
@@ -288,16 +292,17 @@ namespace afnix {
     rdlock ();
     try {
       String result =  "";
-      if ((d_slen == 0) || (d_lidx == -1L)) {
+      if (d_slen == 0) {
 	unlock ();
 	return result;
       }
+      long lidx = (d_lidx == -1L) ? d_slen - 1L : d_lidx;
       if (d_type == LSTK_INTG) {
-	long ival = p_istk[d_lidx];
+	long ival = p_istk[lidx];
 	result = lstl.format (ival);
       }
       if (d_type == LSTK_REAL) {
-	t_real rval = p_rstk[d_lidx];
+	t_real rval = p_rstk[lidx];
 	result = lstl.format (rval);
       } else {
 	result = tostring ();
@@ -558,9 +563,10 @@ namespace afnix {
     wrlock ();
     try {
       if ((lidx < 0L) || (lidx >= d_slen)) {
-	throw Exception ("bundle-error", "invalid literal index in set");
+	d_lidx = -1L;
+      } else {
+	d_lidx = lidx;
       }
-      d_lidx = lidx;
       unlock ();
     } catch (...) {
       unlock ();
@@ -573,7 +579,7 @@ namespace afnix {
   long Bundle::getlidx (void) const {
     rdlock ();
     try {
-      long result = d_lidx;
+      long result = (d_lidx == -1L) ? (d_slen - 1L) : d_lidx;
       unlock ();
       return result;
     } catch (...) {
@@ -596,7 +602,6 @@ namespace afnix {
       // check if we have to resize the bundle
       if (d_slen + 1L >= d_size) resize (2 * d_size);
       p_bstk[d_slen++] = bval;
-      d_lidx++;
       unlock ();
     } catch (...) {
       unlock ();
@@ -618,7 +623,6 @@ namespace afnix {
       // check if we have to resize the bundle
       if (d_slen + 1L >= d_size) resize (2 * d_size);
       p_istk[d_slen++] = ival;
-      d_lidx++;
       unlock ();
     } catch (...) {
       unlock ();
@@ -640,7 +644,6 @@ namespace afnix {
       // check if we have to resize the bundle
       if (d_slen + 1L >= d_size) resize (2 * d_size);
       p_rstk[d_slen++] = rval;
-      d_lidx++;
       unlock ();
     } catch (...) {
       unlock ();
@@ -683,7 +686,6 @@ namespace afnix {
 	Literal* lobj = (lval == nilp) ? nilp :
 	  dynamic_cast <Literal*> (lval->clone ());
 	Object::iref (p_lstk[d_slen++] = lobj);
-	d_lidx++;
       } else {
 	// check inconsistent add
 	throw Exception ("bundle-error", "invalid object to add",
