@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_XMLNODE_HPP
@@ -45,6 +45,8 @@ namespace afnix {
 
   class XmlNode : public Collectable {
   protected:
+    /// the confine pointer
+    void*   p_cptr;
     /// the empty flag
     bool     d_eflg;
     /// the eol flag
@@ -228,9 +230,9 @@ namespace afnix {
 
   private:
     // make the copy constructor private
-    XmlNode (const XmlNode&);
+    XmlNode (const XmlNode&) =delete;
     // make the assignment operator private
-    XmlNode& operator = (const XmlNode&);
+    XmlNode& operator = (const XmlNode&) =delete;
 
   public:
     /// @return true if the given quark is defined
