@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_LOCALIZER_HPP
@@ -55,6 +55,10 @@ namespace afnix {
 
     /// @return the localization method
     virtual t_lmth getlmth (void) const;
+
+    /// validate a localized position
+    /// @param pval the position value
+    virtual bool validate (const t_real pval) const;
     
     /// locate by boolean argument
     /// @param pval the position value
