@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_SAMPLER_HPP
@@ -64,15 +64,19 @@ namespace afnix {
     /// @return the streamable object
     virtual Streamable* getsobj (void) const;
 
+    /// validate a localized position
+    /// @param pval the position value
+    virtual bool validate (const t_real pval) const;
+    
     /// sample a boolean by boolean
     /// @param pval the position value
     virtual bool mapbool (const bool pval);
     
-    /// sample a real by integer
+    /// sample a boolean by integer
     /// @param pval the position value
     virtual bool mapbool (const long pval);
     
-    /// sample a real by real
+    /// sample a boolean by real
     /// @param pval the position value
     virtual bool mapbool (const t_real pval);
 
@@ -80,11 +84,11 @@ namespace afnix {
     /// @param pval the position value
     virtual long maplong (const bool pval);
     
-    /// sample an integer  by integer
+    /// sample an integer by integer
     /// @param pval the position value
     virtual long maplong (const long pval);
     
-    /// sample an integer  by real
+    /// sample an integer by real
     /// @param pval the position value
     virtual long maplong (const t_real pval);
     
