@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Cart.hpp"
@@ -53,7 +53,7 @@ namespace afnix {
   void Cart::reset (void) {
     wrlock ();
     try {
-      d_cos.reset ();
+      d_cas.reset ();
       unlock ();
     } catch (...) {
       unlock ();
@@ -102,12 +102,12 @@ namespace afnix {
     }
   }
 
-  // get the number of rco in the cart
+  // get the number of agent in the cart
 
   long Cart::length (void) const {
     rdlock ();
     try {
-      long result = d_cos.length ();
+      long result = d_cas.length ();
       unlock ();
       return result;
     } catch (...) {
@@ -121,7 +121,7 @@ namespace afnix {
   bool Cart::empty (void) const {
     rdlock ();
     try {
-      bool result = d_cos.empty ();
+      bool result = d_cas.empty ();
       unlock ();
       return result;
     } catch (...) {
@@ -130,27 +130,27 @@ namespace afnix {
     }
   }
 
-  // check if an rco exists in this cart
+  // check if an agent exists in this cart
 
   bool Cart::exists (const t_long kid) const {
     rdlock ();
     try {
       // check the key id
       if (kid <= 0LL) {
-	throw Exception ("cart-error", "invalid rco key id to validate");
+	throw Exception ("cart-error", "invalid agent key id to validate");
       }
       // get the set length
-      long slen = d_cos.length ();
+      long slen = d_cas.length ();
       // loop in the set
       for (long i = 0; i < slen; i++) {
-	Object* obj = d_cos.get (i);
-	Rco*    rco = dynamic_cast <Rco*> (obj);
-	if (rco == nilp) {
+	Object* obj = d_cas.get (i);
+	Agent*  agt = dynamic_cast <Agent*> (obj);
+	if (agt == nilp) {
 	  throw Exception ("internal-error", "invalid object in cart",
 			   Object::repr (obj));
 	}
 	// check for valid key id
-	if (rco->iskid (kid) == true) {
+	if (agt->iskid (kid) == true) {
 	  unlock ();
 	  return true;
 	}
@@ -163,37 +163,39 @@ namespace afnix {
     }
   }
 
-  // get a rco at position
+  // get an agent  at position
 
-  Rco Cart::getat (const long idx) const {
+  Agent* Cart::getat (const long idx) const {
     rdlock ();
     try {
-      Rco* rco = dynamic_cast <Rco*> (d_cos.get (idx));
-      if (rco == nilp) {
+      Agent* agt = dynamic_cast <Agent*> (d_cas.get (idx));
+      if (agt == nilp) {
 	throw Exception ("internal-error", "invalid object in cart");
       }
-      Rco result = *rco;
       unlock ();
-      return result;
+      return agt;
     } catch (...) {
       unlock ();
       throw;
     }
   }
 
-  // add a rco in this cart
+  // add a agent in this cart
 
-  t_long Cart::addrco (const Rco& rco) {
+  t_long Cart::addagt (Agent* agt) {
     wrlock ();
     try {
-      // get the rco rid and validate
-      String rid = rco.getrid ();
+      if (agt == nilp) {
+	throw Exception ("cart-error", "invalid nil agent toadd");
+      }
+      // get the agent rid and validate
+      String rid = agt->getrid ();
       if ((d_rid.isnil () == false) && (d_rid != rid)) {
 	throw Exception ("cart-error", 
 			 "invalid rid for registered cart", rid);
       }
-      // get the rco key id and check
-      t_long kid = rco.getkid ();
+      // get the agent key id and check
+      t_long kid = agt->getkid ();
       if (kid <= 0LL) {
 	// generate a unique id
 	kid = System::uniqid ();
@@ -201,34 +203,17 @@ namespace afnix {
 	if (exists (kid) == true) {
 	  throw Exception ("internal-error", "duplicate unique id found");
 	}
-	// create a copy of this rco with a key id
-	Rco* co = new Rco (rco); co->setkid (kid);
+	// create a copy of this agent with a key id
+	Agent* ao = dynamic_cast<Agent*>(agt->clone()); ao->setkid (kid);
 	// add the object in the set
-	d_cos.add (co);
+	d_cas.add (ao);
       } else {
-	// check if the rco exists
+	// check if the agent exists
 	if (exists (kid) == false) {
-	  // create a copy of this rco with a key id
-	  Rco* co = new Rco (rco);
+	  // create a copy of this agent with a key id
+	  Agent* ao = dynamic_cast<Agent*>(agt->clone());
 	  // add the object in the set
-	  d_cos.add (co);
-	} else {
-	  // find the rco in the set by index
-	  long slen = d_cos.length ();
-	  // loop in the set
-	  for (long i = 0; i < slen; i++) {
-	    Object* obj = d_cos.get (i);
-	    Rco*     co = dynamic_cast <Rco*> (obj);
-	    if (co == nilp) {
-	      throw Exception ("internal-error", "invalid object in cart",
-			       Object::repr (obj));
-	    }
-	    // check for valid key id
-	    if (co->iskid (kid) == true) {
-	      *co = rco;
-	      break;
-	    }
-	  }
+	  d_cas.add (ao);
 	}
       }
       unlock ();
@@ -239,30 +224,29 @@ namespace afnix {
     }
   }
 
-  // get a rco object by key id
+  // get a agent object by key id
 
-  Rco Cart::getrco (const t_long kid) const {
+  Agent* Cart::getagt (const t_long kid) const {
     rdlock ();
     try {
       // check the key id
       if (kid <= 0LL) {
-	throw Exception ("cart-error", "invalid rco key id to validate");
+	throw Exception ("cart-error", "invalid agent key id to validate");
       }
       // get the set length
-      long slen = d_cos.length ();
+      long slen = d_cas.length ();
       // loop in the set
       for (long i = 0; i < slen; i++) {
-	Object* obj = d_cos.get (i);
-	Rco*    rco = dynamic_cast <Rco*> (obj);
-	if (rco == nilp) {
+	Object* obj = d_cas.get (i);
+	Agent*  agt = dynamic_cast <Agent*> (obj);
+	if (agt == nilp) {
 	  throw Exception ("internal-error", "invalid object in cart",
 			   Object::repr (obj));
 	}
 	// check for valid key id
-	if (rco->iskid (kid) == true) {
-	  Rco result = *rco;
+	if (agt->iskid (kid) == true) {
 	  unlock ();
-	  return result;
+	  return agt;
 	}
       }
       // not found
@@ -284,13 +268,13 @@ namespace afnix {
   // the object supported quarks
   static const long QUARK_RESET   = zone.intern ("reset");
   static const long QUARK_GETAT   = zone.intern ("get-at");
-  static const long QUARK_ADDRCO  = zone.intern ("add-rco");
-  static const long QUARK_GETRCO  = zone.intern ("get-rco");
   static const long QUARK_LENGTH  = zone.intern ("length");
   static const long QUARK_ISRIDP  = zone.intern ("rid-p");
   static const long QUARK_SETRID  = zone.intern ("set-rid");
   static const long QUARK_GETRID  = zone.intern ("get-rid");
   static const long QUARK_EMPTYP  = zone.intern ("empty-p");
+  static const long QUARK_ADDAGT  = zone.intern ("add-agent");
+  static const long QUARK_GETAGT  = zone.intern ("get-agent");
   static const long QUARK_EXISTSP = zone.intern ("exists-p");
 
   // create a new object in a generic way
@@ -340,23 +324,41 @@ namespace afnix {
     }
     // check for 1 argument
     if (argc == 1) {
-      if (quark == QUARK_ADDRCO) {
+      if (quark == QUARK_ADDAGT) {
 	Object* obj = argv->get (0);
-	Rco*    rco = dynamic_cast <Rco*> (obj);
-	if (rco == nilp) {
+	Agent*  agt = dynamic_cast <Agent*> (obj);
+	if (agt == nilp) {
 	  throw Exception ("type-error", "invalid object with cart add",
 			   Object::repr (obj));
 	}
-	t_long result = addrco (*rco);
+	t_long result = addagt (agt);
 	return new Integer (result);
       }
       if (quark == QUARK_GETAT) {
 	long idx = argv->getlong (0);
-	return new Rco (getat (idx));
+	rdlock ();
+	try {
+	  Object* result = getat (idx);
+	  robj->post (result);
+	  unlock ();
+	  return result;
+	} catch (...) {
+	  unlock ();
+	  throw;
+	}
       }
-      if (quark == QUARK_GETRCO) {
+      if (quark == QUARK_GETAGT) {
 	t_long kid = argv->getlong (0);
-	return new Rco (getrco (kid));
+	rdlock ();
+	try {
+	  Object* result = getagt (kid);
+	  robj->post (result);
+	  unlock ();
+	  return result;
+	} catch (...) {
+	  unlock ();
+	  throw;
+	}
       }
       if (quark == QUARK_ISRIDP) {
 	String rid = argv->getstring (0);
