@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_CART_HPP
@@ -21,24 +21,24 @@
 #include "Set.hpp"
 #endif
 
-#ifndef  AFNIX_RCO_HPP
-#include "Rco.hpp"
+#ifndef  AFNIX_AGENT_HPP
+#include "Agent.hpp"
 #endif
 
 namespace afnix {
 
-  /// The Cart class is the local cloud object set. The class is designed
-  /// to store registered cloud object (rco). The implementation is primarily
+  /// The Cart class is the local cloud agent set. The class is designed
+  /// to store registered agent objects. The implementation is primarily
   /// designed to store a unique form of objects and provides the necessary
   /// mechanism to retrieve an object by key id. A cart can store
-  /// any kind of cloud object as long as its registration id is null. If
-  /// the registration id is defined, the rco id must be the same.
+  /// any kind of agent object as long as its registration id is null. If
+  /// the registration id is defined, the agent id must be the same.
   /// @author amaury darsch
 
   class Cart : public virtual Object {
   protected:
-    /// the cart object set
-    Set    d_cos;
+    /// the cart agent set
+    Set d_cas;
     /// the registration id
     String d_rid;
 
@@ -67,26 +67,26 @@ namespace afnix {
     /// @return the registration id
     virtual String getrid (void) const;
 
-    /// @return the number of rco in the cart
+    /// @return the number of agent in the cart
     virtual long length (void) const;
 
     /// @return true if the cart is empty
     virtual bool empty (void) const;
 
-    /// @return true if an rco exists in the set
+    /// @return true if an agent exists in the set
     virtual bool exists (const t_long kid) const;
 
-    /// get a rco at position
-    /// @param idx the rco position index
-    virtual Rco getat (const long idx) const;
+    /// get a agent at position
+    /// @param idx the agent position index
+    virtual Agent* getat (const long idx) const;
 
-    /// add a rco in this cart
-    /// @param rco the rco to add
-    virtual t_long addrco (const Rco& rco);
+    /// add a agent in this cart
+    /// @param agent the agent to add
+    virtual t_long addagt (Agent* agt);
 
-    /// get a rco by key id
+    /// get a agent by key id
     /// @param kid the key id
-    virtual Rco getrco (const t_long kid) const;
+    virtual Agent* getagt (const t_long kid) const;
 
   private:
     // make the copy constructor private
