@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Vector.hpp"
@@ -132,20 +132,23 @@ namespace afnix {
     }
   }
 
-  // add a rco in the cart set
+  // add a agent in the cart set
 
-  t_long CartSet::addrco (const Rco& rco) {
+  t_long CartSet::addagt (Agent* agt) {
     wrlock ();
     try {
-      // get the rco rid
-      String rid = rco.getrid ();
+      if (agt == nilp) {
+	throw Exception ("cartset-error", "cannot add nil agent");
+      }
+      // get the agent rid
+      String rid = agt->getrid ();
       if (rid.isnil () == true) {
 	// check for valid anonymous
 	if (d_acf == false) {
-	  throw Exception ("cart set-error", "invalid anonymous rco to add");
+	  throw Exception ("cartset-error", "invalid anonymous agent to add");
 	}
-	// add the rco and return
-	t_long result = d_aco.addrco (rco);
+	// add the agent and return
+	t_long result = d_aco.addagt (agt);
 	unlock ();
 	return result;
       }
@@ -155,8 +158,8 @@ namespace afnix {
 	lco = new Cart (rid);
 	d_lht.add (rid, lco);
       }
-      // add the rco in the cart
-      t_long result = lco->addrco (rco);
+      // add the agent in the cart
+      t_long result = lco->addagt (agt);
       unlock ();
       return result;
     } catch (...) {
@@ -165,20 +168,20 @@ namespace afnix {
     }
   }
 
-  // get a rco by rid and index
+  // get a agent by rid and index
 
-  Rco CartSet::getrco (const String& rid, const t_long kid) const {
+  Agent* CartSet::getagt (const String& rid, const t_long kid) const {
     rdlock ();
     try {
       // check for anonymous
       if (rid.isnil () == true) {
 	// check for valid anonymous
 	if (d_acf == false) {
-	  throw Exception ("cart set-error", "invalid anonymous rco query");
+	  throw Exception ("cart set-error", "invalid anonymous agent query");
 	}
-	Rco rco = d_aco.getrco (kid);
+	Agent* agt = d_aco.getagt (kid);
 	unlock ();
-	return rco;
+	return agt;
       }
       // find the cart by rid
       Cart* lco = dynamic_cast <Cart*> (d_lht.lookup (rid));
@@ -186,9 +189,9 @@ namespace afnix {
 	throw Exception ("internal-error", "invalid nil cart in lookup");
       }
       // get the rco by index
-      Rco rco = lco->getrco (kid);
+      Agent* agt = lco->getagt (kid);
       unlock ();
-      return rco;
+      return agt;
     } catch (...) {
       unlock ();
       throw;
@@ -200,17 +203,17 @@ namespace afnix {
   // -------------------------------------------------------------------------
 
   // the quark zone
-  static const long QUARK_ZONE_LENGTH = 6;
+  static const long QUARK_ZONE_LENGTH = 7;
   static QuarkZone  zone (QUARK_ZONE_LENGTH);
 
   // the object supported quarks
   static const long QUARK_GET     = zone.intern ("get");
-  static const long QUARK_ADDRCO  = zone.intern ("add-rco");
-  static const long QUARK_GETRCO  = zone.intern ("get-rco");
   static const long QUARK_LOOKUP  = zone.intern ("lookup");
   static const long QUARK_LENGTH  = zone.intern ("length");
   static const long QUARK_EMPTYP  = zone.intern ("empty-p");
   static const long QUARK_EXISTSP = zone.intern ("exists-p");
+  static const long QUARK_ADDAGT  = zone.intern ("add-agent");
+  static const long QUARK_GETAGT  = zone.intern ("get-agent");
 
   // create a new object in a generic way
 
@@ -231,13 +234,18 @@ namespace afnix {
 
   bool CartSet::isquark (const long quark, const bool hflg) const {
     rdlock ();
-    if (zone.exists (quark) == true) {
+    try {
+      if (zone.exists (quark) == true) {
+	unlock ();
+	return true;
+      }
+      bool result = hflg ? Object::isquark (quark, hflg) : false;
       unlock ();
-      return true;
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
     }
-    bool result = hflg ? Object::isquark (quark, hflg) : false;
-    unlock ();
-    return result;
   }
   
   // apply this object with a set of arguments and a quark
@@ -252,20 +260,20 @@ namespace afnix {
     if (quark == QUARK_LENGTH) return new Integer (length ());
     // check for 1 argument
     if (argc == 1) {
-      if (quark == QUARK_ADDRCO) {
+      if (quark == QUARK_ADDAGT) {
 	Object* obj = argv->get (0);
-	Rco*    rco = dynamic_cast <Rco*> (obj);
-	if (rco == nilp) {
+	Agent*  agt = dynamic_cast <Agent*> (obj);
+	if (agt == nilp) {
 	  throw Exception ("type-error", "invalid object with cart set add",
 			   Object::repr (obj));
 	}
-	t_long result = addrco (*rco);
+	t_long result = addagt (agt);
 	return new Integer (result);
       }
       if (quark == QUARK_GET) {
+	long idx = argv->getlong (0);
 	rdlock ();
 	try {
-	  long idx = argv->getlong (0);
 	  Cart* lco = get (idx);
 	  robj->post (lco);
 	  unlock ();
@@ -276,9 +284,9 @@ namespace afnix {
 	}
       }
       if (quark == QUARK_LOOKUP) {
+	String rid = argv->getstring (0);
 	rdlock ();
 	try {
-	  String rid = argv->getstring (0);
 	  Cart* lco = lookup (rid);
 	  robj->post (lco);
 	  unlock ();
@@ -295,10 +303,18 @@ namespace afnix {
     }
     // check for 2 arguments
     if (argc == 2) {
-      if (quark == QUARK_GETRCO) {
+      if (quark == QUARK_GETAGT) {
 	String rid = argv->getstring (0);
 	t_long kid = argv->getlong (1);
-	return new Rco (getrco (rid, kid));
+	try {
+	  Object* result = getagt (rid, kid);
+	  robj->post (result);
+	  unlock ();
+	  return result;
+	} catch (...) {
+	  unlock();
+	  throw;
+	}
       }
     }
     // call the object method
