@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_CARTSET_HPP
@@ -75,14 +75,14 @@ namespace afnix {
     /// @param rid the cart rid to find
     virtual Cart* lookup (const String& rid) const;
 
-    /// add a rco in this cart set
-    /// @param rco the rco to add
-    virtual t_long addrco (const Rco& rco);
+    /// add a agent in this cart set
+    /// @param agt the agent to add
+    virtual t_long addagt (Agent* agt);
 
-    /// get a rco by key and registration id 
+    /// get a agent by key and registration id 
     /// @param rid the cart rid
-    /// @param kid the rco key id
-    virtual Rco getrco (const String& rid, const t_long kid) const;
+    /// @param kid the agent key id
+    virtual Agent* getagt (const String& rid, const t_long kid) const;
 
   private:
     // make the copy constructor private
