@@ -11,10 +11,9 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
-#include "Ico.hpp"
 #include "Saas.hpp"
 #include "Meta.hpp"
 #include "Libcsm.hpp"
@@ -22,6 +21,7 @@
 #include "Predcsm.hpp"
 #include "CsmCalls.hpp"
 #include "Function.hpp"
+#include "Delegate.hpp"
 #include "Assistant.hpp"
 #include "SessionSet.hpp"
 #include "LocalSpace.hpp"
@@ -39,27 +39,29 @@ namespace afnix {
     Nameset* gset = aset->mknset   ("csm");
 
     // bind all symbols in the afnix:csm nameset
-    gset->symcst ("Rco",              new Meta (Rco::mknew));
-    gset->symcst ("Ico",              new Meta (Ico::mknew));
     gset->symcst ("Slot",             new Meta (Slot::mknew));
     gset->symcst ("Saas",             new Meta (Saas::mknew));
     gset->symcst ("Cart",             new Meta (Cart::mknew));
+    gset->symcst ("Agent",            new Meta (Agent::mknew));
+    gset->symcst ("Carrier",          new Meta (Carrier::mknew));
     gset->symcst ("CartSet",          new Meta (CartSet::mknew));
     gset->symcst ("Session",          new Meta (Session::mknew));
+    gset->symcst ("Delegate",         new Meta (Delegate::mknew));
     gset->symcst ("Appointer",        new Meta (Appointer::mknew));
     gset->symcst ("Assistant",        new Meta (Assistant::mknew));
     gset->symcst ("SessionSet",       new Meta (SessionSet::mknew));
     gset->symcst ("LocalSpace",       new Meta (LocalSpace::mknew));
 
     // bind the predicates
-    gset->symcst ("rco-p",            new Function (csm_rcop));
-    gset->symcst ("ico-p",            new Function (csm_icop));
     gset->symcst ("slot-p",           new Function (csm_slotp));
-    gset->symcst ("xaas-p",           new Function (csm_xaasp));
+    gset->symcst ("raas-p",           new Function (csm_raasp));
     gset->symcst ("saas-p",           new Function (csm_saasp));
     gset->symcst ("cart-p",           new Function (csm_cartp));
+    gset->symcst ("agent-p",          new Function (csm_agtp));
+    gset->symcst ("carrier-p",        new Function (csm_cagtp));
     gset->symcst ("session-p",        new Function (csm_sessp));
     gset->symcst ("cart-set-p",       new Function (csm_csetp));
+    gset->symcst ("delegate-p",       new Function (csm_dagtp));
     gset->symcst ("appointer-p",      new Function (csm_apptp));
     gset->symcst ("workspace-p",      new Function (csm_wspcp));
     gset->symcst ("assistant-p",      new Function (csm_asstp));
