@@ -11,15 +11,15 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
-#include "Ico.hpp"
 #include "Cons.hpp"
 #include "Saas.hpp"
 #include "CartSet.hpp"
 #include "Predcsm.hpp"
 #include "Boolean.hpp"
+#include "Delegate.hpp"
 #include "Assistant.hpp"
 #include "Exception.hpp"
 #include "SessionSet.hpp"
@@ -39,24 +39,33 @@ namespace afnix {
     return (car == nilp) ? nilp : car->eval (robj,nset);
   }
 
-  // rcop: rco object predicate
+  // agtp: agent object predicate
 
-  Object* csm_rcop  (Runnable* robj, Nameset* nset, Cons* args) {
-    Object* obj = get_obj (robj, nset, args, "rco-p");
-    bool result = (dynamic_cast <Rco*> (obj) == nilp) ? false : true;
+  Object* csm_agtp  (Runnable* robj, Nameset* nset, Cons* args) {
+    Object* obj = get_obj (robj, nset, args, "agent-p");
+    bool result = (dynamic_cast <Agent*> (obj) == nilp) ? false : true;
     Object::cref (obj);
     return new Boolean (result);
   }
+  
+  // cagtp: carrier agent object predicate
 
-  // icop: rco object predicate
-
-  Object* csm_icop  (Runnable* robj, Nameset* nset, Cons* args) {
-    Object* obj = get_obj (robj, nset, args, "ico-p");
-    bool result = (dynamic_cast <Ico*> (obj) == nilp) ? false : true;
+  Object* csm_cagtp  (Runnable* robj, Nameset* nset, Cons* args) {
+    Object* obj = get_obj (robj, nset, args, "carrier-p");
+    bool result = (dynamic_cast <Carrier*> (obj) == nilp) ? false : true;
     Object::cref (obj);
     return new Boolean (result);
   }
+  
+  // dagtp: delegate agent object predicate
 
+  Object* csm_dagtp  (Runnable* robj, Nameset* nset, Cons* args) {
+    Object* obj = get_obj (robj, nset, args, "delegate-p");
+    bool result = (dynamic_cast <Delegate*> (obj) == nilp) ? false : true;
+    Object::cref (obj);
+    return new Boolean (result);
+  }
+  
   // cartp: cart object predicate
 
   Object* csm_cartp  (Runnable* robj, Nameset* nset, Cons* args) {
@@ -139,11 +148,11 @@ namespace afnix {
     return new Boolean (result);
   }
 
-  // xaas: xaas predicate
+  // raas: raas predicate
 
-  Object* csm_xaasp  (Runnable* robj, Nameset* nset, Cons* args) {
-    Object* obj = get_obj (robj, nset, args, "xaas-p");
-    bool result = (dynamic_cast <Xaas*> (obj) == nilp) ? false : true;
+  Object* csm_raasp  (Runnable* robj, Nameset* nset, Cons* args) {
+    Object* obj = get_obj (robj, nset, args, "raas-p");
+    bool result = (dynamic_cast <Raas*> (obj) == nilp) ? false : true;
     Object::cref (obj);
     return new Boolean (result);
   }
