@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_PREDCSM_HPP
@@ -27,18 +27,24 @@ namespace afnix {
   /// standard service.
   /// @author amaury darsch
 
-  /// the rco object predicate
+  /// the agent object predicate
   /// @param robj the current runnable
   /// @param nset the current nameset
   /// @param args the arguments list
-  Object* csm_rcop (Runnable* robj, Nameset* nset, Cons* args);
+  Object* csm_agtp (Runnable* robj, Nameset* nset, Cons* args);
 
-  /// the ico object predicate
+  /// the carrier agent object predicate
   /// @param robj the current runnable
   /// @param nset the current nameset
   /// @param args the arguments list
-  Object* csm_icop (Runnable* robj, Nameset* nset, Cons* args);
+  Object* csm_cagtp (Runnable* robj, Nameset* nset, Cons* args);
 
+  /// the delegate agent object predicate
+  /// @param robj the current runnable
+  /// @param nset the current nameset
+  /// @param args the arguments list
+  Object* csm_dagtp (Runnable* robj, Nameset* nset, Cons* args);
+  
   /// the cart object predicate
   /// @param robj the current runnable
   /// @param nset the current nameset
@@ -93,11 +99,11 @@ namespace afnix {
   /// @param args the arguments list
   Object* csm_lspcp (Runnable* robj, Nameset* nset, Cons* args);
 
-  /// the xaas object predicate
+  /// the raas object predicate
   /// @param robj the current runnable
   /// @param nset the current nameset
   /// @param args the arguments list
-  Object* csm_xaasp (Runnable* robj, Nameset* nset, Cons* args);
+  Object* csm_raasp (Runnable* robj, Nameset* nset, Cons* args);
 
   /// the saas object predicate
   /// @param robj the current runnable
