@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Uri.hpp"
@@ -52,7 +52,7 @@ namespace afnix {
   
   // create a service by name
 
-  Saas::Saas (const String& name) : Xaas (name) {
+  Saas::Saas (const String& name) : Raas (name) {
     Plist::add (SAAS_HOST_NAME, SAAS_HOST_INFO, SAAS_HOST_XDEF);
     Plist::add (SAAS_PORT_NAME, SAAS_PORT_INFO, (t_long) SAAS_PORT_XDEF);
     Plist::add (SAAS_PRTO_NAME, SAAS_PRTO_INFO, SAAS_PRTO_XDEF);
@@ -60,7 +60,7 @@ namespace afnix {
 
   // create a service by name and info
 
-  Saas::Saas (const String& name, const String& info) : Xaas (name, info) {
+  Saas::Saas (const String& name, const String& info) : Raas (name, info) {
     Plist::add (SAAS_HOST_NAME, SAAS_HOST_INFO, SAAS_HOST_XDEF);
     Plist::add (SAAS_PORT_NAME, SAAS_PORT_INFO, (t_long) SAAS_PORT_XDEF);
     Plist::add (SAAS_PRTO_NAME, SAAS_PRTO_INFO, SAAS_PRTO_XDEF);
@@ -68,7 +68,7 @@ namespace afnix {
 
   // create a service by plist
 
-  Saas::Saas (const Plist& plst) : Xaas (plst) {
+  Saas::Saas (const Plist& plst) : Raas (plst) {
     if (plst.exists (SAAS_HOST_NAME) == false) sethost (SAAS_HOST_XDEF);
     if (plst.exists (SAAS_PORT_NAME) == false) setport (SAAS_PORT_XDEF);
     if (plst.exists (SAAS_PRTO_NAME) == false) setprto (SAAS_PRTO_XDEF);
@@ -80,7 +80,7 @@ namespace afnix {
     that.rdlock ();
     try {
       // copy the base service
-      Xaas::operator = (that);
+      Raas::operator = (that);
       that.unlock ();
     } catch (...) {
       that.unlock ();
@@ -98,7 +98,7 @@ namespace afnix {
     that.rdlock ();
     try {
       // copy the base service
-      Xaas::operator = (that);
+      Raas::operator = (that);
       unlock ();
       that.unlock ();
       return *this;
@@ -284,7 +284,7 @@ namespace afnix {
       unlock ();
       return true;
     }
-    bool result = hflg ? Xaas::isquark (quark, hflg) : false;
+    bool result = hflg ? Raas::isquark (quark, hflg) : false;
     unlock ();
     return result;
   }
@@ -328,7 +328,7 @@ namespace afnix {
 	return new Boolean (isauth (*xas));
       }		   
     }
-    // call the xaas methods
-    return Xaas::apply (robj, nset, quark, argv);
+    // call the raas methods
+    return Raas::apply (robj, nset, quark, argv);
   }
 }
