@@ -11,14 +11,14 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_SAAS_HPP
 #define  AFNIX_SAAS_HPP
 
-#ifndef  AFNIX_XAAS_HPP
-#include "Xaas.hpp"
+#ifndef  AFNIX_RAAS_HPP
+#include "Raas.hpp"
 #endif
 
 namespace afnix {
@@ -29,7 +29,7 @@ namespace afnix {
   /// is validated afetr a succesfull capability query.
   /// @author amaury darsch
 
-  class Saas : public Xaas {
+  class Saas : public Raas {
   public:
     /// create a service by name
     /// @param name he service name
