@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Meta.hpp"
@@ -55,6 +55,7 @@ namespace afnix {
     gset->symcst ("TlsServer",          new Meta (TlsServer::mknew));
     gset->symcst ("TlsShello",          new Meta (TlsShello::mknew));
     gset->symcst ("TlsChello",          new Meta (TlsChello::mknew));
+    gset->symcst ("TlsDupleix",         new Meta (TlsDupleix::mknew));
     gset->symcst ("TlsConnect",         new Meta (TlsConnect::mknew));
     gset->symcst ("TlsMessage",         new Meta (TlsMessage::mknew));
 
@@ -69,8 +70,8 @@ namespace afnix {
     gset->symcst ("params-p",           new Function (tls_prmp));
     gset->symcst ("header-p",           new Function (tls_hdrp));
     gset->symcst ("record-p",           new Function (tls_recp));
-    gset->symcst ("socket-p",           new Function (tls_sckp));
     gset->symcst ("server-p",           new Function (tls_srvp));
+    gset->symcst ("dupleix-p",          new Function (tls_dpxp));
     gset->symcst ("connect-p",          new Function (tls_conp));
     gset->symcst ("message-p",          new Function (tls_msgp));
     gset->symcst ("handshake-p",        new Function (tls_shkp));
