@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "X509.hpp"
@@ -118,11 +118,11 @@ namespace afnix {
     return new Boolean (result);
   }
 
-  // sckp: tls socket object predicate
+  // sckp: tls dupleix object predicate
   
-  Object* tls_sckp  (Runnable* robj, Nameset* nset, Cons* args) {
-    Object* obj = get_obj (robj, nset, args, "socket-p");
-    bool result = (dynamic_cast <TlsSocket*> (obj) == nilp) ? false : true;
+  Object* tls_dpxp  (Runnable* robj, Nameset* nset, Cons* args) {
+    Object* obj = get_obj (robj, nset, args, "dupleix-p");
+    bool result = (dynamic_cast <TlsDupleix*> (obj) == nilp) ? false : true;
     Object::cref (obj);
     return new Boolean (result);
   }
