@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_PREDTLS_HPP
@@ -75,11 +75,11 @@ namespace afnix {
   /// @param args the arguments list
   Object* tls_conp (Runnable* robj, Nameset* nset, Cons* args);
 
-  /// the tls socket object predicate
+  /// the tls dupleix object predicate
   /// @param robj the current runnable
   /// @param nset the current nameset
   /// @param args the arguments list
-  Object* tls_sckp (Runnable* robj, Nameset* nset, Cons* args);
+  Object* tls_dpxp (Runnable* robj, Nameset* nset, Cons* args);
 
   /// the tls server object predicate
   /// @param robj the current runnable
