@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Vector.hpp"
@@ -373,20 +373,6 @@ namespace afnix {
     }
   }
 
-  // write an alert to an output stream
-
-  long TlsAlert::write (OutputStream* os) const {
-    wrlock ();
-    try {
-      long result = TlsMessage::write (os);
-      unlock ();
-      return result;
-    } catch (...) {
-      unlock ();
-      return 0;
-    }
-  }
-  
   // decode a tls alert message
 
   void TlsAlert::decode (void) {
@@ -420,6 +406,20 @@ namespace afnix {
       throw;
     }
   }
+
+  // get the alert decsriptor
+
+  TlsAlert::t_desc TlsAlert::getdesc (void) const {
+    rdlock ();
+    try {
+      t_desc result = d_desc;
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
   
   // -------------------------------------------------------------------------
   // - object section                                                        -
