@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_TLSALERT_HPP
@@ -106,17 +106,16 @@ namespace afnix {
     /// @return the message info as a plist
     Plist getinfo (void) const;
     
-    /// write an alert to an output stream
-    /// @param os the output stream
-    long write (OutputStream* os) const;
-
     /// decode the alert message
     /// @param rcd the record to decode
     virtual void decode (void);
 
-    // /map an alert to a chunk block
+    /// map an alert to a chunk block
     virtual TlsChunk tochunk (void) const;
     
+    /// @return the alert descriptor
+    virtual t_desc getdesc (void) const;
+    
   public:
     /// create a new object in a generic way
     /// @param argv the argument vector
