@@ -1,6 +1,6 @@
 // ---------------------------------------------------------------------------
-// - TlsConnect.cpp                                                           -
-// - afnix:tls service - tls connect class implementation                     -
+// - TlsConnect.cpp                                                          -
+// - afnix:tls service - tls connect class implementation                    -
 // ---------------------------------------------------------------------------
 // - This program is free software;  you can redistribute it  and/or  modify -
 // - it provided that this copyright notice is kept intact.                  -
@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Md5.hpp"
@@ -28,23 +28,13 @@
 #include "QuarkZone.hpp"
 #include "Exception.hpp"
 #include "TlsConnect.hpp"
-#include "OutputTerm.hpp"
 
 namespace afnix {
-  static OutputTerm terr (OutputTerm::ERROR);
+
   // -------------------------------------------------------------------------
   // - private section                                                       -
   // -------------------------------------------------------------------------
 
-  // the master secret prf label
-  static const String TLS_LABL_MS = "master secret";
-  // the key expansion prf label
-  static const String TLS_LABL_KE = "key expansion";
-  // the client finished prf label
-  static const String TLS_LABL_CF = "client finished";
-  // the server finished prf label
-  static const String TLS_LABL_SF = "server finished";
-
   // this procedure compute the master secret buffer
   static Buffer tls_get_mbuf (const s_shss& shss, TlsState* ssta) {
     // get the key exchange message
@@ -84,7 +74,7 @@ namespace afnix {
   }
 
   // this procedure verify the finished message block
-  static bool tls_chk_mfin (const s_shss& shss, TlsState* ssta) {
+  static void tls_chk_mfin (const s_shss& shss, TlsState* ssta) {
     // get the handshake finished message
     TlsHblock* hblk = dynamic_cast <TlsHblock*> (shss.p_mfin);
     if ((hblk == nilp) || (ssta == nilp)) {
@@ -93,23 +83,18 @@ namespace afnix {
     // check the block finished size
     if (hblk->length() != TLS_SIZE_FIN) {
       throw Exception ("tls-error", "invalid finished message size");
-    }
-    // create a seed buffer
-    Buffer seed;
-    Buffer mbuf = ssta->getmbuf();
-    Md5  hl; Buffer bl = shss.d_cvmb; hl.pushb (seed, bl);
-    Sha1 hr; Buffer br = shss.d_cvmb; hr.pushb (seed, br);
-    // compute the finished signature
-    Buffer finb = TlsProto::prf (mbuf, TLS_LABL_CF, seed, TLS_SIZE_FIN);
+    }    
+    // compute the finished signature and verify
+    Buffer finb = TlsProto::cfin (ssta->getmbuf(), shss.d_cvmb);
     if (finb.length() != TLS_SIZE_FIN){
       throw Exception ("tls-error", "invalid finished buffer size");
     }
     // compare the block buffer with the computed buffer
-    if (hblk->tobuffer() != finb) return false;
-    // success
-    return true;
+    if (hblk->tobuffer() != finb) {
+      throw Exception ("tls-error", "handshake verify failure");
+    }
   }
-  
+
   // -------------------------------------------------------------------------
   // - class section                                                         -
   // -------------------------------------------------------------------------
@@ -240,7 +225,9 @@ namespace afnix {
       // finish a client handshake sequence
       shss.fincs (is, tlsp, ssta);
       // verify the finished message
-      ssta->setvflg (tls_chk_mfin (shss, ssta));
+      tls_chk_mfin (shss, ssta);
+      // send the client finish message
+      shss.sndcs (os, tlsp, ssta);
       // clean and unlock
       delete tlsp;
       unlock ();
