@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Vector.hpp"
@@ -250,7 +250,43 @@ namespace afnix {
       throw;
     }
   }
+  
+  // write a message to the output stream
+  
+  long TlsMessage::write (OutputStream* os, Cipher* ec) const {
+    wrlock ();
+    try {
+      // check for nil record
+      if (p_brcd == nilp) {
+	throw Exception ("tls-error", "cannot write message with nil record");
+      }
+      long result = p_brcd->write (os, ec);
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
 
+  // add a hmac to the message record
+
+  bool TlsMessage::addhmc (Hmac* hmac, const t_octa snum) {
+    wrlock ();
+    try {
+      // check for nil record
+      if (p_brcd == nilp) {
+	throw Exception ("tls-error", "cannot add hmac with nil record");
+      }
+      bool result = p_brcd->addhmc (hmac, snum);
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // -------------------------------------------------------------------------
   // - object section                                                        -
   // -------------------------------------------------------------------------
