@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_TLSMESSAGE_HPP
@@ -103,6 +103,16 @@ namespace afnix {
     /// @param os the output stream
     virtual long write (OutputStream* os) const;
 
+    /// write a message to an output stream
+    /// @param os the output stream
+    /// @param ec the encoding cipher
+    virtual long write (OutputStream* os, Cipher* ec) const;
+
+    /// add a hmac to the message record
+    /// @param hmac the hmac object
+    /// @param snum the sequence number
+    virtual bool addhmc (Hmac* hmac, const t_octa snum);
+    
   public:
     /// create a new object in a generic way
     /// @param argv the argument vector
