@@ -11,11 +11,13 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Byte.hpp"
 #include "Vector.hpp"
+#include "Socket.hpp"
+#include "Integer.hpp"
 #include "TlsTypes.hxx"
 #include "TlsParams.hpp"
 #include "QuarkZone.hpp"
@@ -36,6 +38,10 @@ namespace afnix {
   static const String PI_PRM_CERT = "TLS PARAMETER CERTIFICATE NAME";
   static const String PN_PRM_CKEY = "TLS-PRM-CKEY";
   static const String PI_PRM_CKEY = "TLS PARAMETER CERTIFICATE KEY";
+  static const String PN_PRM_HOST = "TLS-PRM-HOST";
+  static const String PI_PRM_HOST = "TLS PARAMETER HOST NAME";
+  static const String PN_PRM_PORT = "TLS-PRM-PORT";
+  static const String PI_PRM_PORT = "TLS PARAMETER HOST PORT";
 
   // -------------------------------------------------------------------------
   // - class section                                                         -
@@ -46,6 +52,14 @@ namespace afnix {
   TlsParams::TlsParams (void) {
     reset ();
   }
+  
+  // create a tls parameters by host and port
+
+  TlsParams::TlsParams (const String& host, const t_word port) {
+    reset ();
+    d_host = host;
+    d_port = port;
+  }
 
   // copy construct this tls parameters
 
@@ -56,6 +70,8 @@ namespace afnix {
       d_vmin = that.d_vmin;
       d_cert = that.d_cert;
       d_ckey = that.d_ckey;
+      d_host = that.d_host;
+      d_port = that.d_port;
       that.unlock ();
     } catch (...) {
       that.unlock ();
@@ -76,6 +92,8 @@ namespace afnix {
       d_vmin = that.d_vmin;
       d_cert = that.d_cert;
       d_ckey = that.d_ckey;
+      d_host = that.d_host;
+      d_port = that.d_port;
       unlock ();
       that.unlock ();
       return *this;
@@ -109,6 +127,8 @@ namespace afnix {
       d_vmin = TLS_VMIN_DEF;
       d_cert = "";
       d_ckey = "";
+      d_host = "";
+      d_port = 0;
       unlock ();
     } catch (...) {
       unlock ();
@@ -128,6 +148,8 @@ namespace afnix {
       plst.add (PN_PRM_VMIN, PI_PRM_VMIN, (t_long) d_vmin);
       plst.add (PN_PRM_CERT, PI_PRM_CERT, d_cert);
       plst.add (PN_PRM_CKEY, PI_PRM_CKEY, d_ckey);
+      plst.add (PN_PRM_HOST, PI_PRM_HOST, d_host);
+      plst.add (PN_PRM_PORT, PI_PRM_PORT, (t_long) d_port);
       // here it is
       unlock ();
       return plst;
@@ -252,12 +274,82 @@ namespace afnix {
     }
   }
   
+  // set the tls host name
+
+  void TlsParams::sethost (const String& host) {
+    wrlock ();
+    try {
+      d_host = host;
+      unlock ();
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // get the tls host name
+
+  String TlsParams::gethost (void) const {
+    rdlock ();
+    try {
+      String result = d_host;
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // set the tls host port
+
+  void TlsParams::setport (const long port) {
+    wrlock ();
+    try {
+      d_port = port;
+      unlock ();
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // get the tls host port
+
+  long TlsParams::getport (void) const {
+    rdlock ();
+    try {
+      long result = d_port;
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // get the tls server socket parameter
+
+  SockParams TlsParams::tosprms (void) const {
+    rdlock();
+    try {
+      // create a result socket params
+      SockParams prms (d_host, d_port);
+      // here it is
+      unlock ();
+      return prms;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // -------------------------------------------------------------------------
   // - object section                                                        -
   // -------------------------------------------------------------------------
 
   // the quark zone
-  static const long QUARK_ZONE_LENGTH = 7;
+  static const long QUARK_ZONE_LENGTH = 12;
   static QuarkZone  zone (QUARK_ZONE_LENGTH);
 
   // the object supported quarks
@@ -268,6 +360,11 @@ namespace afnix {
   static const long QUARK_GETCERT = zone.intern ("get-certificate");
   static const long QUARK_SETCKEY = zone.intern ("set-certificate-key");
   static const long QUARK_GETCKEY = zone.intern ("get-certificate-key");
+  static const long QUARK_SETHOST = zone.intern ("set-host");
+  static const long QUARK_GETHOST = zone.intern ("get-host");
+  static const long QUARK_SETPORT = zone.intern ("set-port");
+  static const long QUARK_GETPORT = zone.intern ("get-port");
+  static const long QUARK_TOSPRMS = zone.intern ("to-server-sock-params");
 
   // create a new object in a generic way
 
@@ -277,6 +374,12 @@ namespace afnix {
 
     // check for 0 argument
     if (argc == 0) return new TlsParams;
+    // check for 2 arguments
+    if (argc == 2) {
+      String host = argv->getstring (0);
+      t_word port = argv->getlong   (1);
+      return new TlsParams (host, port);
+    }
     // too many arguments
     throw Exception ("argument-error", 
 		     "too many argument with tls parameters");
@@ -304,10 +407,13 @@ namespace afnix {
     
     // check for 0 argument
     if (argc == 0) {
-      if (quark == QUARK_GETVMAJ) return new Byte   (getvmaj ());
-      if (quark == QUARK_GETVMIN) return new Byte   (getvmin ());
-      if (quark == QUARK_GETCERT) return new String (getcert ());
-      if (quark == QUARK_GETCKEY) return new String (getckey ());
+      if (quark == QUARK_GETVMAJ) return new Byte    (getvmaj ());
+      if (quark == QUARK_GETVMIN) return new Byte    (getvmin ());
+      if (quark == QUARK_GETCERT) return new String  (getcert ());
+      if (quark == QUARK_GETCKEY) return new String  (getckey ());
+      if (quark == QUARK_GETHOST) return new String  (gethost ());
+      if (quark == QUARK_GETPORT) return new Integer (getport ());
+      if (quark == QUARK_TOSPRMS) return new SockParams (tosprms ());
     }
     // check for 1 argument
     if (argc == 1) {
@@ -321,6 +427,16 @@ namespace afnix {
 	setckey (ckey);
 	return nilp;
       }
+      if (quark == QUARK_SETHOST) {
+	String host = argv->getstring (0);
+	sethost (host);
+	return nilp;
+      }
+      if (quark == QUARK_SETPORT) {
+	long port = argv->getlong (0);
+	setport (port);
+	return nilp;
+      }
     }
     // check for 2 arguments
     if (argc == 2) {
