@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_TLSPARAMS_HPP
@@ -25,6 +25,10 @@
 #include "TlsInfos.hpp"
 #endif
 
+#ifndef  AFNIX_SOCKPARAMS_HPP
+#include "SockParams.hpp"
+#endif
+
 namespace afnix {
 
   /// The TlsParams class is a container class designed for the storage
@@ -42,11 +46,20 @@ namespace afnix {
     String d_cert;
     /// the certificate key
     String d_ckey;
+    /// the host name
+    String d_host;
+    /// the host port
+    long d_port;
 
   public:
     /// create a default tls parameters
     TlsParams (void);
 
+    /// create a tls parameters by host and port
+    /// @param host the tls host
+    /// @param port the tls port
+    TlsParams (const String& host,const t_word port);
+
     /// copy coonstruct a tls parameters
     /// @param that the object to copy
     TlsParams (const TlsParams& that);
@@ -96,6 +109,23 @@ namespace afnix {
     /// @param cert the certificate list
     /// @param ckey the certificate key
     virtual void setcert (const String& cert, const String& ckey);
+
+    /// set the tls host name
+    /// @param host the host name
+    virtual void sethost (const String& host);
+    
+    /// @return the tls host name
+    virtual String gethost (void) const;
+
+    /// set the tls host port
+    /// @param host the host port
+    virtual void setport (const long port);
+    
+    /// @return the tls host port
+    virtual long getport (void) const;
+
+    /// @return the server socket parameters
+    virtual SockParams tosprms (void) const;
     
   public:
     /// create a new object in a generic way
