@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Md5.hpp"
@@ -19,11 +19,13 @@
 #include "Hmac.hpp"
 #include "Vector.hpp"
 #include "Integer.hpp"
+#include "TlsData.hpp"
 #include "TlsTypes.hxx"
 #include "TlsProto.hxx"
 #include "TlsUtils.hpp"
 #include "TlsShake.hpp"
 #include "TlsCspec.hpp"
+#include "TlsAlert.hpp"
 #include "TlsChello.hpp"
 #include "TlsCkeyxh.hpp"
 #include "TlsFinish.hpp"
@@ -120,7 +122,29 @@ namespace afnix {
       throw;
     }
   }
-   
+
+  // the client verify computation
+
+  Buffer TlsProto::cfin (const Buffer& mbuf, const Buffer& vbuf) {
+    // create a seed buffer
+    Buffer seed;
+    Md5  hl; Buffer bl = vbuf; hl.pushb (seed, bl);
+    Sha1 hr; Buffer br = vbuf; hr.pushb (seed, br);
+    // compute the finished signature
+    return TlsProto::prf (mbuf, TLS_LABL_CF, seed, TLS_SIZE_FIN);
+  }
+
+  // the server verify computation
+
+  Buffer TlsProto::sfin (const Buffer& mbuf, const Buffer& vbuf) {
+    // create a seed buffer
+    Buffer seed;
+    Md5  hl; Buffer bl = vbuf; hl.pushb (seed, bl);
+    Sha1 hr; Buffer br = vbuf; hr.pushb (seed, br);
+    // compute the finished signature
+    return TlsProto::prf (mbuf, TLS_LABL_SF, seed, TLS_SIZE_FIN);
+  }
+  
   // -------------------------------------------------------------------------
   // - class section                                                         -
   // -------------------------------------------------------------------------
@@ -136,26 +160,31 @@ namespace afnix {
     return "TlsProto";
   }
 
-  // get a record by input stream
-
-  TlsRecord* TlsProto::getrcd (InputStream* is) const {
-    rdlock ();
-    try {
-      TlsRecord* rcd = new TlsRecord (is);
-      unlock ();
-      return rcd;
-    } catch (...) {
-      unlock ();
-      throw;
-    }
-  }
-
   // get a record by input stream and cipher
 
-  TlsRecord* TlsProto::getrcd (InputStream* is, Cipher* dc) const {
+  TlsRecord* TlsProto::getrcd (InputStream* is, TlsState* sta) const {
     rdlock ();
     try {
+      if (is == nilp) {
+	unlock ();
+	return nilp;
+      }
+      if (sta == nilp) {
+	TlsRecord* rcd = new TlsRecord (is);
+	unlock ();
+	return rcd;
+      }
+      // get the decoding cipher
+      Cipher* dc = (sta == nilp) ? nilp : sta->getcbcf ();
+      // get the record, possibly with the hmac
       TlsRecord* rcd = new TlsRecord (is, dc);
+      if (rcd != nilp) {
+	// check the record hmac
+	bool status = rcd->chkhmc(sta->getchmc(), sta->newcnum());
+	if (status == false) {
+	  throw Exception ("tls-error", "invalid client hmac record");
+	}
+      }
       unlock ();
       return rcd;
     } catch (...) {
@@ -163,58 +192,8 @@ namespace afnix {
       throw;
     }
   }
-  
-  // get a message by input stream
 
-  TlsMessage* TlsProto::getmsg (InputStream* is) const {
-    rdlock ();
-    try {
-      TlsMessage* msg = getmsg(is, (Cipher*) nilp);
-      unlock ();
-      return msg;
-    } catch (...) {
-      unlock ();
-      throw;
-    }
-  }
-  
-  // get a message by input stream and cipher
-
-  TlsMessage* TlsProto::getmsg (InputStream* is, Cipher* dc) const {
-    rdlock ();
-    TlsRecord* rcd = nilp;
-    try {
-      // get the next available record
-      rcd = getrcd (is, dc);
-      // decode the record
-      TlsMessage* msg = getmsg (rcd);
-      unlock ();
-      return msg;
-    } catch (...) {
-      delete rcd;
-      unlock ();
-      throw;
-    }
-  }
-  
-  // get a message by input stream and state
-
-  TlsMessage* TlsProto::getmsg (InputStream* is, TlsState* sta) const {
-    rdlock ();
-    try {
-      // get the decoding cipher
-      Cipher* dc = (sta == nilp) ?nilp : sta->getcbcf ();
-      // get the message by cipher
-      TlsMessage* msg = getmsg (is, dc);
-      unlock ();
-      return msg;
-    } catch (...) {
-      unlock ();
-      throw;
-    }
-  }
-  
-  // decode a record into a message
+  // get a message by record
   
   TlsMessage* TlsProto::getmsg (TlsRecord* rcd) const {
     // check for nil
@@ -231,9 +210,15 @@ namespace afnix {
       case TLS_TYPE_CCS:
 	result = new TlsCspec (rcd);
 	break;
+      case TLS_TYPE_ALT:
+	result = new TlsAlert (rcd);
+	break;
       case TLS_TYPE_HSK:
 	result = new TlsShake (rcd);
 	break;
+      case TLS_TYPE_APP:
+	result = new TlsData (rcd);
+	break;
       default:
 	throw Exception ("tls-error", "cannot decode record into a message");
 	break;
@@ -245,24 +230,66 @@ namespace afnix {
       throw;
     }
   }
+   
+  // get a message by input stream and state
 
+  TlsMessage* TlsProto::getmsg (InputStream* is, TlsState* sta) const {
+    rdlock ();
+    TlsRecord* rcd = nilp;
+    try {
+      // get the next available record
+      rcd = getrcd (is, sta);
+      // decode the record
+      TlsMessage* msg = getmsg (rcd);
+      unlock ();
+      return msg;
+    } catch (...) {
+      delete rcd;
+      unlock ();
+      throw;
+    }
+  }
+  
   // encode a tls message
 
-  void TlsProto::encode (OutputStream* os, TlsMessage* mesg) const {
+  long TlsProto::encode (OutputStream* os, TlsMessage* msg) const {
     // check for nil
-    if ((mesg == nilp) || (os == nilp)) return;
+    if ((msg == nilp) || (os == nilp)) return 0L;
     rdlock ();
     try {
-      // check for an alert
-      //TlsAlert* alt = dynamic_cast <TlsAlert*> (mesg);
-      //if (alt != nilp) alt->encode (os);
-      // check for a change cipher spec
-      TlsCspec* ccs = dynamic_cast <TlsCspec*> (mesg);
-      if (ccs != nilp) ccs->write (os);
-      // check for a handshake
-      TlsShake* hsk = dynamic_cast <TlsShake*> (mesg);
-      if (hsk != nilp) hsk->write (os);
+      long result = encode (os, msg, nilp);
       unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
+  // encode a tls message
+
+  long TlsProto::encode (OutputStream* os,TlsMessage* msg,TlsState* sta) const {
+    // check for nil
+    if ((msg == nilp) || (os == nilp)) return 0L;
+    rdlock ();
+    try {
+      if (sta == nilp) {
+	long result = msg->write (os);
+	unlock ();
+	return result;
+      }
+      // get the hmac and sequence number
+      Hmac*  hmac = sta->getshmc ();
+      t_octa snum = sta->newsnum ();
+      if (msg->addhmc (hmac, snum) == false) {
+	throw Exception ("tls-error", "cannot add tls message hmac");
+      }
+      // get the decoding cipher
+      Cipher* ec = sta->getsbcf ();
+      // write the message
+      long result = msg->write (os, ec);
+      unlock ();
+      return result;
     } catch (...) {
       unlock ();
       throw;
@@ -311,7 +338,7 @@ namespace afnix {
     TlsHblock*  blk = nilp;
     try {
       // get the next available message
-      TlsMessage* msg = getmsg (is);
+      TlsMessage* msg = getmsg (is, sta);
       if (msg == nilp) {
 	unlock ();
 	return nilp;
@@ -357,7 +384,7 @@ namespace afnix {
     TlsHblock* blk = nilp;
     try {
       // get the next available message
-      TlsMessage* msg = getmsg (is);
+      TlsMessage* msg = getmsg (is, sta);
       if (msg == nilp) {
 	unlock ();
 	return nilp;
@@ -397,7 +424,7 @@ namespace afnix {
     TlsMessage* msg = nilp;
     try {
       // get the next available message
-      if ((msg = getmsg (is)) == nilp) {
+      if ((msg = getmsg (is, sta)) == nilp) {
 	unlock ();
 	return false;
       }
@@ -407,10 +434,10 @@ namespace afnix {
 	throw Exception ("tls-error", "cannot get change cipher spec message");
       }
       // update the state with the new cipher
-      if (sta != nilp) sta->chspec ();
+      bool result = (sta == nilp) ? false : sta->chgccs ();
       delete msg;
       unlock ();
-      return true;
+      return result;
     } catch (...) {
       delete msg;
       unlock ();
@@ -635,6 +662,162 @@ namespace afnix {
       throw;
     }
   }
+
+  // map a server change cipher spec by state
+
+  TlsMessage* TlsProto::getsccs (TlsState* sta) const {
+    // check for nil first
+    if (sta == nilp) return nilp;
+    // lock and map
+    TlsCspec* ccs = nilp;
+    rdlock ();
+    try {
+      // create a tls change cipher spec by state
+      ccs = new TlsCspec (sta->getvmaj (), sta->getvmin());
+      unlock ();
+      return ccs;
+    } catch (...) {
+      delete ccs;
+      unlock ();
+      throw;
+    }
+  }
+  
+  // send the server change cipher spec by state
+
+  bool TlsProto::sndsccs (OutputStream* os, TlsState* sta) const {
+    TlsMessage* sccs = nilp;
+    rdlock ();
+    try {
+      // get the server finish message and encode it
+      sccs = getsccs (sta);
+      // check for valid message and encode it
+      if (sccs == nilp) {
+	unlock ();
+	return false;
+      }
+      encode (os, sccs, sta);
+      // update the state with the new cipher
+      bool result = (sta == nilp) ? false : sta->chgscs ();
+      // done
+      delete sccs;
+      unlock ();
+      return result;
+    } catch (...) {
+      delete sccs;
+      unlock ();
+      throw;
+    }
+  }
+  
+  // map a server finish by state
+
+  TlsMessage* TlsProto::getsfin (TlsState* sta) const {
+    // check for nil first
+    if (sta == nilp) return nilp;
+    // lock and map
+    TlsShake* hsk = nilp;
+    rdlock ();
+    try {
+      // create a tls handshake by state
+      hsk = new TlsShake (sta->getvmaj (), sta->getvmin());
+      // compute the finished signature
+      Buffer mbuf = sta->getmbuf();
+      Buffer finb = TlsProto::sfin (sta->getmbuf(), sta->gethvmb());
+      if (finb.length() != TLS_SIZE_FIN){
+	throw Exception ("tls-error", "invalid finished buffer size");
+      }
+      // add the chunk block to the record
+      hsk->add (TLS_HSHK_FIN, TlsChunk(finb));
+      unlock ();
+      return hsk;
+    } catch (...) {
+      delete hsk;
+      unlock ();
+      throw;
+    }
+  }
+  
+  // send the server finished message
+
+  void TlsProto::sndsfin (OutputStream* os, TlsState* sta) const {
+    TlsMessage* mfin = nilp;
+    rdlock ();
+    try {
+      // get the server finish message and encode it
+      mfin = getsfin (sta);
+      // check for valid message and encode it
+      if (mfin != nilp) encode (os, mfin, sta);
+      // done
+      delete mfin;
+      unlock ();
+    } catch (...) {
+      delete mfin;
+      unlock ();
+      throw;
+    }
+  }
+
+  // pop the next available buffer
+
+  Buffer TlsProto::popb (InputStream* is, TlsState* sta) const {
+    rdlock ();
+    try {
+      // get the next available message
+      TlsMessage* msg = getmsg (is, sta);
+      if (msg == nilp) {
+	throw Exception ("tls-error", "cannot pop tls message in pop buffer");
+      }
+      // check for a data message
+      TlsData* data = dynamic_cast<TlsData*> (msg);
+      if (data != nilp) {
+	Buffer result;
+	data->pushb (result);
+	unlock ();
+	return result;
+      }
+      // check for an alert
+      TlsAlert* alrt = dynamic_cast<TlsAlert*> (msg);
+      if (alrt != nilp) {
+	TlsAlert result = *alrt;
+	throw result;
+      }
+      // invalid message in loop
+      throw Exception ("tls-error", "invalid message in pop buffer",
+		       Object::repr (msg));
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // push a buffer to the stream
+
+  long TlsProto::pushb (OutputStream* os, TlsState* sta,
+			const Buffer& buf) const {
+    rdlock();
+    TlsMessage* msg = nilp;
+    try {
+      // check for valid state
+      if (sta == nilp) {
+	throw Exception ("tls-error", "invalid nil state in push buffer");
+      }
+      // create a tls data message
+      msg = new TlsData (sta->getvmaj(), sta->getvmin());
+      // push the buffer in the message
+      msg->add (buf);
+      // encode the message
+      long result = encode (os, msg, sta);
+      // done
+      delete msg;
+      unlock ();
+      return result;
+    } catch (...) {
+      delete msg;
+      unlock ();
+      throw;
+    }
+  }
   
   // -------------------------------------------------------------------------
   // - object section                                                        -
