@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_TLSPROTO_HPP
@@ -69,6 +69,16 @@ namespace afnix {
     /// @param rlen the prf result size
     static Buffer prf (const Buffer& sbuf, const String& labl,
 		       const Buffer& seed, const long    rlen);
+
+    /// the client verify computation
+    /// @param mbuf the master secret
+    /// @param vbuf the verify buffer 
+    static Buffer cfin (const Buffer& mbuf, const Buffer& vbuf);
+
+    /// the server verify computation
+    /// @param mbuf the master secret
+    /// @param vbuf the verify buffer 
+    static Buffer sfin (const Buffer& mbuf, const Buffer& vbuf);
     
   public:
     /// create a default protocol
@@ -77,37 +87,30 @@ namespace afnix {
     /// @return the class name
     String repr (void) const;
 
-    /// get a record by input stream
-    /// @param is the input strem to read
-    virtual TlsRecord* getrcd (InputStream* is) const;
-
     /// get a record by input stream and cipher
-    /// @param is the input strem to read
-    /// @param dc the decoding cipher
-    virtual TlsRecord* getrcd (InputStream* is, Cipher* dc) const;
+    /// @param is  the input strem to read
+    /// @param sta the tls state
+    virtual TlsRecord* getrcd (InputStream* is, TlsState* sta) const;
 
-    /// get a message by input stream
-    /// @param is the input strem to read
-    virtual TlsMessage* getmsg (InputStream* is) const;
-
-    /// get a message by input stream and cipher
-    /// @param is the input strem to read
-    /// @param dc the decoding cipher
-    virtual TlsMessage* getmsg (InputStream* is, Cipher* dc) const;
+    /// get a message by record
+    /// @param rcd the record to decode
+    virtual TlsMessage* getmsg (TlsRecord* rcd) const;
 
     /// get a message by input stream and state
     /// @param is the input strem to read
     /// @param sta the tls state
     virtual TlsMessage* getmsg (InputStream* is, TlsState* sta) const;
 
-    /// get a message by record
-    /// @param rcd the record to decode
-    virtual TlsMessage* getmsg (TlsRecord* rcd) const;
+    /// encode a tls message
+    /// @param os  the output stream
+    /// @param msg the message to encode
+    virtual long encode (OutputStream* os, TlsMessage* msg) const;
 
     /// encode a tls message
     /// @param os  the output stream
     /// @param msg the message to encode
-    virtual void encode (OutputStream* os, TlsMessage* msg) const;
+    /// @param sta the tls state
+    virtual long encode (OutputStream* os,TlsMessage* msg,TlsState* sta) const;
 
     /// decode a handshake block
     /// @param hblk the block to decode
@@ -163,6 +166,36 @@ namespace afnix {
     /// @param os  the output stream
     /// @param sta the tls state
     virtual void sndsdon (OutputStream* os, TlsState* sta) const;
+
+    /// get a server change cipher spec by state
+    /// @param sta the tls state
+    virtual TlsMessage* getsccs (TlsState* sta) const;
+
+    /// send a server change cipher spec by state
+    /// @param os  the output stream
+    /// @param sta the tls state
+    virtual bool sndsccs (OutputStream* os, TlsState* sta) const;
+
+    /// get a server finished message by state
+    /// @param sta the tls state
+    virtual TlsMessage* getsfin (TlsState* sta) const;
+
+    /// send a server finished by state
+    /// @param os  the output stream
+    /// @param sta the tls state
+    virtual void sndsfin (OutputStream* os, TlsState* sta) const;
+
+    /// pop the next available buffer
+    /// @param is  the output stream
+    /// @param sta the tls state
+    virtual Buffer popb (InputStream* is, TlsState* sta) const;
+
+    /// push a buffer to the stream
+    /// @param os  the output stream
+    /// @param sta the tls state
+    /// @param buf the buffer to push
+    virtual long pushb (OutputStream* os, TlsState* sta,
+			const Buffer& buf) const;
     
   public:
     /// create a new object in a generic way
