@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Vector.hpp"
@@ -21,9 +21,10 @@
 #include "TlsRecord.hpp"
 #include "QuarkZone.hpp"
 #include "Exception.hpp"
+#include "BlockCipher.hpp"
 
 namespace afnix {
-
+  
   // -------------------------------------------------------------------------
   // - class section                                                         -
   // -------------------------------------------------------------------------
@@ -42,13 +43,13 @@ namespace afnix {
     read (is);
   }
 
-  // create a record by input stream and cipher
+  // create a record by input stream, cipher and hmac length
 
   TlsRecord::TlsRecord (InputStream* is, Cipher* dc) {
     p_data = new t_byte[TLS_RLEN_MAX];
     read (is, dc);
   }
-
+  
   // create a record by type and version
 
   TlsRecord::TlsRecord (const t_byte type, 
@@ -81,6 +82,7 @@ namespace afnix {
       d_vmaj = that.d_vmaj;
       d_vmin = that.d_vmin;
       d_rlen = that.d_rlen;
+      d_hlen = that.d_hlen;
       // allocate and copy locally
       p_data = new t_byte[TLS_RLEN_MAX];
       for (long k = 0; k < d_rlen; k++) p_data[k] = that.p_data[k];
@@ -100,6 +102,7 @@ namespace afnix {
     d_vmaj = that.d_vmaj;
     d_vmin = that.d_vmin;
     d_rlen = that.d_rlen;
+    d_hlen = that.d_hlen;
     p_data = that.p_data;
     // reallocate original object
     that.p_data = new t_byte[TLS_RLEN_MAX];
@@ -129,6 +132,7 @@ namespace afnix {
       d_vmaj = that.d_vmaj;
       d_vmin = that.d_vmin;
       d_rlen = that.d_rlen;
+      d_hlen = that.d_hlen;
       // copy locally
       for (long k = 0; k < d_rlen; k++) p_data[k] = that.p_data[k];
       for (long k = d_rlen; k < TLS_RLEN_MAX; k++) p_data[k] = nilc;
@@ -153,6 +157,7 @@ namespace afnix {
     d_vmaj = that.d_vmaj;
     d_vmin = that.d_vmin;
     d_rlen = that.d_rlen;
+    d_hlen = that.d_hlen;
     p_data = that.p_data;
     // reallocate original object
     that.p_data = new t_byte[TLS_RLEN_MAX];
@@ -182,7 +187,8 @@ namespace afnix {
       d_type = nilc;
       d_vmaj = nilc;
       d_vmin = nilc;
-      d_rlen = 0L;   
+      d_rlen = 0L;
+      d_hlen = 0L;
       // nullify the memory
       for (long k = 0; k < TLS_RLEN_MAX; k++) p_data[k] = nilc;
       unlock ();
@@ -356,6 +362,15 @@ namespace afnix {
 	if (result != ob.length ()) {
 	  throw Exception ("record-error", "inconsistent decode size");
 	}
+	// remove the padding if any with block cipher
+	auto* bc = dynamic_cast<BlockCipher*> (dc);
+	if ((bc != nilp) && (result > 0)) {
+	  long plen = (long) ob.get(result - 1);
+	  if ((plen + 1) >= result) {
+	    throw Exception ("record-error", "inconsistent record padding");
+	  }
+	  result -= (plen + 1);
+	}
 	// copy the buffer into the record
 	d_rlen = ob.copy ((char*) p_data, result);
 	if (result != d_rlen) {
@@ -372,14 +387,57 @@ namespace afnix {
       throw;
     }
   }
-
+  
   // write a record to an output stream
 
   long TlsRecord::write (OutputStream* os) const {
+    rdlock ();
+    try {
+      long result = write (os, nilp);
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
+  // write a record to an output stream
+
+  long TlsRecord::write (OutputStream* os, Cipher* ec) const {
     // check for nil
     if (os == nilp) return 0L;
     rdlock ();
     try {
+      // prepare the record length
+      t_word rlen = (t_word) (d_rlen + d_hlen);
+      // eventually encode the data
+      Buffer ob;
+      if (ec != nilp) {
+	// push the data in the input buffer
+	Buffer ib (rlen); ib.add ((const char*) p_data, rlen);
+	// eventually pad the data
+	auto* bc = dynamic_cast<BlockCipher*> (ec);
+	if (bc != nilp) {
+	  long cbsz = bc->getcbsz ();
+	  long psiz = cbsz - ((rlen + 1) % cbsz);
+	  if (cbsz > 255) {
+	    throw Exception ("tls-error", "invalid record padding size");
+	  }
+	  if ((rlen + psiz) >= TLS_RLEN_MAX) {
+	    throw Exception ("tls-error", "invalid padded record block size");
+	  }
+	  for (long k = 0; k <= psiz; k++) {
+	    ib.add ((char) psiz);
+	  }
+	  if (ib.length() != rlen + psiz + 1) {
+	    throw Exception ("tls-error", "inconsistent padded record size");
+	  }
+	}
+	rlen = ec->stream (ob, ib);
+      } else {
+	rlen = ob.add ((const char*) p_data, d_rlen);
+      }
       // initialize result
       long result = 0L;
       // write the record type
@@ -387,12 +445,11 @@ namespace afnix {
       // write the version
       result += os->write ((char) d_vmaj);
       result += os->write ((char) d_vmin);
-      // write the record length
-      t_word rlen = (t_word) d_rlen;
+      // prepare the record length
       result += os->write ((char) ((rlen & 0xFF00) >> 8));
       result += os->write ((char)  (rlen & 0x00FF));
       // write the record data
-      result += os->write ((const char*) p_data, d_rlen);
+      result += os->write (ob);
       // here it is
       unlock ();
       return result;
@@ -402,6 +459,99 @@ namespace afnix {
     }
   }
 
+  // check the record hmac
+
+  bool TlsRecord::chkhmc (Hmac* hmac, const t_octa snum) {
+    rdlock ();
+    try {
+      // check for nil hmac
+      if (hmac == nilp) {
+	unlock ();
+	return true;
+      }
+      // reset the hmac
+      hmac->reset();
+      // get the hmac length and record length
+      long hlen = hmac->length();
+      long rlen = d_rlen - hlen;
+      if (rlen < 0) {
+	unlock ();
+	return false;
+      }
+      // create the hmac buffer
+      Buffer hbuf;
+      hbuf.addho (snum);
+      hbuf.add ((char) d_type);
+      hbuf.add ((char) d_vmaj);
+      hbuf.add ((char) d_vmin);
+      hbuf.addhw ((t_word) rlen);
+      // compute the mac
+      Buffer mbuf;
+      hmac->process (hbuf);
+      hmac->process (p_data, rlen);
+      hmac->finish ();
+      hmac->pushb (mbuf);
+      // check the computed result
+      Buffer vbuf (hlen, hlen, (char*) &p_data[rlen]);
+      bool result = (mbuf == vbuf);
+      // update if valid
+      if (result == true) {
+	d_hlen  = hlen;
+	d_rlen -= hlen;
+      }
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // add the record hmac
+
+  bool TlsRecord::addhmc (Hmac* hmac, const t_octa snum) {
+    // lock and add
+    rdlock ();
+    try {
+      // check for nil hmac
+      if (hmac == nilp) {
+	unlock ();
+	return true;
+      }
+      // check for valid hmac len or record length
+      if ((d_rlen == 0) || (d_hlen != 0)) {
+	unlock ();
+	return false;
+      }
+      // reset the hmac
+      hmac->reset();
+      // create the hmac buffer
+      Buffer hbuf;
+      hbuf.addho (snum);
+      hbuf.add ((char) d_type);
+      hbuf.add ((char) d_vmaj);
+      hbuf.add ((char) d_vmin);
+      hbuf.addhw ((t_word) d_rlen);
+      // compute the mac
+      Buffer mbuf;
+      hmac->process (hbuf);
+      hmac->process (p_data, d_rlen);
+      hmac->finish ();
+      hmac->pushb (mbuf);
+      // paranoid check
+      long hlen = hmac->length();
+      if (mbuf.length() != hlen) return false;
+      // map the buffer to the record
+      mbuf.tomap(&p_data[d_rlen], hlen);
+      d_hlen = hlen;
+      unlock ();
+      return true;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
   // -------------------------------------------------------------------------
   // - object section                                                        -
   // -------------------------------------------------------------------------
@@ -460,7 +610,7 @@ namespace afnix {
 			    Vector* argv) {
     // get the number of arguments
     long argc = (argv == nilp) ? 0 : argv->length ();
-    
+
     // dispatch 1 argument
     if (argc == 1) {
       if (quark == QUARK_READ) {
