@@ -11,12 +11,16 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_TLSRECORD_HPP
 #define  AFNIX_TLSRECORD_HPP
 
+#ifndef  AFNIX_HMAC_HPP
+#include "Hmac.hpp"
+#endif
+
 #ifndef  AFNIX_CIPHER_HPP
 #include "Cipher.hpp"
 #endif
@@ -38,11 +42,13 @@ namespace afnix {
   /// The TlsRecord class is the raw record class for the tls protocol.
   /// A record object is created from an input stream with a byte data
   /// array those length is the record length. The tls protocol restricts
-  /// the record length to 16 KiB.
+  /// the record length to 16 KiB. The record length is the total record
+  /// size after reception and cipher decoding. Just after decoding, the
+  /// hmac length is null.If the hmac is succesfully verified, the record
+  /// length and hmac length are adjusted accordingly.
   /// @author amaury darsch
 
   class TlsRecord : public TlsHeader {
-  protected:
   protected:
     /// the record type
     t_byte  d_type;
@@ -52,6 +58,8 @@ namespace afnix {
     t_byte  d_vmin;
     /// the record length
     long    d_rlen;
+    /// the hmac length
+    long    d_hlen;
     /// the record data
     t_byte* p_data;
 
@@ -63,9 +71,9 @@ namespace afnix {
     /// @param is the input stream to read
     TlsRecord (InputStream* is);
 
-    /// create a record by input stream and cipher
-    /// @param is the input stream to read
-    /// @param dc the decoding cipher
+    /// create a record by input stream, cipher and hmac length
+    /// @param is   the input stream to read
+    /// @param dc   the decoding cipher
     TlsRecord (InputStream* is, Cipher* dc);
     
     /// create a record by type and version
@@ -131,14 +139,29 @@ namespace afnix {
     virtual long read (InputStream* is);
 
     /// fill a record from an input stream
-    /// @param is the input stream to read
-    /// @param dc the decoding cipher
+    /// @param is   the input stream to read
+    /// @param dc   the decoding cipher
     virtual long read (InputStream* is, Cipher* dc);
 
     /// write a record to an output stream
     /// @param os the output stream
     virtual long write (OutputStream* os) const;
 
+    /// write a record to an output stream
+    /// @param os the output stream
+    /// @param ec the encoding cipher
+    virtual long write (OutputStream* os, Cipher* ec) const;
+
+    /// check the record hmac
+    /// @param hmac the hmac object
+    /// @param snum the sequence number
+    virtual bool chkhmc (Hmac* hmac, const t_octa snum);
+
+    /// add a hmac to the record
+    /// @param hmac the hmac object
+    /// @param snum the sequence number
+    virtual bool addhmc (Hmac* hmac, const t_octa snum);
+    
   public:
     /// create a new object in a generic way
     /// @param argv the argument vector
