@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Vector.hpp"
@@ -35,15 +35,16 @@ namespace afnix {
 
   // create a server by name and host
 
-  TlsServer::TlsServer (const String& host, t_word port) : 
+  TlsServer::TlsServer (const String& host, const t_word port) :
     TcpServer (host, port) {
+    d_prms.sethost (host);
+    d_prms.setport (port);
   }
 
   // create a server by name, host and parameters
 
-  TlsServer::TlsServer (const String& host, t_word port,
-			const TlsParams& prms) : TcpServer (host, port) {
-    setprms (prms);
+  TlsServer::TlsServer (const TlsParams& prms) : TcpServer (prms.tosprms()) {
+    d_prms = prms;
   }
  
   // return the class name
@@ -52,9 +53,9 @@ namespace afnix {
     return "TlsServer";
   }
 
-  // get an accepted connected socket
+  // get a full dupleix connection
 
-  TcpSocket* TlsServer::accept (void) const {
+  TlsDupleix* TlsServer::acceptfd (void) const {
     rdlock ();
     TlsState* ssta = nilp;
     try {
@@ -70,7 +71,7 @@ namespace afnix {
 	return nilp;
       }
       // create the result socket
-      TcpSocket* result = new TlsSocket (s, ssta);
+      TlsDupleix* result = new TlsDupleix (s->getis(), s->getos(), ssta);
       unlock ();
       return result;
     } catch (...) {
@@ -98,11 +99,12 @@ namespace afnix {
   // -------------------------------------------------------------------------
 
   // the quark zone
-  static const long QUARK_ZONE_LENGTH = 1;
+  static const long QUARK_ZONE_LENGTH = 2;
   static QuarkZone  zone (QUARK_ZONE_LENGTH);
 
   // the object supported quarks
-  static const long QUARK_SETPRMS = zone.intern ("set-parameters");
+  static const long QUARK_SETPRMS  = zone.intern ("set-parameters");
+  static const long QUARK_ACCEPTFD = zone.intern ("accept-full-dupleix");
  
   // create a new object in a generic way
 
@@ -112,23 +114,21 @@ namespace afnix {
     
     // check for 0 argument
     if (argc == 0) return new TlsServer;
-    // check for 2 arguments
-    if (argc == 2) {
-      String host = argv->getstring (0);
-      t_word port = argv->getlong   (1);
-      return new TlsServer (host, port);
-    }
-    // check for 3 arguments
-    if (argc == 3) {
-      String host = argv->getstring (0);
-      t_word port = argv->getlong   (1);
-      Object* obj = argv->get (2);
+    // check for 1 argument
+    if (argc == 1) {
+      Object* obj = argv->get (0);
       TlsParams* prms = dynamic_cast <TlsParams*> (obj);
       if (prms == nilp) {
 	throw Exception ("type-error", "invalid object as parameters",
 			 Object::repr (obj));
       }
-      return new TlsServer (host, port, *prms);
+      return new TlsServer (*prms);
+    }
+    // check for 2 arguments
+    if (argc == 2) {
+      String host = argv->getstring (0);
+      t_word port = argv->getlong   (1);
+      return new TlsServer (host, port);
     }
     // too many arguments
     throw Exception ("argument-error", 
@@ -159,6 +159,10 @@ namespace afnix {
 			    Vector* argv) {
     // get the number of arguments
     long argc = (argv == nilp) ? 0 : argv->length ();
+    // dispatch 0 argument
+    if (argc == 0) {
+      if (quark == QUARK_ACCEPTFD) return acceptfd();
+    }
     // dispatch 1 argument
     if (argc == 1) {
       if (quark == QUARK_SETPRMS) {
