@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_TLSSERVER_HPP
@@ -21,8 +21,8 @@
 #include "TcpServer.hpp"
 #endif
 
-#ifndef  AFNIX_TLSSOCKET_HPP
-#include "TlsSocket.hpp"
+#ifndef  AFNIX_TLSDUPLEIX_HPP
+#include "TlsDupleix.hpp"
 #endif
 
 namespace afnix {
@@ -30,7 +30,8 @@ namespace afnix {
   /// The TlsServer class is the server socket class for the tls protocol.
   /// The class is a wrapper around the tcp server with extra information
   /// needed to setup a secure channel. Once a connection is accepted (in
-  /// the tcp sense) the handshake can start.
+  /// the tcp sense) the handshake can start. The class is designed to
+  /// produce a tls dupleix object, once the full handshake is completed.
   /// @author amaury darsch
 
   class TlsServer : public TcpServer {
@@ -47,17 +48,15 @@ namespace afnix {
     /// @param port the port to listen
     TlsServer (const String& host, t_word port);
 
-    /// create a tls server with a host, port and parameters
-    /// @param host the host to bind the server
-    /// @param port the port to listen
+    /// create a tls server by parameters
     /// @param prms the tls parameters
-    TlsServer (const String& host, t_word port, const TlsParams& prms);
+    TlsServer (const TlsParams& prms);
     
     /// @return the class name
     String repr (void) const;
     
-    /// @return an accepted connected tcp socket
-    TcpSocket* accept (void) const;
+    /// @return a full dupleix connection
+    TlsDupleix* acceptfd (void) const;
 
     /// set the tls parameters
     /// @param prms the tls parameters
