@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Byte.hpp"
@@ -26,14 +26,13 @@
 #include "Exception.hpp"
 
 namespace afnix {
-
+  
   // -------------------------------------------------------------------------
   // - private section                                                       -
   // -------------------------------------------------------------------------
 
   // the default flags
   static const bool   STA_SFLG_DEF = false;
-  static const bool   STA_VFLG_DEF = false;
   // the default cipher
   static const t_word STA_CIFR_DEF = 0x0000U;
   // the default size
@@ -41,12 +40,12 @@ namespace afnix {
   static const long   STA_BSIZ_DEF = 0L;
   static const long   STA_VSIZ_DEF = 0L;
   static const long   STA_HSIZ_DEF = 0L;
+  static const t_octa STA_CNUM_DEF = nilo;
+  static const t_octa STA_SNUM_DEF = nilo;
   
   // the state name and info
   static const String PN_STA_SFLG  = "TLS-STA-SFLG";
   static const String PI_STA_SFLG  = "TLS STATE SERVER FLAG";
-  static const String PN_STA_VFLG  = "TLS-STA-VFLG";
-  static const String PI_STA_VFLG  = "TLS STATE VERIFY FLAG";
   static const String PN_STA_VMAJ  = "TLS-STA-VMAJ";
   static const String PI_STA_VMAJ  = "TLS STATE MAJOR VERSION";
   static const String PN_STA_VMIN  = "TLS-STA-VMIN";
@@ -125,7 +124,6 @@ namespace afnix {
     that.rdlock ();
     try {
       d_sflg = that.d_sflg;
-      d_vflg = that.d_vflg;
       d_vmaj = that.d_vmaj;
       d_vmin = that.d_vmin;
       d_cifr = that.d_cifr;
@@ -133,6 +131,8 @@ namespace afnix {
       d_bsiz = that.d_bsiz;
       d_vsiz = that.d_vsiz;
       d_hsiz = that.d_hsiz;
+      d_cnum = that.d_cnum;
+      d_snum = that.d_snum;
       d_crnd = that.d_crnd;
       d_srnd = that.d_srnd;
       d_mbuf = that.d_mbuf;
@@ -179,7 +179,6 @@ namespace afnix {
     that.rdlock ();
     try {
       d_sflg = that.d_sflg;
-      d_vflg = that.d_vflg;
       d_vmaj = that.d_vmaj;
       d_vmin = that.d_vmin;
       d_cifr = that.d_cifr;
@@ -187,6 +186,8 @@ namespace afnix {
       d_bsiz = that.d_bsiz;
       d_vsiz = that.d_vsiz;
       d_hsiz = that.d_hsiz;
+      d_cnum = that.d_cnum;
+      d_snum = that.d_snum;
       d_crnd = that.d_crnd;
       d_srnd = that.d_srnd;
       d_mbuf = that.d_mbuf;
@@ -239,13 +240,14 @@ namespace afnix {
     wrlock ();
     try {
       d_sflg = STA_SFLG_DEF;
-      d_vflg = STA_VFLG_DEF;
       d_vmaj = TLS_VMAJ_DEF;
       d_vmin = TLS_VMIN_DEF;
       d_ksiz = STA_KSIZ_DEF;
       d_bsiz = STA_BSIZ_DEF;
       d_vsiz = STA_VSIZ_DEF;
       d_hsiz = STA_HSIZ_DEF;
+      d_cnum = STA_CNUM_DEF;
+      d_snum = STA_SNUM_DEF;
       d_crnd.reset ();
       d_srnd.reset ();
       d_mbuf.reset ();
@@ -281,7 +283,6 @@ namespace afnix {
       Plist plst = d_info;
       // add the state info
       plst.add (PN_STA_SFLG, PI_STA_SFLG, d_sflg);
-      plst.add (PN_STA_VFLG, PI_STA_VFLG, d_vflg);
       plst.add (PN_STA_VMAJ, PI_STA_VMAJ, (t_long) d_vmaj);
       plst.add (PN_STA_VMIN, PI_STA_VMIN, (t_long) d_vmin);
       plst.add (PN_STA_CRND, PI_STA_CRND, d_crnd.format ());
@@ -385,33 +386,6 @@ namespace afnix {
     }
   }
 
-  // set the verify flag
-
-  void TlsState::setvflg (const bool vflg) {
-    wrlock ();
-    try {
-      d_vflg = vflg;
-      unlock ();
-    } catch (...) {
-      unlock ();
-      throw;
-    }
-  }
-
-  // get the verify flag
-
-  bool TlsState::getvflg (void) const {
-    rdlock ();
-    try {
-      bool result = d_vflg;
-      unlock ();
-      return result;
-    } catch (...) {
-      unlock ();
-      throw;
-    }
-  }
-
   // get the tls major version
 
   t_byte TlsState::getvmaj (void) const {
@@ -787,7 +761,7 @@ namespace afnix {
     }
   }
 
-    // get the client hmac
+  // get the client hmac
 
   Hmac* TlsState::getchmc (void) const {
     rdlock ();
@@ -842,31 +816,117 @@ namespace afnix {
       throw;
     }
   }
-  
-  // change the state cipher spec
 
-  void TlsState::chspec (void) {
+  // get the client sequence number
+
+  t_octa TlsState::getcnum (void) const {
+    rdlock ();
+    try {
+      t_octa result = d_cnum;
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // get the server sequence number
+
+  t_octa TlsState::getsnum (void) const {
+    rdlock ();
+    try {
+      t_octa result = d_snum;      
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+  
+  // get a new client sequence number
+
+  t_octa TlsState::newcnum (void) {
+    wrlock ();
+    try {
+      // get the client sequence number
+      t_octa result = d_cnum;
+      // update only with non null hmac
+      if (p_chmc != nilp) d_cnum++;
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // get a new server sequence number
+
+  t_octa TlsState::newsnum (void) {
+    wrlock ();
+    try {
+      // get the server sequence number
+      t_octa result = d_snum;
+      // update only with non null hmac
+      if (p_shmc != nilp) d_snum++;
+      unlock ();
+      return result;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // change the state client cipher spec
+
+  bool TlsState::chgccs (void) {
     wrlock ();
     try {
       // remove old ciphers
       Object::dref (p_cbcf); p_cbcf = nilp;
-      Object::dref (p_sbcf); p_sbcf = nilp;
       // rebuild new ciphers
       if (p_suit != nilp) {
 	p_cbcf = p_suit->getcipher (d_cifr, true,  d_ckey, d_civb);
-	p_sbcf = p_suit->getcipher (d_cifr, false, d_skey, d_sivb);
-	Object::iref (p_cbcf); Object::iref (p_sbcf);
+	Object::iref (p_cbcf);
       }
       // remove old hmacs
       Object::dref (p_chmc); p_chmc = nilp;
-      Object::dref (p_shmc); p_shmc = nilp;
       // rebuild new macs
       if (p_suit != nilp) {
 	p_chmc = p_suit->gethmac (d_cifr, d_cmac);
-	p_shmc = p_suit->gethmac (d_cifr, d_smac);
-	Object::iref (p_chmc); Object::iref (p_shmc);
+	Object::iref (p_chmc);
       }
       unlock ();
+      return true;
+    } catch (...) {
+      unlock ();
+      throw;
+    }
+  }
+
+  // change the state server cipher spec
+
+  bool TlsState::chgscs (void) {
+    wrlock ();
+    try {
+      // remove old ciphers
+      Object::dref (p_sbcf); p_sbcf = nilp;
+      // rebuild new ciphers
+      if (p_suit != nilp) {
+	p_sbcf = p_suit->getcipher (d_cifr, false, d_skey, d_sivb);
+	Object::iref (p_sbcf);
+      }
+      // remove old hmacs
+      Object::dref (p_shmc); p_shmc = nilp;
+      // rebuild new macs
+      if (p_suit != nilp) {
+	p_shmc = p_suit->gethmac (d_cifr, d_smac);
+	Object::iref (p_shmc);
+      }
+      unlock ();
+      return true;
     } catch (...) {
       unlock ();
       throw;
@@ -878,12 +938,11 @@ namespace afnix {
   // -------------------------------------------------------------------------
 
   // the quark zone
-  static const long QUARK_ZONE_LENGTH = 12;
+  static const long QUARK_ZONE_LENGTH = 16;
   static QuarkZone  zone (QUARK_ZONE_LENGTH);
 
   // the object supported quarks
   static const long QUARK_SERVP   = zone.intern ("server-p");
-  static const long QUARK_VERIFYP = zone.intern ("verify-p");
   static const long QUARK_GETKSIZ = zone.intern ("get-key-size");
   static const long QUARK_GETBSIZ = zone.intern ("get-block-size");
   static const long QUARK_GETVSIZ = zone.intern ("get-iv-size");
@@ -896,6 +955,8 @@ namespace afnix {
   static const long QUARK_GETSRND = zone.intern ("get-server-random-buffer");
   static const long QUARK_GETMBUF = zone.intern ("get-master-secret-buffer");
   static const long QUARK_GETEBUF = zone.intern ("get-key-expansion-buffer");
+  static const long QUARK_GETCNUM = zone.intern ("get-client-sequence-number");
+  static const long QUARK_GETSNUM = zone.intern ("get-server-sequence-number");
 
   // create a new object in a generic way
 
@@ -943,7 +1004,6 @@ namespace afnix {
     // dispatch 0 arguments
     if (argc == 0) {
       if (quark == QUARK_SERVP)   return new Boolean (getsflg ());
-      if (quark == QUARK_VERIFYP) return new Boolean (getvflg ());
       if (quark == QUARK_GETVMAJ) return new Byte (getvmaj ());
       if (quark == QUARK_GETVMIN) return new Byte (getvmin ());
       if (quark == QUARK_GETKSIZ) return new Integer (getksiz ());
@@ -954,6 +1014,8 @@ namespace afnix {
       if (quark == QUARK_GETSRND) return new Buffer  (getsrnd ());
       if (quark == QUARK_GETMBUF) return new Buffer  (getmbuf ());
       if (quark == QUARK_GETEBUF) return new Buffer  (getebuf ());
+      if (quark == QUARK_GETCNUM) return new Integer (getcnum ());
+      if (quark == QUARK_GETSNUM) return new Integer (getsnum ());
       if (quark == QUARK_GETSUIT) {
 	rdlock ();
 	try {
