@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #ifndef  AFNIX_TLSSTATE_HPP
@@ -31,18 +31,18 @@
 
 namespace afnix {
 
-  /// The TlsConnect class is the common connection socket class for the
-  /// tls protocol. The class is designed to negotiate a tls connection
-  /// which result in the generation of a tls socket object. It is here
-  /// the handshake is performed.
+  /// The TlsState class is the global tls connnection state object. The class
+  /// is designed to carry all the information about the tls session, including
+  /// the most wanted keys, cipher version, certificate list and so on and so
+  /// forth. Since the class also holds the sequence number, it is here that
+  /// the record hmac computation is performed although this does not seem
+  /// natural.
   /// @author amaury darsch
 
   class TlsState : public TlsInfos {
   protected:
     /// the server flag
     bool   d_sflg;
-    /// the verify flag
-    bool   d_vflg;
     /// the major version
     t_byte d_vmaj;
     /// the minor version
@@ -57,6 +57,10 @@ namespace afnix {
     long   d_vsiz;
     /// the hash size
     long   d_hsiz;
+    /// the client sequence number
+    t_octa d_cnum;
+    /// the server sequence number
+    t_octa d_snum;    
     /// the client random
     Buffer d_crnd;
     /// the server random
@@ -93,7 +97,7 @@ namespace afnix {
     TlsSuite* p_suit;
     /// the certificate list
     TlsCerts* p_cert;
-    
+
   public:
     /// create a  default tls state
     TlsState (void);
@@ -164,13 +168,6 @@ namespace afnix {
     /// @return the server flag
     virtual bool getsflg (void) const;
 
-    /// set the verify flag
-    /// @param vlfg the verify flag
-    virtual void setvflg (const bool vflg);
-
-    /// @return the verify flag
-    virtual bool getvflg (void) const;
-
     /// @return the tls major version
     virtual t_byte getvmaj (void) const;
 
@@ -267,9 +264,24 @@ namespace afnix {
     /// @return the handshake verify message buffer
     virtual const Buffer& gethvmb (void) const;
 
-    /// change the cipher spec
-    virtual void chspec (void);
+    /// @return the client sequence number
+    virtual t_octa getcnum (void) const;
+
+    /// @return the server sequence number
+    virtual t_octa getsnum (void) const;
+
+    /// @return a new client sequence number
+    virtual t_octa newcnum (void);
     
+    /// @return a new server sequence number
+    virtual t_octa newsnum (void);
+    
+    /// change the client cipher spec
+    virtual bool chgccs (void);
+
+    /// change the server cipher spec
+    virtual bool chgscs (void);
+
   public:
     /// create a new object in a generic way
     /// @param argv the argument vector
