@@ -11,7 +11,7 @@
 // - the copyright holder be liable for any  direct, indirect, incidental or -
 // - special damages arising in any way out of the use of this software.     -
 // ---------------------------------------------------------------------------
-// - copyright (c) 1999-2016 amaury darsch                                   -
+// - copyright (c) 1999-2017 amaury darsch                                   -
 // ---------------------------------------------------------------------------
 
 #include "Aes.hpp"
@@ -621,6 +621,9 @@ namespace afnix {
       s_cinfo cinfo = getcinfo (cifr);
       // create the cipher result
       Cipher* result = cinfo.getcipher (rflg, kbuf, kiv);
+      // force the padding to none with block cipher
+      auto* bc = dynamic_cast<BlockCipher*> (result);
+      if (bc != nilp) bc->setpmod (BlockCipher::CPM_NONE);
       // here it is
       unlock ();
       return result;
